/******************************************************************************
*   This file is part of TinTin++                                             *
*                                                                             *
*   Copyright 2004-2019 Igor van den Hoven                                    *
*                                                                             *
*   TinTin++ is free software; you can redistribute it and/or modify          *
*   it under the terms of the GNU General Public License as published by      *
*   the Free Software Foundation; either version 3 of the License, or         *
*   (at your option) any later version.                                       *
*                                                                             *
*   This program is distributed in the hope that it will be useful,           *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of            *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
*   GNU General Public License for more details.                              *
*                                                                             *
*                                                                             *
*   You should have received a copy of the GNU General Public License         *
*   along with TinTin++.  If not, see https://www.gnu.org/licenses.           *
******************************************************************************/

/******************************************************************************
*                (T)he K(I)cki(N) (T)ickin D(I)kumud Clie(N)t                 *
*                                                                             *
*                         coded by Peter Unold 1992                           *
******************************************************************************/

#include "tintin.h"


DO_COMMAND(do_bell)
{
	arg = sub_arg_in_braces(ses, arg, arg1, GET_ONE, SUB_VAR|SUB_FUN);
	arg = sub_arg_in_braces(ses, arg, arg2, GET_ONE, SUB_VAR|SUB_FUN);

	if (*arg1 == 0)
	{
		print_stdout(0, 0, "\007");
	}
	else if (is_abbrev(arg1, "FLASH"))
	{
		if (is_abbrev(arg2, "ON"))
		{
			print_stdout(0, 0, "\e[?1042h");
		}
		else if (is_abbrev(arg2, "OFF"))
		{
			print_stdout(0, 0, "\e[?1042l");
		}
		else
		{
			show_error(ses, LIST_COMMAND, "#SYNTAX: #BELL FLASH {ON|OFF}");
		}
	}
	else if (is_abbrev(arg1, "FOCUS"))
	{
		if (is_abbrev(arg2, "ON"))
		{
			print_stdout(0, 0, "\e[?1043h");
		}
		else if (is_abbrev(arg2, "OFF"))
		{
			print_stdout(0, 0, "\e[?1043l");
		}
		else
		{
			show_error(ses, LIST_COMMAND, "#SYNTAX: #BELL FOCUS {ON|OFF}");
		}
	}
	else if (is_abbrev(arg1, "MARGIN"))
	{
		if (is_abbrev(arg2, "ON"))
		{
			print_stdout(0, 0, "\e[?44h");
		}
		else if (is_abbrev(arg2, "OFF"))
		{
			print_stdout(0, 0, "\e[?44l");
		}
		else
		{
			show_error(ses, LIST_COMMAND, "#SYNTAX: #BELL MARGIN {ON|OFF}");
		}
	}
	else if (is_abbrev(arg1, "RING"))
	{
		print_stdout(0, 0, "\007");
	}
	else if (is_abbrev(arg1, "VOLUME"))
	{
		if (is_math(ses, arg2))
		{
			print_stdout(0, 0, "\e[ %dt", (int) get_number(ses, arg2));
		}
		else
		{
			show_error(ses, LIST_COMMAND, "#SYNTAX: #BELL VOLUME {1-8}");
		}
	}
	else
	{
		show_error(ses, LIST_COMMAND, "#SYNTAX: #BELL {FLASH|FOCUS|MARGIN|RING|VOLUME} {ARGUMENT}");
	}

	return ses;
}


DO_COMMAND(do_cr)
{
	write_mud(ses, "", SUB_EOL);

	return ses;
}


DO_COMMAND(do_echo)
{
	char *format, *result, *temp, *output, *left;
	int lnf;

	format = arg1;
	result = arg2;

	temp = str_alloc_stack(0);
	left = str_alloc_stack(0);

	arg = sub_arg_in_braces(ses, arg, format, GET_ONE, SUB_VAR|SUB_FUN);

	format_string(ses, format, arg, result);

	arg = result;

	if (*arg == DEFAULT_OPEN)
	{
		arg = get_arg_in_braces(ses, arg, left, GET_ALL);
		      get_arg_in_braces(ses, arg, temp, GET_ALL);

		if (*temp)
		{
//			int row = (int) get_number(ses, temp);

			substitute(ses, left, format, SUB_COL|SUB_ESC);

			split_show(ses, format, temp, "");

			return ses;
		}
	}

	lnf = is_suffix(arg, "\\") && !is_suffix(arg, "\\\\");

	substitute(ses, arg, temp, SUB_COL|SUB_ESC);

	output = str_alloc_stack(0);

	if (strip_vt102_strlen(ses, ses->more_output) != 0)
	{
		str_cpy_printf(&output, "\n\e[0m%s\e[0m", temp);
	}
	else
	{
		str_cpy_printf(&output, "\e[0m%s\e[0m", temp);
	}

	add_line_buffer(ses, output, lnf);

	if (ses == gtd->ses)
	{
		if (!HAS_BIT(ses->flags, SES_FLAG_READMUD) && IS_SPLIT(ses))
		{
			save_pos(ses);

			goto_pos(ses, ses->split->bot_row, 1);

			print_line(ses, &output, lnf);
			
			restore_pos(ses);
		}
		else
		{
			print_line(ses, &output, lnf);
		}
	}

	return ses;
}


DO_COMMAND(do_end)
{
	if (*arg)
	{
		sub_arg_in_braces(ses, arg, arg1, GET_ALL, SUB_VAR|SUB_FUN|SUB_COL|SUB_ESC|SUB_LNF);

		quitmsg(arg1);
	}
	else
	{
		quitmsg(NULL);
	}
	return NULL;
}


DO_COMMAND(do_nop)
{
	return ses;
}


DO_COMMAND(do_send)
{
	push_call("do_send(%p,%p)",ses,arg);

	get_arg_in_braces(ses, arg, arg1, GET_ALL);

	write_mud(ses, arg1, SUB_VAR|SUB_FUN|SUB_ESC|SUB_EOL);

	pop_call();
	return ses;
}

struct interval_type
{
        int head;
        int tail;
};

struct interval_type cp949_to_unicode_table[] =
{
{0xB0A1,0xAC00},{0xB0A2,0xAC01},{0x8141,0xAC02},{0x8142,0xAC03},{0xB0A3,0xAC04},{0x8143,0xAC05},{0x8144,0xAC06},{0xB0A4,0xAC07},{0xB0A5,0xAC08},{0xB0A6,0xAC09},{0xB0A7,0xAC0A},{0x8145,0xAC0B},{0x8146,0xAC0C},{0x8147,0xAC0D},{0x8148,0xAC0E},{0x8149,0xAC0F},{0xB0A8,0xAC10},{0xB0A9,0xAC11},{0xB0AA,0xAC12},{0xB0AB,0xAC13},{0xB0AC,0xAC14},{0xB0AD,0xAC15},{0xB0AE,0xAC16},{0xB0AF,0xAC17},{0x814A,0xAC18},{0xB0B0,0xAC19},{0xB0B1,0xAC1A},{0xB0B2,0xAC1B},{0xB0B3,0xAC1C},{0xB0B4,0xAC1D},{0x814B,0xAC1E},{0x814C,0xAC1F},{0xB0B5,0xAC20},{0x814D,0xAC21},{0x814E,0xAC22},{0x814F,0xAC23},{0xB0B6,0xAC24},{0x8150,0xAC25},{0x8151,0xAC26},{0x8152,0xAC27},{0x8153,0xAC28},{0x8154,0xAC29},{0x8155,0xAC2A},{0x8156,0xAC2B},{0xB0B7,0xAC2C},{0xB0B8,0xAC2D},{0x8157,0xAC2E},{0xB0B9,0xAC2F},{0xB0BA,0xAC30},{0xB0BB,0xAC31},{0x8158,0xAC32},{0x8159,0xAC33},{0x815A,0xAC34},{0x8161,0xAC35},{0x8162,0xAC36},{0x8163,0xAC37},{0xB0BC,0xAC38},{0xB0BD,0xAC39},{0x8164,0xAC3A},{0x8165,0xAC3B},{0xB0BE,0xAC3C},{0x8166,0xAC3D},{0x8167,0xAC3E},{0x8168,0xAC3F},{0xB0BF,0xAC40},{0x8169,0xAC41},{0x816A,0xAC42},{0x816B,0xAC43},{0x816C,0xAC44},{0x816D,0xAC45},{0x816E,0xAC46},{0x816F,0xAC47},{0x8170,0xAC48},{0x8171,0xAC49},{0x8172,0xAC4A},{0xB0C0,0xAC4B},{0x8173,0xAC4C},{0xB0C1,0xAC4D},{0x8174,0xAC4E},{0x8175,0xAC4F},{0x8176,0xAC50},{0x8177,0xAC51},{0x8178,0xAC52},{0x8179,0xAC53},{0xB0C2,0xAC54},{0x817A,0xAC55},{0x8181,0xAC56},{0x8182,0xAC57},{0xB0C3,0xAC58},{0x8183,0xAC59},{0x8184,0xAC5A},{0x8185,0xAC5B},{0xB0C4,0xAC5C},{0x8186,0xAC5D},{0x8187,0xAC5E},{0x8188,0xAC5F},{0x8189,0xAC60},{0x818A,0xAC61},{0x818B,0xAC62},{0x818C,0xAC63},{0x818D,0xAC64},{0x818E,0xAC65},{0x818F,0xAC66},{0x8190,0xAC67},{0x8191,0xAC68},{0x8192,0xAC69},{0x8193,0xAC6A},{0x8194,0xAC6B},{0x8195,0xAC6C},{0x8196,0xAC6D},{0x8197,0xAC6E},{0x8198,0xAC6F},{0xB0C5,0xAC70},{0xB0C6,0xAC71},{0x8199,0xAC72},{0x819A,0xAC73},{0xB0C7,0xAC74},{0x819B,0xAC75},{0x819C,0xAC76},{0xB0C8,0xAC77},{0xB0C9,0xAC78},{0x819D,0xAC79},{0xB0CA,0xAC7A},{0x819E,0xAC7B},{0x819F,0xAC7C},{0x81A0,0xAC7D},{0x81A1,0xAC7E},{0x81A2,0xAC7F},{0xB0CB,0xAC80},{0xB0CC,0xAC81},{0x81A3,0xAC82},{0xB0CD,0xAC83},{0xB0CE,0xAC84},{0xB0CF,0xAC85},{0xB0D0,0xAC86},{0x81A4,0xAC87},{0x81A5,0xAC88},{0xB0D1,0xAC89},{0xB0D2,0xAC8A},{0xB0D3,0xAC8B},{0xB0D4,0xAC8C},{0x81A6,0xAC8D},{0x81A7,0xAC8E},{0x81A8,0xAC8F},{0xB0D5,0xAC90},{0x81A9,0xAC91},{0x81AA,0xAC92},{0x81AB,0xAC93},{0xB0D6,0xAC94},{0x81AC,0xAC95},{0x81AD,0xAC96},{0x81AE,0xAC97},{0x81AF,0xAC98},{0x81B0,0xAC99},{0x81B1,0xAC9A},{0x81B2,0xAC9B},{0xB0D7,0xAC9C},{0xB0D8,0xAC9D},{0x81B3,0xAC9E},{0xB0D9,0xAC9F},{0xB0DA,0xACA0},{0xB0DB,0xACA1},{0x81B4,0xACA2},{0x81B5,0xACA3},{0x81B6,0xACA4},{0x81B7,0xACA5},{0x81B8,0xACA6},{0x81B9,0xACA7},{0xB0DC,0xACA8},{0xB0DD,0xACA9},{0xB0DE,0xACAA},{0x81BA,0xACAB},{0xB0DF,0xACAC},{0x81BB,0xACAD},{0x81BC,0xACAE},{0xB0E0,0xACAF},{0xB0E1,0xACB0},{0x81BD,0xACB1},{0x81BE,0xACB2},{0x81BF,0xACB3},{0x81C0,0xACB4},{0x81C1,0xACB5},{0x81C2,0xACB6},{0x81C3,0xACB7},{0xB0E2,0xACB8},{0xB0E3,0xACB9},{0x81C4,0xACBA},{0xB0E4,0xACBB},{0xB0E5,0xACBC},{0xB0E6,0xACBD},{0x81C5,0xACBE},{0x81C6,0xACBF},{0x81C7,0xACC0},{0xB0E7,0xACC1},{0x81C8,0xACC2},{0x81C9,0xACC3},{0xB0E8,0xACC4},{0x81CA,0xACC5},{0x81CB,0xACC6},{0x81CC,0xACC7},{0xB0E9,0xACC8},{0x81CD,0xACC9},{0x81CE,0xACCA},{0x81CF,0xACCB},{0xB0EA,0xACCC},{0x81D0,0xACCD},{0x81D1,0xACCE},{0x81D2,0xACCF},{0x81D3,0xACD0},{0x81D4,0xACD1},{0x81D5,0xACD2},{0x81D6,0xACD3},{0x81D7,0xACD4},{0xB0EB,0xACD5},{0x81D8,0xACD6},{0xB0EC,0xACD7},{0x81D9,0xACD8},{0x81DA,0xACD9},{0x81DB,0xACDA},{0x81DC,0xACDB},{0x81DD,0xACDC},{0x81DE,0xACDD},{0x81DF,0xACDE},{0x81E0,0xACDF},{0xB0ED,0xACE0},{0xB0EE,0xACE1},{0x81E1,0xACE2},{0x81E2,0xACE3},{0xB0EF,0xACE4},{0x81E3,0xACE5},{0x81E4,0xACE6},{0xB0F0,0xACE7},{0xB0F1,0xACE8},{0x81E5,0xACE9},{0xB0F2,0xACEA},{0x81E6,0xACEB},{0xB0F3,0xACEC},{0x81E7,0xACED},{0x81E8,0xACEE},{0xB0F4,0xACEF},{0xB0F5,0xACF0},{0xB0F6,0xACF1},{0x81E9,0xACF2},{0xB0F7,0xACF3},{0x81EA,0xACF4},{0xB0F8,0xACF5},{0xB0F9,0xACF6},
{0x81EB,0xACF7},{0x81EC,0xACF8},{0x81ED,0xACF9},{0x81EE,0xACFA},{0x81EF,0xACFB},{0xB0FA,0xACFC},{0xB0FB,0xACFD},{0x81F0,0xACFE},{0x81F1,0xACFF},{0xB0FC,0xAD00},{0x81F2,0xAD01},{0x81F3,0xAD02},{0x81F4,0xAD03},{0xB0FD,0xAD04},{0x81F5,0xAD05},{0xB0FE,0xAD06},{0x81F6,0xAD07},{0x81F7,0xAD08},{0x81F8,0xAD09},{0x81F9,0xAD0A},{0x81FA,0xAD0B},{0xB1A1,0xAD0C},{0xB1A2,0xAD0D},{0x81FB,0xAD0E},{0xB1A3,0xAD0F},{0x81FC,0xAD10},{0xB1A4,0xAD11},{0x81FD,0xAD12},{0x81FE,0xAD13},{0x8241,0xAD14},{0x8242,0xAD15},{0x8243,0xAD16},{0x8244,0xAD17},{0xB1A5,0xAD18},{0x8245,0xAD19},{0x8246,0xAD1A},{0x8247,0xAD1B},{0xB1A6,0xAD1C},{0x8248,0xAD1D},{0x8249,0xAD1E},{0x824A,0xAD1F},{0xB1A7,0xAD20},{0x824B,0xAD21},{0x824C,0xAD22},{0x824D,0xAD23},{0x824E,0xAD24},{0x824F,0xAD25},{0x8250,0xAD26},{0x8251,0xAD27},{0x8252,0xAD28},{0xB1A8,0xAD29},{0x8253,0xAD2A},{0x8254,0xAD2B},{0xB1A9,0xAD2C},{0xB1AA,0xAD2D},{0x8255,0xAD2E},{0x8256,0xAD2F},{0x8257,0xAD30},{0x8258,0xAD31},{0x8259,0xAD32},{0x825A,0xAD33},{0xB1AB,0xAD34},{0xB1AC,0xAD35},{0x8261,0xAD36},{0x8262,0xAD37},{0xB1AD,0xAD38},{0x8263,0xAD39},{0x8264,0xAD3A},{0x8265,0xAD3B},{0xB1AE,0xAD3C},{0x8266,0xAD3D},{0x8267,0xAD3E},{0x8268,0xAD3F},{0x8269,0xAD40},{0x826A,0xAD41},{0x826B,0xAD42},{0x826C,0xAD43},{0xB1AF,0xAD44},{0xB1B0,0xAD45},{0x826D,0xAD46},{0xB1B1,0xAD47},{0x826E,0xAD48},{0xB1B2,0xAD49},{0x826F,0xAD4A},{0x8270,0xAD4B},{0x8271,0xAD4C},{0x8272,0xAD4D},{0x8273,0xAD4E},{0x8274,0xAD4F},{0xB1B3,0xAD50},{0x8275,0xAD51},{0x8276,0xAD52},{0x8277,0xAD53},{0xB1B4,0xAD54},{0x8278,0xAD55},{0x8279,0xAD56},{0x827A,0xAD57},{0xB1B5,0xAD58},{0x8281,0xAD59},{0x8282,0xAD5A},{0x8283,0xAD5B},{0x8284,0xAD5C},{0x8285,0xAD5D},{0x8286,0xAD5E},{0x8287,0xAD5F},{0x8288,0xAD60},{0xB1B6,0xAD61},{0x8289,0xAD62},{0xB1B7,0xAD63},{0x828A,0xAD64},{0x828B,0xAD65},{0x828C,0xAD66},{0x828D,0xAD67},{0x828E,0xAD68},{0x828F,0xAD69},{0x8290,0xAD6A},{0x8291,0xAD6B},{0xB1B8,0xAD6C},{0xB1B9,0xAD6D},{0x8292,0xAD6E},{0x8293,0xAD6F},{0xB1BA,0xAD70},{0x8294,0xAD71},{0x8295,0xAD72},{0xB1BB,0xAD73},{0xB1BC,0xAD74},{0xB1BD,0xAD75},{0xB1BE,0xAD76},{0x8296,0xAD77},{0x8297,0xAD78},{0x8298,0xAD79},{0x8299,0xAD7A},{0xB1BF,0xAD7B},{0xB1C0,0xAD7C},{0xB1C1,0xAD7D},{0x829A,0xAD7E},{0xB1C2,0xAD7F},{0x829B,0xAD80},{0xB1C3,0xAD81},{0xB1C4,0xAD82},{0x829C,0xAD83},{0x829D,0xAD84},{0x829E,0xAD85},{0x829F,0xAD86},{0x82A0,0xAD87},{0xB1C5,0xAD88},{0xB1C6,0xAD89},{0x82A1,0xAD8A},{0x82A2,0xAD8B},{0xB1C7,0xAD8C},{0x82A3,0xAD8D},{0x82A4,0xAD8E},{0x82A5,0xAD8F},{0xB1C8,0xAD90},{0x82A6,0xAD91},{0x82A7,0xAD92},{0x82A8,0xAD93},{0x82A9,0xAD94},{0x82AA,0xAD95},{0x82AB,0xAD96},{0x82AC,0xAD97},{0x82AD,0xAD98},{0x82AE,0xAD99},{0x82AF,0xAD9A},{0x82B0,0xAD9B},{0xB1C9,0xAD9C},{0xB1CA,0xAD9D},{0x82B1,0xAD9E},{0x82B2,0xAD9F},{0x82B3,0xADA0},{0x82B4,0xADA1},{0x82B5,0xADA2},{0x82B6,0xADA3},{0xB1CB,0xADA4},{0x82B7,0xADA5},{0x82B8,0xADA6},{0x82B9,0xADA7},{0x82BA,0xADA8},{0x82BB,0xADA9},{0x82BC,0xADAA},{0x82BD,0xADAB},{0x82BE,0xADAC},{0x82BF,0xADAD},{0x82C0,0xADAE},{0x82C1,0xADAF},{0x82C2,0xADB0},{0x82C3,0xADB1},{0x82C4,0xADB2},{0x82C5,0xADB3},{0x82C6,0xADB4},{0x82C7,0xADB5},{0x82C8,0xADB6},{0xB1CC,0xADB7},{0x82C9,0xADB8},{0x82CA,0xADB9},{0x82CB,0xADBA},{0x82CC,0xADBB},{0x82CD,0xADBC},{0x82CE,0xADBD},{0x82CF,0xADBE},{0x82D0,0xADBF},{0xB1CD,0xADC0},{0xB1CE,0xADC1},{0x82D1,0xADC2},{0x82D2,0xADC3},{0xB1CF,0xADC4},{0x82D3,0xADC5},{0x82D4,0xADC6},{0x82D5,0xADC7},{0xB1D0,0xADC8},{0x82D6,0xADC9},{0x82D7,0xADCA},{0x82D8,0xADCB},{0x82D9,0xADCC},{0x82DA,0xADCD},{0x82DB,0xADCE},{0x82DC,0xADCF},{0xB1D1,0xADD0},{0xB1D2,0xADD1},{0x82DD,0xADD2},{0xB1D3,0xADD3},{0x82DE,0xADD4},{0x82DF,0xADD5},{0x82E0,0xADD6},{0x82E1,0xADD7},{0x82E2,0xADD8},{0x82E3,0xADD9},{0x82E4,0xADDA},{0x82E5,0xADDB},{0xB1D4,0xADDC},{0x82E6,0xADDD},{0x82E7,0xADDE},{0x82E8,0xADDF},{0xB1D5,0xADE0},{0x82E9,0xADE1},{0x82EA,0xADE2},{0x82EB,0xADE3},{0xB1D6,0xADE4},{0x82EC,0xADE5},{0x82ED,0xADE6},{0x82EE,0xADE7},{0x82EF,0xADE8},{0x82F0,0xADE9},{0x82F1,0xADEA},{0x82F2,0xADEB},{0x82F3,0xADEC},{0x82F4,0xADED},
{0x82F5,0xADEE},{0x82F6,0xADEF},{0x82F7,0xADF0},{0x82F8,0xADF1},{0x82F9,0xADF2},{0x82FA,0xADF3},{0x82FB,0xADF4},{0x82FC,0xADF5},{0x82FD,0xADF6},{0x82FE,0xADF7},{0xB1D7,0xADF8},{0xB1D8,0xADF9},{0x8341,0xADFA},{0x8342,0xADFB},{0xB1D9,0xADFC},{0x8343,0xADFD},{0x8344,0xADFE},{0xB1DA,0xADFF},{0xB1DB,0xAE00},{0xB1DC,0xAE01},{0x8345,0xAE02},{0x8346,0xAE03},{0x8347,0xAE04},{0x8348,0xAE05},{0x8349,0xAE06},{0x834A,0xAE07},{0xB1DD,0xAE08},{0xB1DE,0xAE09},{0x834B,0xAE0A},{0xB1DF,0xAE0B},{0x834C,0xAE0C},{0xB1E0,0xAE0D},{0x834D,0xAE0E},{0x834E,0xAE0F},{0x834F,0xAE10},{0x8350,0xAE11},{0x8351,0xAE12},{0x8352,0xAE13},{0xB1E1,0xAE14},{0x8353,0xAE15},{0x8354,0xAE16},{0x8355,0xAE17},{0x8356,0xAE18},{0x8357,0xAE19},{0x8358,0xAE1A},{0x8359,0xAE1B},{0x835A,0xAE1C},{0x8361,0xAE1D},{0x8362,0xAE1E},{0x8363,0xAE1F},{0x8364,0xAE20},{0x8365,0xAE21},{0x8366,0xAE22},{0x8367,0xAE23},{0x8368,0xAE24},{0x8369,0xAE25},{0x836A,0xAE26},{0x836B,0xAE27},{0x836C,0xAE28},{0x836D,0xAE29},{0x836E,0xAE2A},{0x836F,0xAE2B},{0x8370,0xAE2C},{0x8371,0xAE2D},{0x8372,0xAE2E},{0x8373,0xAE2F},{0xB1E2,0xAE30},{0xB1E3,0xAE31},{0x8374,0xAE32},{0x8375,0xAE33},{0xB1E4,0xAE34},{0x8376,0xAE35},{0x8377,0xAE36},{0xB1E5,0xAE37},{0xB1E6,0xAE38},{0x8378,0xAE39},{0xB1E7,0xAE3A},{0x8379,0xAE3B},{0x837A,0xAE3C},{0x8381,0xAE3D},{0x8382,0xAE3E},{0x8383,0xAE3F},{0xB1E8,0xAE40},{0xB1E9,0xAE41},{0x8384,0xAE42},{0xB1EA,0xAE43},{0x8385,0xAE44},{0xB1EB,0xAE45},{0xB1EC,0xAE46},{0x8386,0xAE47},{0x8387,0xAE48},{0x8388,0xAE49},{0xB1ED,0xAE4A},{0x8389,0xAE4B},{0xB1EE,0xAE4C},{0xB1EF,0xAE4D},{0xB1F0,0xAE4E},{0x838A,0xAE4F},{0xB1F1,0xAE50},{0x838B,0xAE51},{0x838C,0xAE52},{0x838D,0xAE53},{0xB1F2,0xAE54},{0x838E,0xAE55},{0xB1F3,0xAE56},{0x838F,0xAE57},{0x8390,0xAE58},{0x8391,0xAE59},{0x8392,0xAE5A},{0x8393,0xAE5B},{0xB1F4,0xAE5C},{0xB1F5,0xAE5D},{0x8394,0xAE5E},{0xB1F6,0xAE5F},{0xB1F7,0xAE60},{0xB1F8,0xAE61},{0x8395,0xAE62},{0x8396,0xAE63},{0x8397,0xAE64},{0xB1F9,0xAE65},{0x8398,0xAE66},{0x8399,0xAE67},{0xB1FA,0xAE68},{0xB1FB,0xAE69},{0x839A,0xAE6A},{0x839B,0xAE6B},{0xB1FC,0xAE6C},{0x839C,0xAE6D},{0x839D,0xAE6E},{0x839E,0xAE6F},{0xB1FD,0xAE70},{0x839F,0xAE71},{0x83A0,0xAE72},{0x83A1,0xAE73},{0x83A2,0xAE74},{0x83A3,0xAE75},{0x83A4,0xAE76},{0x83A5,0xAE77},{0xB1FE,0xAE78},{0xB2A1,0xAE79},{0x83A6,0xAE7A},{0xB2A2,0xAE7B},{0xB2A3,0xAE7C},{0xB2A4,0xAE7D},{0x83A7,0xAE7E},{0x83A8,0xAE7F},{0x83A9,0xAE80},{0x83AA,0xAE81},{0x83AB,0xAE82},{0x83AC,0xAE83},{0xB2A5,0xAE84},{0xB2A6,0xAE85},{0x83AD,0xAE86},{0x83AE,0xAE87},{0x83AF,0xAE88},{0x83B0,0xAE89},{0x83B1,0xAE8A},{0x83B2,0xAE8B},{0xB2A7,0xAE8C},{0x83B3,0xAE8D},{0x83B4,0xAE8E},{0x83B5,0xAE8F},{0x83B6,0xAE90},{0x83B7,0xAE91},{0x83B8,0xAE92},{0x83B9,0xAE93},{0x83BA,0xAE94},{0x83BB,0xAE95},{0x83BC,0xAE96},{0x83BD,0xAE97},{0x83BE,0xAE98},{0x83BF,0xAE99},{0x83C0,0xAE9A},{0x83C1,0xAE9B},{0x83C2,0xAE9C},{0x83C3,0xAE9D},{0x83C4,0xAE9E},{0x83C5,0xAE9F},{0x83C6,0xAEA0},{0x83C7,0xAEA1},{0x83C8,0xAEA2},{0x83C9,0xAEA3},{0x83CA,0xAEA4},{0x83CB,0xAEA5},{0x83CC,0xAEA6},{0x83CD,0xAEA7},{0x83CE,0xAEA8},{0x83CF,0xAEA9},{0x83D0,0xAEAA},{0x83D1,0xAEAB},{0x83D2,0xAEAC},{0x83D3,0xAEAD},{0x83D4,0xAEAE},{0x83D5,0xAEAF},{0x83D6,0xAEB0},{0x83D7,0xAEB1},{0x83D8,0xAEB2},{0x83D9,0xAEB3},{0x83DA,0xAEB4},{0x83DB,0xAEB5},{0x83DC,0xAEB6},{0x83DD,0xAEB7},{0x83DE,0xAEB8},{0x83DF,0xAEB9},{0x83E0,0xAEBA},{0x83E1,0xAEBB},{0xB2A8,0xAEBC},{0xB2A9,0xAEBD},{0xB2AA,0xAEBE},{0x83E2,0xAEBF},{0xB2AB,0xAEC0},{0x83E3,0xAEC1},{0x83E4,0xAEC2},{0x83E5,0xAEC3},{0xB2AC,0xAEC4},{0x83E6,0xAEC5},{0x83E7,0xAEC6},{0x83E8,0xAEC7},{0x83E9,0xAEC8},{0x83EA,0xAEC9},{0x83EB,0xAECA},{0x83EC,0xAECB},{0xB2AD,0xAECC},{0xB2AE,0xAECD},{0x83ED,0xAECE},{0xB2AF,0xAECF},{0xB2B0,0xAED0},{0xB2B1,0xAED1},{0x83EE,0xAED2},{0x83EF,0xAED3},{0x83F0,0xAED4},{0x83F1,0xAED5},{0x83F2,0xAED6},{0x83F3,0xAED7},{0xB2B2,0xAED8},{0xB2B3,0xAED9},{0x83F4,0xAEDA},{0x83F5,0xAEDB},{0xB2B4,0xAEDC},{0x83F6,0xAEDD},{0x83F7,0xAEDE},{0x83F8,0xAEDF},{0x83F9,0xAEE0},{0x83FA,0xAEE1},{0x83FB,0xAEE2},{0x83FC,0xAEE3},{0x83FD,0xAEE4},
{0x83FE,0xAEE5},{0x8441,0xAEE6},{0x8442,0xAEE7},{0xB2B5,0xAEE8},{0x8443,0xAEE9},{0x8444,0xAEEA},{0xB2B6,0xAEEB},{0x8445,0xAEEC},{0xB2B7,0xAEED},{0x8446,0xAEEE},{0x8447,0xAEEF},{0x8448,0xAEF0},{0x8449,0xAEF1},{0x844A,0xAEF2},{0x844B,0xAEF3},{0xB2B8,0xAEF4},{0x844C,0xAEF5},{0x844D,0xAEF6},{0x844E,0xAEF7},{0xB2B9,0xAEF8},{0x844F,0xAEF9},{0x8450,0xAEFA},{0x8451,0xAEFB},{0xB2BA,0xAEFC},{0x8452,0xAEFD},{0x8453,0xAEFE},{0x8454,0xAEFF},{0x8455,0xAF00},{0x8456,0xAF01},{0x8457,0xAF02},{0x8458,0xAF03},{0x8459,0xAF04},{0x845A,0xAF05},{0x8461,0xAF06},{0xB2BB,0xAF07},{0xB2BC,0xAF08},{0x8462,0xAF09},{0x8463,0xAF0A},{0x8464,0xAF0B},{0x8465,0xAF0C},{0xB2BD,0xAF0D},{0x8466,0xAF0E},{0x8467,0xAF0F},{0xB2BE,0xAF10},{0x8468,0xAF11},{0x8469,0xAF12},{0x846A,0xAF13},{0x846B,0xAF14},{0x846C,0xAF15},{0x846D,0xAF16},{0x846E,0xAF17},{0x846F,0xAF18},{0x8470,0xAF19},{0x8471,0xAF1A},{0x8472,0xAF1B},{0x8473,0xAF1C},{0x8474,0xAF1D},{0x8475,0xAF1E},{0x8476,0xAF1F},{0x8477,0xAF20},{0x8478,0xAF21},{0x8479,0xAF22},{0x847A,0xAF23},{0x8481,0xAF24},{0x8482,0xAF25},{0x8483,0xAF26},{0x8484,0xAF27},{0x8485,0xAF28},{0x8486,0xAF29},{0x8487,0xAF2A},{0x8488,0xAF2B},{0xB2BF,0xAF2C},{0xB2C0,0xAF2D},{0x8489,0xAF2E},{0x848A,0xAF2F},{0xB2C1,0xAF30},{0x848B,0xAF31},{0xB2C2,0xAF32},{0x848C,0xAF33},{0xB2C3,0xAF34},{0x848D,0xAF35},{0x848E,0xAF36},{0x848F,0xAF37},{0x8490,0xAF38},{0x8491,0xAF39},{0x8492,0xAF3A},{0x8493,0xAF3B},{0xB2C4,0xAF3C},{0xB2C5,0xAF3D},{0x8494,0xAF3E},{0xB2C6,0xAF3F},{0x8495,0xAF40},{0xB2C7,0xAF41},{0xB2C8,0xAF42},{0xB2C9,0xAF43},{0x8496,0xAF44},{0x8497,0xAF45},{0x8498,0xAF46},{0x8499,0xAF47},{0xB2CA,0xAF48},{0xB2CB,0xAF49},{0x849A,0xAF4A},{0x849B,0xAF4B},{0x849C,0xAF4C},{0x849D,0xAF4D},{0x849E,0xAF4E},{0x849F,0xAF4F},{0xB2CC,0xAF50},{0x84A0,0xAF51},{0x84A1,0xAF52},{0x84A2,0xAF53},{0x84A3,0xAF54},{0x84A4,0xAF55},{0x84A5,0xAF56},{0x84A6,0xAF57},{0x84A7,0xAF58},{0x84A8,0xAF59},{0x84A9,0xAF5A},{0x84AA,0xAF5B},{0xB2CD,0xAF5C},{0xB2CE,0xAF5D},{0x84AB,0xAF5E},{0x84AC,0xAF5F},{0x84AD,0xAF60},{0x84AE,0xAF61},{0x84AF,0xAF62},{0x84B0,0xAF63},{0xB2CF,0xAF64},{0xB2D0,0xAF65},{0x84B1,0xAF66},{0x84B2,0xAF67},{0x84B3,0xAF68},{0x84B4,0xAF69},{0x84B5,0xAF6A},{0x84B6,0xAF6B},{0x84B7,0xAF6C},{0x84B8,0xAF6D},{0x84B9,0xAF6E},{0x84BA,0xAF6F},{0x84BB,0xAF70},{0x84BC,0xAF71},{0x84BD,0xAF72},{0x84BE,0xAF73},{0x84BF,0xAF74},{0x84C0,0xAF75},{0x84C1,0xAF76},{0x84C2,0xAF77},{0x84C3,0xAF78},{0xB2D1,0xAF79},{0x84C4,0xAF7A},{0x84C5,0xAF7B},{0x84C6,0xAF7C},{0x84C7,0xAF7D},{0x84C8,0xAF7E},{0x84C9,0xAF7F},{0xB2D2,0xAF80},{0x84CA,0xAF81},{0x84CB,0xAF82},{0x84CC,0xAF83},{0xB2D3,0xAF84},{0x84CD,0xAF85},{0x84CE,0xAF86},{0x84CF,0xAF87},{0xB2D4,0xAF88},{0x84D0,0xAF89},{0x84D1,0xAF8A},{0x84D2,0xAF8B},{0x84D3,0xAF8C},{0x84D4,0xAF8D},{0x84D5,0xAF8E},{0x84D6,0xAF8F},{0xB2D5,0xAF90},{0xB2D6,0xAF91},{0x84D7,0xAF92},{0x84D8,0xAF93},{0x84D9,0xAF94},{0xB2D7,0xAF95},{0x84DA,0xAF96},{0x84DB,0xAF97},{0x84DC,0xAF98},{0x84DD,0xAF99},{0x84DE,0xAF9A},{0x84DF,0xAF9B},{0xB2D8,0xAF9C},{0x84E0,0xAF9D},{0x84E1,0xAF9E},{0x84E2,0xAF9F},{0x84E3,0xAFA0},{0x84E4,0xAFA1},{0x84E5,0xAFA2},{0x84E6,0xAFA3},{0x84E7,0xAFA4},{0x84E8,0xAFA5},{0x84E9,0xAFA6},{0x84EA,0xAFA7},{0x84EB,0xAFA8},{0x84EC,0xAFA9},{0x84ED,0xAFAA},{0x84EE,0xAFAB},{0x84EF,0xAFAC},{0x84F0,0xAFAD},{0x84F1,0xAFAE},{0x84F2,0xAFAF},{0x84F3,0xAFB0},{0x84F4,0xAFB1},{0x84F5,0xAFB2},{0x84F6,0xAFB3},{0x84F7,0xAFB4},{0x84F8,0xAFB5},{0x84F9,0xAFB6},{0x84FA,0xAFB7},{0xB2D9,0xAFB8},{0xB2DA,0xAFB9},{0x84FB,0xAFBA},{0x84FC,0xAFBB},{0xB2DB,0xAFBC},{0x84FD,0xAFBD},{0x84FE,0xAFBE},{0x8541,0xAFBF},{0xB2DC,0xAFC0},{0x8542,0xAFC1},{0x8543,0xAFC2},{0x8544,0xAFC3},{0x8545,0xAFC4},{0x8546,0xAFC5},{0x8547,0xAFC6},{0xB2DD,0xAFC7},{0xB2DE,0xAFC8},{0xB2DF,0xAFC9},{0x8548,0xAFCA},{0xB2E0,0xAFCB},{0x8549,0xAFCC},{0xB2E1,0xAFCD},{0xB2E2,0xAFCE},{0x854A,0xAFCF},{0x854B,0xAFD0},{0x854C,0xAFD1},{0x854D,0xAFD2},{0x854E,0xAFD3},{0xB2E3,0xAFD4},{0x854F,0xAFD5},{0x8550,0xAFD6},{0x8551,0xAFD7},{0x8552,0xAFD8},{0x8553,0xAFD9},{0x8554,0xAFDA},{0x8555,0xAFDB},
{0xB2E4,0xAFDC},{0x8556,0xAFDD},{0x8557,0xAFDE},{0x8558,0xAFDF},{0x8559,0xAFE0},{0x855A,0xAFE1},{0x8561,0xAFE2},{0x8562,0xAFE3},{0x8563,0xAFE4},{0x8564,0xAFE5},{0x8565,0xAFE6},{0x8566,0xAFE7},{0xB2E5,0xAFE8},{0xB2E6,0xAFE9},{0x8567,0xAFEA},{0x8568,0xAFEB},{0x8569,0xAFEC},{0x856A,0xAFED},{0x856B,0xAFEE},{0x856C,0xAFEF},{0xB2E7,0xAFF0},{0xB2E8,0xAFF1},{0x856D,0xAFF2},{0x856E,0xAFF3},{0xB2E9,0xAFF4},{0x856F,0xAFF5},{0x8570,0xAFF6},{0x8571,0xAFF7},{0xB2EA,0xAFF8},{0x8572,0xAFF9},{0x8573,0xAFFA},{0x8574,0xAFFB},{0x8575,0xAFFC},{0x8576,0xAFFD},{0x8577,0xAFFE},{0x8578,0xAFFF},{0xB2EB,0xB000},{0xB2EC,0xB001},{0x8579,0xB002},{0x857A,0xB003},{0xB2ED,0xB004},{0x8581,0xB005},{0x8582,0xB006},{0x8583,0xB007},{0x8584,0xB008},{0x8585,0xB009},{0x8586,0xB00A},{0x8587,0xB00B},{0xB2EE,0xB00C},{0x8588,0xB00D},{0x8589,0xB00E},{0x858A,0xB00F},{0xB2EF,0xB010},{0x858B,0xB011},{0x858C,0xB012},{0x858D,0xB013},{0xB2F0,0xB014},{0x858E,0xB015},{0x858F,0xB016},{0x8590,0xB017},{0x8591,0xB018},{0x8592,0xB019},{0x8593,0xB01A},{0x8594,0xB01B},{0xB2F1,0xB01C},{0xB2F2,0xB01D},{0x8595,0xB01E},{0x8596,0xB01F},{0x8597,0xB020},{0x8598,0xB021},{0x8599,0xB022},{0x859A,0xB023},{0x859B,0xB024},{0x859C,0xB025},{0x859D,0xB026},{0x859E,0xB027},{0xB2F3,0xB028},{0x859F,0xB029},{0x85A0,0xB02A},{0x85A1,0xB02B},{0x85A2,0xB02C},{0x85A3,0xB02D},{0x85A4,0xB02E},{0x85A5,0xB02F},{0x85A6,0xB030},{0x85A7,0xB031},{0x85A8,0xB032},{0x85A9,0xB033},{0x85AA,0xB034},{0x85AB,0xB035},{0x85AC,0xB036},{0x85AD,0xB037},{0x85AE,0xB038},{0x85AF,0xB039},{0x85B0,0xB03A},{0x85B1,0xB03B},{0x85B2,0xB03C},{0x85B3,0xB03D},{0x85B4,0xB03E},{0x85B5,0xB03F},{0x85B6,0xB040},{0x85B7,0xB041},{0x85B8,0xB042},{0x85B9,0xB043},{0xB2F4,0xB044},{0xB2F5,0xB045},{0x85BA,0xB046},{0x85BB,0xB047},{0xB2F6,0xB048},{0x85BC,0xB049},{0xB2F7,0xB04A},{0x85BD,0xB04B},{0xB2F8,0xB04C},{0x85BE,0xB04D},{0xB2F9,0xB04E},{0x85BF,0xB04F},{0x85C0,0xB050},{0x85C1,0xB051},{0x85C2,0xB052},{0xB2FA,0xB053},{0xB2FB,0xB054},{0xB2FC,0xB055},{0x85C3,0xB056},{0xB2FD,0xB057},{0x85C4,0xB058},{0xB2FE,0xB059},{0x85C5,0xB05A},{0x85C6,0xB05B},{0x85C7,0xB05C},{0xB3A1,0xB05D},{0x85C8,0xB05E},{0x85C9,0xB05F},{0x85CA,0xB060},{0x85CB,0xB061},{0x85CC,0xB062},{0x85CD,0xB063},{0x85CE,0xB064},{0x85CF,0xB065},{0x85D0,0xB066},{0x85D1,0xB067},{0x85D2,0xB068},{0x85D3,0xB069},{0x85D4,0xB06A},{0x85D5,0xB06B},{0x85D6,0xB06C},{0x85D7,0xB06D},{0x85D8,0xB06E},{0x85D9,0xB06F},{0x85DA,0xB070},{0x85DB,0xB071},{0x85DC,0xB072},{0x85DD,0xB073},{0x85DE,0xB074},{0x85DF,0xB075},{0x85E0,0xB076},{0x85E1,0xB077},{0x85E2,0xB078},{0x85E3,0xB079},{0x85E4,0xB07A},{0x85E5,0xB07B},{0xB3A2,0xB07C},{0xB3A3,0xB07D},{0x85E6,0xB07E},{0x85E7,0xB07F},{0xB3A4,0xB080},{0x85E8,0xB081},{0x85E9,0xB082},{0x85EA,0xB083},{0xB3A5,0xB084},{0x85EB,0xB085},{0x85EC,0xB086},{0x85ED,0xB087},{0x85EE,0xB088},{0x85EF,0xB089},{0x85F0,0xB08A},{0x85F1,0xB08B},{0xB3A6,0xB08C},{0xB3A7,0xB08D},{0x85F2,0xB08E},{0xB3A8,0xB08F},{0x85F3,0xB090},{0xB3A9,0xB091},{0x85F4,0xB092},{0x85F5,0xB093},{0x85F6,0xB094},{0x85F7,0xB095},{0x85F8,0xB096},{0x85F9,0xB097},{0xB3AA,0xB098},{0xB3AB,0xB099},{0xB3AC,0xB09A},{0x85FA,0xB09B},{0xB3AD,0xB09C},{0x85FB,0xB09D},{0x85FC,0xB09E},{0xB3AE,0xB09F},{0xB3AF,0xB0A0},{0xB3B0,0xB0A1},{0xB3B1,0xB0A2},{0x85FD,0xB0A3},{0x85FE,0xB0A4},{0x8641,0xB0A5},{0x8642,0xB0A6},{0x8643,0xB0A7},{0xB3B2,0xB0A8},{0xB3B3,0xB0A9},{0x8644,0xB0AA},{0xB3B4,0xB0AB},{0xB3B5,0xB0AC},{0xB3B6,0xB0AD},{0xB3B7,0xB0AE},{0xB3B8,0xB0AF},{0x8645,0xB0B0},{0xB3B9,0xB0B1},{0x8646,0xB0B2},{0xB3BA,0xB0B3},{0xB3BB,0xB0B4},{0xB3BC,0xB0B5},{0x8647,0xB0B6},{0x8648,0xB0B7},{0xB3BD,0xB0B8},{0x8649,0xB0B9},{0x864A,0xB0BA},{0x864B,0xB0BB},{0xB3BE,0xB0BC},{0x864C,0xB0BD},{0x864D,0xB0BE},{0x864E,0xB0BF},{0x864F,0xB0C0},{0x8650,0xB0C1},{0x8651,0xB0C2},{0x8652,0xB0C3},{0xB3BF,0xB0C4},{0xB3C0,0xB0C5},{0x8653,0xB0C6},{0xB3C1,0xB0C7},{0xB3C2,0xB0C8},{0xB3C3,0xB0C9},{0x8654,0xB0CA},{0x8655,0xB0CB},{0x8656,0xB0CC},{0x8657,0xB0CD},{0x8658,0xB0CE},{0x8659,0xB0CF},{0xB3C4,0xB0D0},{0xB3C5,0xB0D1},{0x865A,0xB0D2},
{0x8661,0xB0D3},{0xB3C6,0xB0D4},{0x8662,0xB0D5},{0x8663,0xB0D6},{0x8664,0xB0D7},{0xB3C7,0xB0D8},{0x8665,0xB0D9},{0x8666,0xB0DA},{0x8667,0xB0DB},{0x8668,0xB0DC},{0x8669,0xB0DD},{0x866A,0xB0DE},{0x866B,0xB0DF},{0xB3C8,0xB0E0},{0x866C,0xB0E1},{0x866D,0xB0E2},{0x866E,0xB0E3},{0x866F,0xB0E4},{0xB3C9,0xB0E5},{0x8670,0xB0E6},{0x8671,0xB0E7},{0x8672,0xB0E8},{0x8673,0xB0E9},{0x8674,0xB0EA},{0x8675,0xB0EB},{0x8676,0xB0EC},{0x8677,0xB0ED},{0x8678,0xB0EE},{0x8679,0xB0EF},{0x867A,0xB0F0},{0x8681,0xB0F1},{0x8682,0xB0F2},{0x8683,0xB0F3},{0x8684,0xB0F4},{0x8685,0xB0F5},{0x8686,0xB0F6},{0x8687,0xB0F7},{0x8688,0xB0F8},{0x8689,0xB0F9},{0x868A,0xB0FA},{0x868B,0xB0FB},{0x868C,0xB0FC},{0x868D,0xB0FD},{0x868E,0xB0FE},{0x868F,0xB0FF},{0x8690,0xB100},{0x8691,0xB101},{0x8692,0xB102},{0x8693,0xB103},{0x8694,0xB104},{0x8695,0xB105},{0x8696,0xB106},{0x8697,0xB107},{0xB3CA,0xB108},{0xB3CB,0xB109},{0x8698,0xB10A},{0xB3CC,0xB10B},{0xB3CD,0xB10C},{0x8699,0xB10D},{0x869A,0xB10E},{0x869B,0xB10F},{0xB3CE,0xB110},{0x869C,0xB111},{0xB3CF,0xB112},{0xB3D0,0xB113},{0x869D,0xB114},{0x869E,0xB115},{0x869F,0xB116},{0x86A0,0xB117},{0xB3D1,0xB118},{0xB3D2,0xB119},{0x86A1,0xB11A},{0xB3D3,0xB11B},{0xB3D4,0xB11C},{0xB3D5,0xB11D},{0x86A2,0xB11E},{0x86A3,0xB11F},{0x86A4,0xB120},{0x86A5,0xB121},{0x86A6,0xB122},{0xB3D6,0xB123},{0xB3D7,0xB124},{0xB3D8,0xB125},{0x86A7,0xB126},{0x86A8,0xB127},{0xB3D9,0xB128},{0x86A9,0xB129},{0x86AA,0xB12A},{0x86AB,0xB12B},{0xB3DA,0xB12C},{0x86AC,0xB12D},{0x86AD,0xB12E},{0x86AE,0xB12F},{0x86AF,0xB130},{0x86B0,0xB131},{0x86B1,0xB132},{0x86B2,0xB133},{0xB3DB,0xB134},{0xB3DC,0xB135},{0x86B3,0xB136},{0xB3DD,0xB137},{0xB3DE,0xB138},{0xB3DF,0xB139},{0x86B4,0xB13A},{0x86B5,0xB13B},{0x86B6,0xB13C},{0x86B7,0xB13D},{0x86B8,0xB13E},{0x86B9,0xB13F},{0xB3E0,0xB140},{0xB3E1,0xB141},{0x86BA,0xB142},{0x86BB,0xB143},{0xB3E2,0xB144},{0x86BC,0xB145},{0x86BD,0xB146},{0x86BE,0xB147},{0xB3E3,0xB148},{0x86BF,0xB149},{0x86C0,0xB14A},{0x86C1,0xB14B},{0x86C2,0xB14C},{0x86C3,0xB14D},{0x86C4,0xB14E},{0x86C5,0xB14F},{0xB3E4,0xB150},{0xB3E5,0xB151},{0x86C6,0xB152},{0x86C7,0xB153},{0xB3E6,0xB154},{0xB3E7,0xB155},{0x86C8,0xB156},{0x86C9,0xB157},{0xB3E8,0xB158},{0x86CA,0xB159},{0x86CB,0xB15A},{0x86CC,0xB15B},{0xB3E9,0xB15C},{0x86CD,0xB15D},{0x86CE,0xB15E},{0x86CF,0xB15F},{0xB3EA,0xB160},{0x86D0,0xB161},{0x86D1,0xB162},{0x86D2,0xB163},{0x86D3,0xB164},{0x86D4,0xB165},{0x86D5,0xB166},{0x86D6,0xB167},{0x86D7,0xB168},{0x86D8,0xB169},{0x86D9,0xB16A},{0x86DA,0xB16B},{0x86DB,0xB16C},{0x86DC,0xB16D},{0x86DD,0xB16E},{0x86DE,0xB16F},{0x86DF,0xB170},{0x86E0,0xB171},{0x86E1,0xB172},{0x86E2,0xB173},{0x86E3,0xB174},{0x86E4,0xB175},{0x86E5,0xB176},{0x86E6,0xB177},{0xB3EB,0xB178},{0xB3EC,0xB179},{0x86E7,0xB17A},{0x86E8,0xB17B},{0xB3ED,0xB17C},{0x86E9,0xB17D},{0x86EA,0xB17E},{0x86EB,0xB17F},{0xB3EE,0xB180},{0x86EC,0xB181},{0xB3EF,0xB182},{0x86ED,0xB183},{0x86EE,0xB184},{0x86EF,0xB185},{0x86F0,0xB186},{0x86F1,0xB187},{0xB3F0,0xB188},{0xB3F1,0xB189},{0x86F2,0xB18A},{0xB3F2,0xB18B},{0x86F3,0xB18C},{0xB3F3,0xB18D},{0x86F4,0xB18E},{0x86F5,0xB18F},{0x86F6,0xB190},{0x86F7,0xB191},{0xB3F4,0xB192},{0xB3F5,0xB193},{0xB3F6,0xB194},{0x86F8,0xB195},{0x86F9,0xB196},{0x86FA,0xB197},{0xB3F7,0xB198},{0x86FB,0xB199},{0x86FC,0xB19A},{0x86FD,0xB19B},{0xB3F8,0xB19C},{0x86FE,0xB19D},{0x8741,0xB19E},{0x8742,0xB19F},{0x8743,0xB1A0},{0x8744,0xB1A1},{0x8745,0xB1A2},{0x8746,0xB1A3},{0x8747,0xB1A4},{0x8748,0xB1A5},{0x8749,0xB1A6},{0x874A,0xB1A7},{0xB3F9,0xB1A8},{0x874B,0xB1A9},{0x874C,0xB1AA},{0x874D,0xB1AB},{0x874E,0xB1AC},{0x874F,0xB1AD},{0x8750,0xB1AE},{0x8751,0xB1AF},{0x8752,0xB1B0},{0x8753,0xB1B1},{0x8754,0xB1B2},{0x8755,0xB1B3},{0x8756,0xB1B4},{0x8757,0xB1B5},{0x8758,0xB1B6},{0x8759,0xB1B7},{0x875A,0xB1B8},{0x8761,0xB1B9},{0x8762,0xB1BA},{0x8763,0xB1BB},{0x8764,0xB1BC},{0x8765,0xB1BD},{0x8766,0xB1BE},{0x8767,0xB1BF},{0x8768,0xB1C0},{0x8769,0xB1C1},{0x876A,0xB1C2},{0x876B,0xB1C3},{0x876C,0xB1C4},{0x876D,0xB1C5},{0x876E,0xB1C6},{0x876F,0xB1C7},{0x8770,0xB1C8},{0x8771,0xB1C9},
{0x8772,0xB1CA},{0x8773,0xB1CB},{0xB3FA,0xB1CC},{0x8774,0xB1CD},{0x8775,0xB1CE},{0x8776,0xB1CF},{0xB3FB,0xB1D0},{0x8777,0xB1D1},{0x8778,0xB1D2},{0x8779,0xB1D3},{0xB3FC,0xB1D4},{0x877A,0xB1D5},{0x8781,0xB1D6},{0x8782,0xB1D7},{0x8783,0xB1D8},{0x8784,0xB1D9},{0x8785,0xB1DA},{0x8786,0xB1DB},{0xB3FD,0xB1DC},{0xB3FE,0xB1DD},{0x8787,0xB1DE},{0xB4A1,0xB1DF},{0x8788,0xB1E0},{0x8789,0xB1E1},{0x878A,0xB1E2},{0x878B,0xB1E3},{0x878C,0xB1E4},{0x878D,0xB1E5},{0x878E,0xB1E6},{0x878F,0xB1E7},{0xB4A2,0xB1E8},{0xB4A3,0xB1E9},{0x8790,0xB1EA},{0x8791,0xB1EB},{0xB4A4,0xB1EC},{0x8792,0xB1ED},{0x8793,0xB1EE},{0x8794,0xB1EF},{0xB4A5,0xB1F0},{0x8795,0xB1F1},{0x8796,0xB1F2},{0x8797,0xB1F3},{0x8798,0xB1F4},{0x8799,0xB1F5},{0x879A,0xB1F6},{0x879B,0xB1F7},{0x879C,0xB1F8},{0xB4A6,0xB1F9},{0x879D,0xB1FA},{0xB4A7,0xB1FB},{0x879E,0xB1FC},{0xB4A8,0xB1FD},{0x879F,0xB1FE},{0x87A0,0xB1FF},{0x87A1,0xB200},{0x87A2,0xB201},{0x87A3,0xB202},{0x87A4,0xB203},{0xB4A9,0xB204},{0xB4AA,0xB205},{0x87A5,0xB206},{0x87A6,0xB207},{0xB4AB,0xB208},{0x87A7,0xB209},{0x87A8,0xB20A},{0xB4AC,0xB20B},{0xB4AD,0xB20C},{0x87A9,0xB20D},{0x87AA,0xB20E},{0x87AB,0xB20F},{0x87AC,0xB210},{0x87AD,0xB211},{0x87AE,0xB212},{0x87AF,0xB213},{0xB4AE,0xB214},{0xB4AF,0xB215},{0x87B0,0xB216},{0xB4B0,0xB217},{0x87B1,0xB218},{0xB4B1,0xB219},{0x87B2,0xB21A},{0x87B3,0xB21B},{0x87B4,0xB21C},{0x87B5,0xB21D},{0x87B6,0xB21E},{0x87B7,0xB21F},{0xB4B2,0xB220},{0x87B8,0xB221},{0x87B9,0xB222},{0x87BA,0xB223},{0x87BB,0xB224},{0x87BC,0xB225},{0x87BD,0xB226},{0x87BE,0xB227},{0x87BF,0xB228},{0x87C0,0xB229},{0x87C1,0xB22A},{0x87C2,0xB22B},{0x87C3,0xB22C},{0x87C4,0xB22D},{0x87C5,0xB22E},{0x87C6,0xB22F},{0x87C7,0xB230},{0x87C8,0xB231},{0x87C9,0xB232},{0x87CA,0xB233},{0xB4B3,0xB234},{0x87CB,0xB235},{0x87CC,0xB236},{0x87CD,0xB237},{0x87CE,0xB238},{0x87CF,0xB239},{0x87D0,0xB23A},{0x87D1,0xB23B},{0xB4B4,0xB23C},{0x87D2,0xB23D},{0x87D3,0xB23E},{0x87D4,0xB23F},{0x87D5,0xB240},{0x87D6,0xB241},{0x87D7,0xB242},{0x87D8,0xB243},{0x87D9,0xB244},{0x87DA,0xB245},{0x87DB,0xB246},{0x87DC,0xB247},{0x87DD,0xB248},{0x87DE,0xB249},{0x87DF,0xB24A},{0x87E0,0xB24B},{0x87E1,0xB24C},{0x87E2,0xB24D},{0x87E3,0xB24E},{0x87E4,0xB24F},{0x87E5,0xB250},{0x87E6,0xB251},{0x87E7,0xB252},{0x87E8,0xB253},{0x87E9,0xB254},{0x87EA,0xB255},{0x87EB,0xB256},{0x87EC,0xB257},{0xB4B5,0xB258},{0x87ED,0xB259},{0x87EE,0xB25A},{0x87EF,0xB25B},{0xB4B6,0xB25C},{0x87F0,0xB25D},{0x87F1,0xB25E},{0x87F2,0xB25F},{0xB4B7,0xB260},{0x87F3,0xB261},{0x87F4,0xB262},{0x87F5,0xB263},{0x87F6,0xB264},{0x87F7,0xB265},{0x87F8,0xB266},{0x87F9,0xB267},{0xB4B8,0xB268},{0xB4B9,0xB269},{0x87FA,0xB26A},{0x87FB,0xB26B},{0x87FC,0xB26C},{0x87FD,0xB26D},{0x87FE,0xB26E},{0x8841,0xB26F},{0x8842,0xB270},{0x8843,0xB271},{0x8844,0xB272},{0x8845,0xB273},{0xB4BA,0xB274},{0xB4BB,0xB275},{0x8846,0xB276},{0x8847,0xB277},{0x8848,0xB278},{0x8849,0xB279},{0x884A,0xB27A},{0x884B,0xB27B},{0xB4BC,0xB27C},{0x884C,0xB27D},{0x884D,0xB27E},{0x884E,0xB27F},{0x884F,0xB280},{0x8850,0xB281},{0x8851,0xB282},{0x8852,0xB283},{0xB4BD,0xB284},{0xB4BE,0xB285},{0x8853,0xB286},{0x8854,0xB287},{0x8855,0xB288},{0xB4BF,0xB289},{0x8856,0xB28A},{0x8857,0xB28B},{0x8858,0xB28C},{0x8859,0xB28D},{0x885A,0xB28E},{0x8861,0xB28F},{0xB4C0,0xB290},{0xB4C1,0xB291},{0x8862,0xB292},{0x8863,0xB293},{0xB4C2,0xB294},{0x8864,0xB295},{0x8865,0xB296},{0x8866,0xB297},{0xB4C3,0xB298},{0xB4C4,0xB299},{0xB4C5,0xB29A},{0x8867,0xB29B},{0x8868,0xB29C},{0x8869,0xB29D},{0x886A,0xB29E},{0x886B,0xB29F},{0xB4C6,0xB2A0},{0xB4C7,0xB2A1},{0x886C,0xB2A2},{0xB4C8,0xB2A3},{0x886D,0xB2A4},{0xB4C9,0xB2A5},{0xB4CA,0xB2A6},{0x886E,0xB2A7},{0x886F,0xB2A8},{0x8870,0xB2A9},{0xB4CB,0xB2AA},{0x8871,0xB2AB},{0xB4CC,0xB2AC},{0x8872,0xB2AD},{0x8873,0xB2AE},{0x8874,0xB2AF},{0xB4CD,0xB2B0},{0x8875,0xB2B1},{0x8876,0xB2B2},{0x8877,0xB2B3},{0xB4CE,0xB2B4},{0x8878,0xB2B5},{0x8879,0xB2B6},{0x887A,0xB2B7},{0x8881,0xB2B8},{0x8882,0xB2B9},{0x8883,0xB2BA},{0x8884,0xB2BB},{0x8885,0xB2BC},{0x8886,0xB2BD},{0x8887,0xB2BE},{0x8888,0xB2BF},{0x8889,0xB2C0},
{0x888A,0xB2C1},{0x888B,0xB2C2},{0x888C,0xB2C3},{0x888D,0xB2C4},{0x888E,0xB2C5},{0x888F,0xB2C6},{0x8890,0xB2C7},{0xB4CF,0xB2C8},{0xB4D0,0xB2C9},{0x8891,0xB2CA},{0x8892,0xB2CB},{0xB4D1,0xB2CC},{0x8893,0xB2CD},{0x8894,0xB2CE},{0x8895,0xB2CF},{0xB4D2,0xB2D0},{0x8896,0xB2D1},{0xB4D3,0xB2D2},{0x8897,0xB2D3},{0x8898,0xB2D4},{0x8899,0xB2D5},{0x889A,0xB2D6},{0x889B,0xB2D7},{0xB4D4,0xB2D8},{0xB4D5,0xB2D9},{0x889C,0xB2DA},{0xB4D6,0xB2DB},{0x889D,0xB2DC},{0xB4D7,0xB2DD},{0x889E,0xB2DE},{0x889F,0xB2DF},{0x88A0,0xB2E0},{0x88A1,0xB2E1},{0xB4D8,0xB2E2},{0x88A2,0xB2E3},{0xB4D9,0xB2E4},{0xB4DA,0xB2E5},{0xB4DB,0xB2E6},{0x88A3,0xB2E7},{0xB4DC,0xB2E8},{0x88A4,0xB2E9},{0x88A5,0xB2EA},{0xB4DD,0xB2EB},{0xB4DE,0xB2EC},{0xB4DF,0xB2ED},{0xB4E0,0xB2EE},{0xB4E1,0xB2EF},{0x88A6,0xB2F0},{0x88A7,0xB2F1},{0x88A8,0xB2F2},{0xB4E2,0xB2F3},{0xB4E3,0xB2F4},{0xB4E4,0xB2F5},{0x88A9,0xB2F6},{0xB4E5,0xB2F7},{0xB4E6,0xB2F8},{0xB4E7,0xB2F9},{0xB4E8,0xB2FA},{0xB4E9,0xB2FB},{0x88AA,0xB2FC},{0x88AB,0xB2FD},{0x88AC,0xB2FE},{0xB4EA,0xB2FF},{0xB4EB,0xB300},{0xB4EC,0xB301},{0x88AD,0xB302},{0x88AE,0xB303},{0xB4ED,0xB304},{0x88AF,0xB305},{0x88B0,0xB306},{0x88B1,0xB307},{0xB4EE,0xB308},{0x88B2,0xB309},{0x88B3,0xB30A},{0x88B4,0xB30B},{0x88B5,0xB30C},{0x88B6,0xB30D},{0x88B7,0xB30E},{0x88B8,0xB30F},{0xB4EF,0xB310},{0xB4F0,0xB311},{0x88B9,0xB312},{0xB4F1,0xB313},{0xB4F2,0xB314},{0xB4F3,0xB315},{0x88BA,0xB316},{0x88BB,0xB317},{0x88BC,0xB318},{0x88BD,0xB319},{0x88BE,0xB31A},{0x88BF,0xB31B},{0xB4F4,0xB31C},{0x88C0,0xB31D},{0x88C1,0xB31E},{0x88C2,0xB31F},{0x88C3,0xB320},{0x88C4,0xB321},{0x88C5,0xB322},{0x88C6,0xB323},{0x88C7,0xB324},{0x88C8,0xB325},{0x88C9,0xB326},{0x88CA,0xB327},{0x88CB,0xB328},{0x88CC,0xB329},{0x88CD,0xB32A},{0x88CE,0xB32B},{0x88CF,0xB32C},{0x88D0,0xB32D},{0x88D1,0xB32E},{0x88D2,0xB32F},{0x88D3,0xB330},{0x88D4,0xB331},{0x88D5,0xB332},{0x88D6,0xB333},{0x88D7,0xB334},{0x88D8,0xB335},{0x88D9,0xB336},{0x88DA,0xB337},{0x88DB,0xB338},{0x88DC,0xB339},{0x88DD,0xB33A},{0x88DE,0xB33B},{0x88DF,0xB33C},{0x88E0,0xB33D},{0x88E1,0xB33E},{0x88E2,0xB33F},{0x88E3,0xB340},{0x88E4,0xB341},{0x88E5,0xB342},{0x88E6,0xB343},{0x88E7,0xB344},{0x88E8,0xB345},{0x88E9,0xB346},{0x88EA,0xB347},{0x88EB,0xB348},{0x88EC,0xB349},{0x88ED,0xB34A},{0x88EE,0xB34B},{0x88EF,0xB34C},{0x88F0,0xB34D},{0x88F1,0xB34E},{0x88F2,0xB34F},{0x88F3,0xB350},{0x88F4,0xB351},{0x88F5,0xB352},{0x88F6,0xB353},{0xB4F5,0xB354},{0xB4F6,0xB355},{0xB4F7,0xB356},{0x88F7,0xB357},{0xB4F8,0xB358},{0x88F8,0xB359},{0x88F9,0xB35A},{0xB4F9,0xB35B},{0xB4FA,0xB35C},{0x88FA,0xB35D},{0xB4FB,0xB35E},{0xB4FC,0xB35F},{0x88FB,0xB360},{0x88FC,0xB361},{0x88FD,0xB362},{0x88FE,0xB363},{0xB4FD,0xB364},{0xB4FE,0xB365},{0x8941,0xB366},{0xB5A1,0xB367},{0x8942,0xB368},{0xB5A2,0xB369},{0x8943,0xB36A},{0xB5A3,0xB36B},{0x8944,0xB36C},{0x8945,0xB36D},{0xB5A4,0xB36E},{0x8946,0xB36F},{0xB5A5,0xB370},{0xB5A6,0xB371},{0x8947,0xB372},{0x8948,0xB373},{0xB5A7,0xB374},{0x8949,0xB375},{0x894A,0xB376},{0x894B,0xB377},{0xB5A8,0xB378},{0x894C,0xB379},{0x894D,0xB37A},{0x894E,0xB37B},{0x894F,0xB37C},{0x8950,0xB37D},{0x8951,0xB37E},{0x8952,0xB37F},{0xB5A9,0xB380},{0xB5AA,0xB381},{0x8953,0xB382},{0xB5AB,0xB383},{0xB5AC,0xB384},{0xB5AD,0xB385},{0x8954,0xB386},{0x8955,0xB387},{0x8956,0xB388},{0x8957,0xB389},{0x8958,0xB38A},{0x8959,0xB38B},{0xB5AE,0xB38C},{0x895A,0xB38D},{0x8961,0xB38E},{0x8962,0xB38F},{0xB5AF,0xB390},{0x8963,0xB391},{0x8964,0xB392},{0x8965,0xB393},{0xB5B0,0xB394},{0x8966,0xB395},{0x8967,0xB396},{0x8968,0xB397},{0x8969,0xB398},{0x896A,0xB399},{0x896B,0xB39A},{0x896C,0xB39B},{0x896D,0xB39C},{0x896E,0xB39D},{0x896F,0xB39E},{0x8970,0xB39F},{0xB5B1,0xB3A0},{0xB5B2,0xB3A1},{0x8971,0xB3A2},{0x8972,0xB3A3},{0x8973,0xB3A4},{0x8974,0xB3A5},{0x8975,0xB3A6},{0x8976,0xB3A7},{0xB5B3,0xB3A8},{0x8977,0xB3A9},{0x8978,0xB3AA},{0x8979,0xB3AB},{0xB5B4,0xB3AC},{0x897A,0xB3AD},{0x8981,0xB3AE},{0x8982,0xB3AF},{0x8983,0xB3B0},{0x8984,0xB3B1},{0x8985,0xB3B2},{0x8986,0xB3B3},{0x8987,0xB3B4},{0x8988,0xB3B5},{0x8989,0xB3B6},{0x898A,0xB3B7},
{0x898B,0xB3B8},{0x898C,0xB3B9},{0x898D,0xB3BA},{0x898E,0xB3BB},{0x898F,0xB3BC},{0x8990,0xB3BD},{0x8991,0xB3BE},{0x8992,0xB3BF},{0x8993,0xB3C0},{0x8994,0xB3C1},{0x8995,0xB3C2},{0x8996,0xB3C3},{0xB5B5,0xB3C4},{0xB5B6,0xB3C5},{0x8997,0xB3C6},{0x8998,0xB3C7},{0xB5B7,0xB3C8},{0x8999,0xB3C9},{0x899A,0xB3CA},{0xB5B8,0xB3CB},{0xB5B9,0xB3CC},{0x899B,0xB3CD},{0xB5BA,0xB3CE},{0x899C,0xB3CF},{0xB5BB,0xB3D0},{0x899D,0xB3D1},{0x899E,0xB3D2},{0x899F,0xB3D3},{0xB5BC,0xB3D4},{0xB5BD,0xB3D5},{0x89A0,0xB3D6},{0xB5BE,0xB3D7},{0x89A1,0xB3D8},{0xB5BF,0xB3D9},{0x89A2,0xB3DA},{0xB5C0,0xB3DB},{0x89A3,0xB3DC},{0xB5C1,0xB3DD},{0x89A4,0xB3DE},{0x89A5,0xB3DF},{0xB5C2,0xB3E0},{0x89A6,0xB3E1},{0x89A7,0xB3E2},{0x89A8,0xB3E3},{0xB5C3,0xB3E4},{0x89A9,0xB3E5},{0x89AA,0xB3E6},{0x89AB,0xB3E7},{0xB5C4,0xB3E8},{0x89AC,0xB3E9},{0x89AD,0xB3EA},{0x89AE,0xB3EB},{0x89AF,0xB3EC},{0x89B0,0xB3ED},{0x89B1,0xB3EE},{0x89B2,0xB3EF},{0x89B3,0xB3F0},{0x89B4,0xB3F1},{0x89B5,0xB3F2},{0x89B6,0xB3F3},{0x89B7,0xB3F4},{0x89B8,0xB3F5},{0x89B9,0xB3F6},{0x89BA,0xB3F7},{0x89BB,0xB3F8},{0x89BC,0xB3F9},{0x89BD,0xB3FA},{0x89BE,0xB3FB},{0xB5C5,0xB3FC},{0x89BF,0xB3FD},{0x89C0,0xB3FE},{0x89C1,0xB3FF},{0x89C2,0xB400},{0x89C3,0xB401},{0x89C4,0xB402},{0x89C5,0xB403},{0x89C6,0xB404},{0x89C7,0xB405},{0x89C8,0xB406},{0x89C9,0xB407},{0x89CA,0xB408},{0x89CB,0xB409},{0x89CC,0xB40A},{0x89CD,0xB40B},{0x89CE,0xB40C},{0x89CF,0xB40D},{0x89D0,0xB40E},{0x89D1,0xB40F},{0xB5C6,0xB410},{0x89D2,0xB411},{0x89D3,0xB412},{0x89D4,0xB413},{0x89D5,0xB414},{0x89D6,0xB415},{0x89D7,0xB416},{0x89D8,0xB417},{0xB5C7,0xB418},{0x89D9,0xB419},{0x89DA,0xB41A},{0x89DB,0xB41B},{0xB5C8,0xB41C},{0x89DC,0xB41D},{0x89DD,0xB41E},{0x89DE,0xB41F},{0xB5C9,0xB420},{0x89DF,0xB421},{0x89E0,0xB422},{0x89E1,0xB423},{0x89E2,0xB424},{0x89E3,0xB425},{0x89E4,0xB426},{0x89E5,0xB427},{0xB5CA,0xB428},{0xB5CB,0xB429},{0x89E6,0xB42A},{0xB5CC,0xB42B},{0x89E7,0xB42C},{0x89E8,0xB42D},{0x89E9,0xB42E},{0x89EA,0xB42F},{0x89EB,0xB430},{0x89EC,0xB431},{0x89ED,0xB432},{0x89EE,0xB433},{0xB5CD,0xB434},{0x89EF,0xB435},{0x89F0,0xB436},{0x89F1,0xB437},{0x89F2,0xB438},{0x89F3,0xB439},{0x89F4,0xB43A},{0x89F5,0xB43B},{0x89F6,0xB43C},{0x89F7,0xB43D},{0x89F8,0xB43E},{0x89F9,0xB43F},{0x89FA,0xB440},{0x89FB,0xB441},{0x89FC,0xB442},{0x89FD,0xB443},{0x89FE,0xB444},{0x8A41,0xB445},{0x8A42,0xB446},{0x8A43,0xB447},{0x8A44,0xB448},{0x8A45,0xB449},{0x8A46,0xB44A},{0x8A47,0xB44B},{0x8A48,0xB44C},{0x8A49,0xB44D},{0x8A4A,0xB44E},{0x8A4B,0xB44F},{0xB5CE,0xB450},{0xB5CF,0xB451},{0x8A4C,0xB452},{0x8A4D,0xB453},{0xB5D0,0xB454},{0x8A4E,0xB455},{0x8A4F,0xB456},{0x8A50,0xB457},{0xB5D1,0xB458},{0x8A51,0xB459},{0x8A52,0xB45A},{0x8A53,0xB45B},{0x8A54,0xB45C},{0x8A55,0xB45D},{0x8A56,0xB45E},{0x8A57,0xB45F},{0xB5D2,0xB460},{0xB5D3,0xB461},{0x8A58,0xB462},{0xB5D4,0xB463},{0x8A59,0xB464},{0xB5D5,0xB465},{0x8A5A,0xB466},{0x8A61,0xB467},{0x8A62,0xB468},{0x8A63,0xB469},{0x8A64,0xB46A},{0x8A65,0xB46B},{0xB5D6,0xB46C},{0x8A66,0xB46D},{0x8A67,0xB46E},{0x8A68,0xB46F},{0x8A69,0xB470},{0x8A6A,0xB471},{0x8A6B,0xB472},{0x8A6C,0xB473},{0x8A6D,0xB474},{0x8A6E,0xB475},{0x8A6F,0xB476},{0x8A70,0xB477},{0x8A71,0xB478},{0x8A72,0xB479},{0x8A73,0xB47A},{0x8A74,0xB47B},{0x8A75,0xB47C},{0x8A76,0xB47D},{0x8A77,0xB47E},{0x8A78,0xB47F},{0xB5D7,0xB480},{0x8A79,0xB481},{0x8A7A,0xB482},{0x8A81,0xB483},{0x8A82,0xB484},{0x8A83,0xB485},{0x8A84,0xB486},{0x8A85,0xB487},{0xB5D8,0xB488},{0x8A86,0xB489},{0x8A87,0xB48A},{0x8A88,0xB48B},{0x8A89,0xB48C},{0x8A8A,0xB48D},{0x8A8B,0xB48E},{0x8A8C,0xB48F},{0x8A8D,0xB490},{0x8A8E,0xB491},{0x8A8F,0xB492},{0x8A90,0xB493},{0x8A91,0xB494},{0x8A92,0xB495},{0x8A93,0xB496},{0x8A94,0xB497},{0x8A95,0xB498},{0x8A96,0xB499},{0x8A97,0xB49A},{0x8A98,0xB49B},{0x8A99,0xB49C},{0xB5D9,0xB49D},{0x8A9A,0xB49E},{0x8A9B,0xB49F},{0x8A9C,0xB4A0},{0x8A9D,0xB4A1},{0x8A9E,0xB4A2},{0x8A9F,0xB4A3},{0xB5DA,0xB4A4},{0x8AA0,0xB4A5},{0x8AA1,0xB4A6},{0x8AA2,0xB4A7},{0xB5DB,0xB4A8},{0x8AA3,0xB4A9},{0x8AA4,0xB4AA},{0x8AA5,0xB4AB},{0xB5DC,0xB4AC},{0x8AA6,0xB4AD},{0x8AA7,0xB4AE},
{0x8AA8,0xB4AF},{0x8AA9,0xB4B0},{0x8AAA,0xB4B1},{0x8AAB,0xB4B2},{0x8AAC,0xB4B3},{0x8AAD,0xB4B4},{0xB5DD,0xB4B5},{0x8AAE,0xB4B6},{0xB5DE,0xB4B7},{0x8AAF,0xB4B8},{0xB5DF,0xB4B9},{0x8AB0,0xB4BA},{0x8AB1,0xB4BB},{0x8AB2,0xB4BC},{0x8AB3,0xB4BD},{0x8AB4,0xB4BE},{0x8AB5,0xB4BF},{0xB5E0,0xB4C0},{0x8AB6,0xB4C1},{0x8AB7,0xB4C2},{0x8AB8,0xB4C3},{0xB5E1,0xB4C4},{0x8AB9,0xB4C5},{0x8ABA,0xB4C6},{0x8ABB,0xB4C7},{0xB5E2,0xB4C8},{0x8ABC,0xB4C9},{0x8ABD,0xB4CA},{0x8ABE,0xB4CB},{0x8ABF,0xB4CC},{0x8AC0,0xB4CD},{0x8AC1,0xB4CE},{0x8AC2,0xB4CF},{0xB5E3,0xB4D0},{0x8AC3,0xB4D1},{0x8AC4,0xB4D2},{0x8AC5,0xB4D3},{0x8AC6,0xB4D4},{0xB5E4,0xB4D5},{0x8AC7,0xB4D6},{0x8AC8,0xB4D7},{0x8AC9,0xB4D8},{0x8ACA,0xB4D9},{0x8ACB,0xB4DA},{0x8ACC,0xB4DB},{0xB5E5,0xB4DC},{0xB5E6,0xB4DD},{0x8ACD,0xB4DE},{0x8ACE,0xB4DF},{0xB5E7,0xB4E0},{0x8ACF,0xB4E1},{0x8AD0,0xB4E2},{0xB5E8,0xB4E3},{0xB5E9,0xB4E4},{0x8AD1,0xB4E5},{0xB5EA,0xB4E6},{0x8AD2,0xB4E7},{0x8AD3,0xB4E8},{0x8AD4,0xB4E9},{0x8AD5,0xB4EA},{0x8AD6,0xB4EB},{0xB5EB,0xB4EC},{0xB5EC,0xB4ED},{0x8AD7,0xB4EE},{0xB5ED,0xB4EF},{0x8AD8,0xB4F0},{0xB5EE,0xB4F1},{0x8AD9,0xB4F2},{0x8ADA,0xB4F3},{0x8ADB,0xB4F4},{0x8ADC,0xB4F5},{0x8ADD,0xB4F6},{0x8ADE,0xB4F7},{0xB5EF,0xB4F8},{0x8ADF,0xB4F9},{0x8AE0,0xB4FA},{0x8AE1,0xB4FB},{0x8AE2,0xB4FC},{0x8AE3,0xB4FD},{0x8AE4,0xB4FE},{0x8AE5,0xB4FF},{0x8AE6,0xB500},{0x8AE7,0xB501},{0x8AE8,0xB502},{0x8AE9,0xB503},{0x8AEA,0xB504},{0x8AEB,0xB505},{0x8AEC,0xB506},{0x8AED,0xB507},{0x8AEE,0xB508},{0x8AEF,0xB509},{0x8AF0,0xB50A},{0x8AF1,0xB50B},{0x8AF2,0xB50C},{0x8AF3,0xB50D},{0x8AF4,0xB50E},{0x8AF5,0xB50F},{0x8AF6,0xB510},{0x8AF7,0xB511},{0x8AF8,0xB512},{0x8AF9,0xB513},{0xB5F0,0xB514},{0xB5F1,0xB515},{0x8AFA,0xB516},{0x8AFB,0xB517},{0xB5F2,0xB518},{0x8AFC,0xB519},{0x8AFD,0xB51A},{0xB5F3,0xB51B},{0xB5F4,0xB51C},{0x8AFE,0xB51D},{0x8B41,0xB51E},{0x8B42,0xB51F},{0x8B43,0xB520},{0x8B44,0xB521},{0x8B45,0xB522},{0x8B46,0xB523},{0xB5F5,0xB524},{0xB5F6,0xB525},{0x8B47,0xB526},{0xB5F7,0xB527},{0xB5F8,0xB528},{0xB5F9,0xB529},{0xB5FA,0xB52A},{0x8B48,0xB52B},{0x8B49,0xB52C},{0x8B4A,0xB52D},{0x8B4B,0xB52E},{0x8B4C,0xB52F},{0xB5FB,0xB530},{0xB5FC,0xB531},{0x8B4D,0xB532},{0x8B4E,0xB533},{0xB5FD,0xB534},{0x8B4F,0xB535},{0x8B50,0xB536},{0x8B51,0xB537},{0xB5FE,0xB538},{0x8B52,0xB539},{0x8B53,0xB53A},{0x8B54,0xB53B},{0x8B55,0xB53C},{0x8B56,0xB53D},{0x8B57,0xB53E},{0x8B58,0xB53F},{0xB6A1,0xB540},{0xB6A2,0xB541},{0x8B59,0xB542},{0xB6A3,0xB543},{0xB6A4,0xB544},{0xB6A5,0xB545},{0x8B5A,0xB546},{0x8B61,0xB547},{0x8B62,0xB548},{0x8B63,0xB549},{0x8B64,0xB54A},{0xB6A6,0xB54B},{0xB6A7,0xB54C},{0xB6A8,0xB54D},{0x8B65,0xB54E},{0x8B66,0xB54F},{0xB6A9,0xB550},{0x8B67,0xB551},{0x8B68,0xB552},{0x8B69,0xB553},{0xB6AA,0xB554},{0x8B6A,0xB555},{0x8B6B,0xB556},{0x8B6C,0xB557},{0x8B6D,0xB558},{0x8B6E,0xB559},{0x8B6F,0xB55A},{0x8B70,0xB55B},{0xB6AB,0xB55C},{0xB6AC,0xB55D},{0x8B71,0xB55E},{0xB6AD,0xB55F},{0xB6AE,0xB560},{0xB6AF,0xB561},{0x8B72,0xB562},{0x8B73,0xB563},{0x8B74,0xB564},{0x8B75,0xB565},{0x8B76,0xB566},{0x8B77,0xB567},{0x8B78,0xB568},{0x8B79,0xB569},{0x8B7A,0xB56A},{0x8B81,0xB56B},{0x8B82,0xB56C},{0x8B83,0xB56D},{0x8B84,0xB56E},{0x8B85,0xB56F},{0x8B86,0xB570},{0x8B87,0xB571},{0x8B88,0xB572},{0x8B89,0xB573},{0x8B8A,0xB574},{0x8B8B,0xB575},{0x8B8C,0xB576},{0x8B8D,0xB577},{0x8B8E,0xB578},{0x8B8F,0xB579},{0x8B90,0xB57A},{0x8B91,0xB57B},{0x8B92,0xB57C},{0x8B93,0xB57D},{0x8B94,0xB57E},{0x8B95,0xB57F},{0x8B96,0xB580},{0x8B97,0xB581},{0x8B98,0xB582},{0x8B99,0xB583},{0x8B9A,0xB584},{0x8B9B,0xB585},{0x8B9C,0xB586},{0x8B9D,0xB587},{0x8B9E,0xB588},{0x8B9F,0xB589},{0x8BA0,0xB58A},{0x8BA1,0xB58B},{0x8BA2,0xB58C},{0x8BA3,0xB58D},{0x8BA4,0xB58E},{0x8BA5,0xB58F},{0x8BA6,0xB590},{0x8BA7,0xB591},{0x8BA8,0xB592},{0x8BA9,0xB593},{0x8BAA,0xB594},{0x8BAB,0xB595},{0x8BAC,0xB596},{0x8BAD,0xB597},{0x8BAE,0xB598},{0x8BAF,0xB599},{0x8BB0,0xB59A},{0x8BB1,0xB59B},{0x8BB2,0xB59C},{0x8BB3,0xB59D},{0x8BB4,0xB59E},{0x8BB5,0xB59F},{0xB6B0,0xB5A0},{0xB6B1,0xB5A1},{0x8BB6,0xB5A2},{0x8BB7,0xB5A3},{0xB6B2,0xB5A4},{0x8BB8,0xB5A5},
{0x8BB9,0xB5A6},{0x8BBA,0xB5A7},{0xB6B3,0xB5A8},{0x8BBB,0xB5A9},{0xB6B4,0xB5AA},{0xB6B5,0xB5AB},{0x8BBC,0xB5AC},{0x8BBD,0xB5AD},{0x8BBE,0xB5AE},{0x8BBF,0xB5AF},{0xB6B6,0xB5B0},{0xB6B7,0xB5B1},{0x8BC0,0xB5B2},{0xB6B8,0xB5B3},{0xB6B9,0xB5B4},{0xB6BA,0xB5B5},{0x8BC1,0xB5B6},{0x8BC2,0xB5B7},{0x8BC3,0xB5B8},{0x8BC4,0xB5B9},{0x8BC5,0xB5BA},{0xB6BB,0xB5BB},{0xB6BC,0xB5BC},{0xB6BD,0xB5BD},{0x8BC6,0xB5BE},{0x8BC7,0xB5BF},{0xB6BE,0xB5C0},{0x8BC8,0xB5C1},{0x8BC9,0xB5C2},{0x8BCA,0xB5C3},{0xB6BF,0xB5C4},{0x8BCB,0xB5C5},{0x8BCC,0xB5C6},{0x8BCD,0xB5C7},{0x8BCE,0xB5C8},{0x8BCF,0xB5C9},{0x8BD0,0xB5CA},{0x8BD1,0xB5CB},{0xB6C0,0xB5CC},{0xB6C1,0xB5CD},{0x8BD2,0xB5CE},{0xB6C2,0xB5CF},{0xB6C3,0xB5D0},{0xB6C4,0xB5D1},{0x8BD3,0xB5D2},{0x8BD4,0xB5D3},{0x8BD5,0xB5D4},{0x8BD6,0xB5D5},{0x8BD7,0xB5D6},{0x8BD8,0xB5D7},{0xB6C5,0xB5D8},{0x8BD9,0xB5D9},{0x8BDA,0xB5DA},{0x8BDB,0xB5DB},{0x8BDC,0xB5DC},{0x8BDD,0xB5DD},{0x8BDE,0xB5DE},{0x8BDF,0xB5DF},{0x8BE0,0xB5E0},{0x8BE1,0xB5E1},{0x8BE2,0xB5E2},{0x8BE3,0xB5E3},{0x8BE4,0xB5E4},{0x8BE5,0xB5E5},{0x8BE6,0xB5E6},{0x8BE7,0xB5E7},{0x8BE8,0xB5E8},{0x8BE9,0xB5E9},{0x8BEA,0xB5EA},{0x8BEB,0xB5EB},{0xB6C6,0xB5EC},{0x8BEC,0xB5ED},{0x8BED,0xB5EE},{0x8BEE,0xB5EF},{0x8BEF,0xB5F0},{0x8BF0,0xB5F1},{0x8BF1,0xB5F2},{0x8BF2,0xB5F3},{0x8BF3,0xB5F4},{0x8BF4,0xB5F5},{0x8BF5,0xB5F6},{0x8BF6,0xB5F7},{0x8BF7,0xB5F8},{0x8BF8,0xB5F9},{0x8BF9,0xB5FA},{0x8BFA,0xB5FB},{0x8BFB,0xB5FC},{0x8BFC,0xB5FD},{0x8BFD,0xB5FE},{0x8BFE,0xB5FF},{0x8C41,0xB600},{0x8C42,0xB601},{0x8C43,0xB602},{0x8C44,0xB603},{0x8C45,0xB604},{0x8C46,0xB605},{0x8C47,0xB606},{0x8C48,0xB607},{0x8C49,0xB608},{0x8C4A,0xB609},{0x8C4B,0xB60A},{0x8C4C,0xB60B},{0x8C4D,0xB60C},{0x8C4E,0xB60D},{0x8C4F,0xB60E},{0x8C50,0xB60F},{0xB6C7,0xB610},{0xB6C8,0xB611},{0x8C51,0xB612},{0x8C52,0xB613},{0xB6C9,0xB614},{0x8C53,0xB615},{0x8C54,0xB616},{0x8C55,0xB617},{0xB6CA,0xB618},{0x8C56,0xB619},{0x8C57,0xB61A},{0x8C58,0xB61B},{0x8C59,0xB61C},{0x8C5A,0xB61D},{0x8C61,0xB61E},{0x8C62,0xB61F},{0x8C63,0xB620},{0x8C64,0xB621},{0x8C65,0xB622},{0x8C66,0xB623},{0x8C67,0xB624},{0xB6CB,0xB625},{0x8C68,0xB626},{0x8C69,0xB627},{0x8C6A,0xB628},{0x8C6B,0xB629},{0x8C6C,0xB62A},{0x8C6D,0xB62B},{0xB6CC,0xB62C},{0x8C6E,0xB62D},{0x8C6F,0xB62E},{0x8C70,0xB62F},{0x8C71,0xB630},{0x8C72,0xB631},{0x8C73,0xB632},{0x8C74,0xB633},{0xB6CD,0xB634},{0x8C75,0xB635},{0x8C76,0xB636},{0x8C77,0xB637},{0x8C78,0xB638},{0x8C79,0xB639},{0x8C7A,0xB63A},{0x8C81,0xB63B},{0x8C82,0xB63C},{0x8C83,0xB63D},{0x8C84,0xB63E},{0x8C85,0xB63F},{0x8C86,0xB640},{0x8C87,0xB641},{0x8C88,0xB642},{0x8C89,0xB643},{0x8C8A,0xB644},{0x8C8B,0xB645},{0x8C8C,0xB646},{0x8C8D,0xB647},{0xB6CE,0xB648},{0x8C8E,0xB649},{0x8C8F,0xB64A},{0x8C90,0xB64B},{0x8C91,0xB64C},{0x8C92,0xB64D},{0x8C93,0xB64E},{0x8C94,0xB64F},{0x8C95,0xB650},{0x8C96,0xB651},{0x8C97,0xB652},{0x8C98,0xB653},{0x8C99,0xB654},{0x8C9A,0xB655},{0x8C9B,0xB656},{0x8C9C,0xB657},{0x8C9D,0xB658},{0x8C9E,0xB659},{0x8C9F,0xB65A},{0x8CA0,0xB65B},{0x8CA1,0xB65C},{0x8CA2,0xB65D},{0x8CA3,0xB65E},{0x8CA4,0xB65F},{0x8CA5,0xB660},{0x8CA6,0xB661},{0x8CA7,0xB662},{0x8CA8,0xB663},{0xB6CF,0xB664},{0x8CA9,0xB665},{0x8CAA,0xB666},{0x8CAB,0xB667},{0xB6D0,0xB668},{0x8CAC,0xB669},{0x8CAD,0xB66A},{0x8CAE,0xB66B},{0x8CAF,0xB66C},{0x8CB0,0xB66D},{0x8CB1,0xB66E},{0x8CB2,0xB66F},{0x8CB3,0xB670},{0x8CB4,0xB671},{0x8CB5,0xB672},{0x8CB6,0xB673},{0x8CB7,0xB674},{0x8CB8,0xB675},{0x8CB9,0xB676},{0x8CBA,0xB677},{0x8CBB,0xB678},{0x8CBC,0xB679},{0x8CBD,0xB67A},{0x8CBE,0xB67B},{0x8CBF,0xB67C},{0x8CC0,0xB67D},{0x8CC1,0xB67E},{0x8CC2,0xB67F},{0x8CC3,0xB680},{0x8CC4,0xB681},{0x8CC5,0xB682},{0x8CC6,0xB683},{0x8CC7,0xB684},{0x8CC8,0xB685},{0x8CC9,0xB686},{0x8CCA,0xB687},{0x8CCB,0xB688},{0x8CCC,0xB689},{0x8CCD,0xB68A},{0x8CCE,0xB68B},{0x8CCF,0xB68C},{0x8CD0,0xB68D},{0x8CD1,0xB68E},{0x8CD2,0xB68F},{0x8CD3,0xB690},{0x8CD4,0xB691},{0x8CD5,0xB692},{0x8CD6,0xB693},{0x8CD7,0xB694},{0x8CD8,0xB695},{0x8CD9,0xB696},{0x8CDA,0xB697},{0x8CDB,0xB698},{0x8CDC,0xB699},{0x8CDD,0xB69A},{0x8CDE,0xB69B},{0xB6D1,0xB69C},
{0xB6D2,0xB69D},{0x8CDF,0xB69E},{0x8CE0,0xB69F},{0xB6D3,0xB6A0},{0x8CE1,0xB6A1},{0x8CE2,0xB6A2},{0x8CE3,0xB6A3},{0xB6D4,0xB6A4},{0x8CE4,0xB6A5},{0x8CE5,0xB6A6},{0x8CE6,0xB6A7},{0x8CE7,0xB6A8},{0x8CE8,0xB6A9},{0x8CE9,0xB6AA},{0xB6D5,0xB6AB},{0xB6D6,0xB6AC},{0x8CEA,0xB6AD},{0x8CEB,0xB6AE},{0x8CEC,0xB6AF},{0x8CED,0xB6B0},{0xB6D7,0xB6B1},{0x8CEE,0xB6B2},{0x8CEF,0xB6B3},{0x8CF0,0xB6B4},{0x8CF1,0xB6B5},{0x8CF2,0xB6B6},{0x8CF3,0xB6B7},{0x8CF4,0xB6B8},{0x8CF5,0xB6B9},{0x8CF6,0xB6BA},{0x8CF7,0xB6BB},{0x8CF8,0xB6BC},{0x8CF9,0xB6BD},{0x8CFA,0xB6BE},{0x8CFB,0xB6BF},{0x8CFC,0xB6C0},{0x8CFD,0xB6C1},{0x8CFE,0xB6C2},{0x8D41,0xB6C3},{0x8D42,0xB6C4},{0x8D43,0xB6C5},{0x8D44,0xB6C6},{0x8D45,0xB6C7},{0x8D46,0xB6C8},{0x8D47,0xB6C9},{0x8D48,0xB6CA},{0x8D49,0xB6CB},{0x8D4A,0xB6CC},{0x8D4B,0xB6CD},{0x8D4C,0xB6CE},{0x8D4D,0xB6CF},{0x8D4E,0xB6D0},{0x8D4F,0xB6D1},{0x8D50,0xB6D2},{0x8D51,0xB6D3},{0xB6D8,0xB6D4},{0x8D52,0xB6D5},{0x8D53,0xB6D6},{0x8D54,0xB6D7},{0x8D55,0xB6D8},{0x8D56,0xB6D9},{0x8D57,0xB6DA},{0x8D58,0xB6DB},{0x8D59,0xB6DC},{0x8D5A,0xB6DD},{0x8D61,0xB6DE},{0x8D62,0xB6DF},{0x8D63,0xB6E0},{0x8D64,0xB6E1},{0x8D65,0xB6E2},{0x8D66,0xB6E3},{0x8D67,0xB6E4},{0x8D68,0xB6E5},{0x8D69,0xB6E6},{0x8D6A,0xB6E7},{0x8D6B,0xB6E8},{0x8D6C,0xB6E9},{0x8D6D,0xB6EA},{0x8D6E,0xB6EB},{0x8D6F,0xB6EC},{0x8D70,0xB6ED},{0x8D71,0xB6EE},{0x8D72,0xB6EF},{0xB6D9,0xB6F0},{0x8D73,0xB6F1},{0x8D74,0xB6F2},{0x8D75,0xB6F3},{0xB6DA,0xB6F4},{0x8D76,0xB6F5},{0x8D77,0xB6F6},{0x8D78,0xB6F7},{0xB6DB,0xB6F8},{0x8D79,0xB6F9},{0x8D7A,0xB6FA},{0x8D81,0xB6FB},{0x8D82,0xB6FC},{0x8D83,0xB6FD},{0x8D84,0xB6FE},{0x8D85,0xB6FF},{0xB6DC,0xB700},{0xB6DD,0xB701},{0x8D86,0xB702},{0x8D87,0xB703},{0x8D88,0xB704},{0xB6DE,0xB705},{0x8D89,0xB706},{0x8D8A,0xB707},{0x8D8B,0xB708},{0x8D8C,0xB709},{0x8D8D,0xB70A},{0x8D8E,0xB70B},{0x8D8F,0xB70C},{0x8D90,0xB70D},{0x8D91,0xB70E},{0x8D92,0xB70F},{0x8D93,0xB710},{0x8D94,0xB711},{0x8D95,0xB712},{0x8D96,0xB713},{0x8D97,0xB714},{0x8D98,0xB715},{0x8D99,0xB716},{0x8D9A,0xB717},{0x8D9B,0xB718},{0x8D9C,0xB719},{0x8D9D,0xB71A},{0x8D9E,0xB71B},{0x8D9F,0xB71C},{0x8DA0,0xB71D},{0x8DA1,0xB71E},{0x8DA2,0xB71F},{0x8DA3,0xB720},{0x8DA4,0xB721},{0x8DA5,0xB722},{0x8DA6,0xB723},{0x8DA7,0xB724},{0x8DA8,0xB725},{0x8DA9,0xB726},{0x8DAA,0xB727},{0xB6DF,0xB728},{0xB6E0,0xB729},{0x8DAB,0xB72A},{0x8DAC,0xB72B},{0xB6E1,0xB72C},{0x8DAD,0xB72D},{0x8DAE,0xB72E},{0xB6E2,0xB72F},{0xB6E3,0xB730},{0x8DAF,0xB731},{0x8DB0,0xB732},{0x8DB1,0xB733},{0x8DB2,0xB734},{0x8DB3,0xB735},{0x8DB4,0xB736},{0x8DB5,0xB737},{0xB6E4,0xB738},{0xB6E5,0xB739},{0x8DB6,0xB73A},{0xB6E6,0xB73B},{0x8DB7,0xB73C},{0x8DB8,0xB73D},{0x8DB9,0xB73E},{0x8DBA,0xB73F},{0x8DBB,0xB740},{0x8DBC,0xB741},{0x8DBD,0xB742},{0x8DBE,0xB743},{0xB6E7,0xB744},{0x8DBF,0xB745},{0x8DC0,0xB746},{0x8DC1,0xB747},{0xB6E8,0xB748},{0x8DC2,0xB749},{0x8DC3,0xB74A},{0x8DC4,0xB74B},{0xB6E9,0xB74C},{0x8DC5,0xB74D},{0x8DC6,0xB74E},{0x8DC7,0xB74F},{0x8DC8,0xB750},{0x8DC9,0xB751},{0x8DCA,0xB752},{0x8DCB,0xB753},{0xB6EA,0xB754},{0xB6EB,0xB755},{0x8DCC,0xB756},{0x8DCD,0xB757},{0x8DCE,0xB758},{0x8DCF,0xB759},{0x8DD0,0xB75A},{0x8DD1,0xB75B},{0x8DD2,0xB75C},{0x8DD3,0xB75D},{0x8DD4,0xB75E},{0x8DD5,0xB75F},{0xB6EC,0xB760},{0x8DD6,0xB761},{0x8DD7,0xB762},{0x8DD8,0xB763},{0xB6ED,0xB764},{0x8DD9,0xB765},{0x8DDA,0xB766},{0x8DDB,0xB767},{0xB6EE,0xB768},{0x8DDC,0xB769},{0x8DDD,0xB76A},{0x8DDE,0xB76B},{0x8DDF,0xB76C},{0x8DE0,0xB76D},{0x8DE1,0xB76E},{0x8DE2,0xB76F},{0xB6EF,0xB770},{0xB6F0,0xB771},{0x8DE3,0xB772},{0xB6F1,0xB773},{0x8DE4,0xB774},{0xB6F2,0xB775},{0x8DE5,0xB776},{0x8DE6,0xB777},{0x8DE7,0xB778},{0x8DE8,0xB779},{0x8DE9,0xB77A},{0x8DEA,0xB77B},{0xB6F3,0xB77C},{0xB6F4,0xB77D},{0x8DEB,0xB77E},{0x8DEC,0xB77F},{0xB6F5,0xB780},{0x8DED,0xB781},{0x8DEE,0xB782},{0x8DEF,0xB783},{0xB6F6,0xB784},{0x8DF0,0xB785},{0x8DF1,0xB786},{0x8DF2,0xB787},{0x8DF3,0xB788},{0x8DF4,0xB789},{0x8DF5,0xB78A},{0x8DF6,0xB78B},{0xB6F7,0xB78C},{0xB6F8,0xB78D},{0x8DF7,0xB78E},{0xB6F9,0xB78F},{0xB6FA,0xB790},{0xB6FB,0xB791},{0xB6FC,0xB792},{0x8DF8,0xB793},
{0x8DF9,0xB794},{0x8DFA,0xB795},{0xB6FD,0xB796},{0xB6FE,0xB797},{0xB7A1,0xB798},{0xB7A2,0xB799},{0x8DFB,0xB79A},{0x8DFC,0xB79B},{0xB7A3,0xB79C},{0x8DFD,0xB79D},{0x8DFE,0xB79E},{0x8E41,0xB79F},{0xB7A4,0xB7A0},{0x8E42,0xB7A1},{0x8E43,0xB7A2},{0x8E44,0xB7A3},{0x8E45,0xB7A4},{0x8E46,0xB7A5},{0x8E47,0xB7A6},{0x8E48,0xB7A7},{0xB7A5,0xB7A8},{0xB7A6,0xB7A9},{0x8E49,0xB7AA},{0xB7A7,0xB7AB},{0xB7A8,0xB7AC},{0xB7A9,0xB7AD},{0x8E4A,0xB7AE},{0x8E4B,0xB7AF},{0x8E4C,0xB7B0},{0x8E4D,0xB7B1},{0x8E4E,0xB7B2},{0x8E4F,0xB7B3},{0xB7AA,0xB7B4},{0xB7AB,0xB7B5},{0x8E50,0xB7B6},{0x8E51,0xB7B7},{0xB7AC,0xB7B8},{0x8E52,0xB7B9},{0x8E53,0xB7BA},{0x8E54,0xB7BB},{0x8E55,0xB7BC},{0x8E56,0xB7BD},{0x8E57,0xB7BE},{0x8E58,0xB7BF},{0x8E59,0xB7C0},{0x8E5A,0xB7C1},{0x8E61,0xB7C2},{0x8E62,0xB7C3},{0x8E63,0xB7C4},{0x8E64,0xB7C5},{0x8E65,0xB7C6},{0xB7AD,0xB7C7},{0x8E66,0xB7C8},{0xB7AE,0xB7C9},{0x8E67,0xB7CA},{0x8E68,0xB7CB},{0x8E69,0xB7CC},{0x8E6A,0xB7CD},{0x8E6B,0xB7CE},{0x8E6C,0xB7CF},{0x8E6D,0xB7D0},{0x8E6E,0xB7D1},{0x8E6F,0xB7D2},{0x8E70,0xB7D3},{0x8E71,0xB7D4},{0x8E72,0xB7D5},{0x8E73,0xB7D6},{0x8E74,0xB7D7},{0x8E75,0xB7D8},{0x8E76,0xB7D9},{0x8E77,0xB7DA},{0x8E78,0xB7DB},{0x8E79,0xB7DC},{0x8E7A,0xB7DD},{0x8E81,0xB7DE},{0x8E82,0xB7DF},{0x8E83,0xB7E0},{0x8E84,0xB7E1},{0x8E85,0xB7E2},{0x8E86,0xB7E3},{0x8E87,0xB7E4},{0x8E88,0xB7E5},{0x8E89,0xB7E6},{0x8E8A,0xB7E7},{0x8E8B,0xB7E8},{0x8E8C,0xB7E9},{0x8E8D,0xB7EA},{0x8E8E,0xB7EB},{0xB7AF,0xB7EC},{0xB7B0,0xB7ED},{0x8E8F,0xB7EE},{0x8E90,0xB7EF},{0xB7B1,0xB7F0},{0x8E91,0xB7F1},{0x8E92,0xB7F2},{0x8E93,0xB7F3},{0xB7B2,0xB7F4},{0x8E94,0xB7F5},{0x8E95,0xB7F6},{0x8E96,0xB7F7},{0x8E97,0xB7F8},{0x8E98,0xB7F9},{0x8E99,0xB7FA},{0x8E9A,0xB7FB},{0xB7B3,0xB7FC},{0xB7B4,0xB7FD},{0x8E9B,0xB7FE},{0xB7B5,0xB7FF},{0xB7B6,0xB800},{0xB7B7,0xB801},{0x8E9C,0xB802},{0x8E9D,0xB803},{0x8E9E,0xB804},{0x8E9F,0xB805},{0x8EA0,0xB806},{0xB7B8,0xB807},{0xB7B9,0xB808},{0xB7BA,0xB809},{0x8EA1,0xB80A},{0x8EA2,0xB80B},{0xB7BB,0xB80C},{0x8EA3,0xB80D},{0x8EA4,0xB80E},{0x8EA5,0xB80F},{0xB7BC,0xB810},{0x8EA6,0xB811},{0x8EA7,0xB812},{0x8EA8,0xB813},{0x8EA9,0xB814},{0x8EAA,0xB815},{0x8EAB,0xB816},{0x8EAC,0xB817},{0xB7BD,0xB818},{0xB7BE,0xB819},{0x8EAD,0xB81A},{0xB7BF,0xB81B},{0x8EAE,0xB81C},{0xB7C0,0xB81D},{0x8EAF,0xB81E},{0x8EB0,0xB81F},{0x8EB1,0xB820},{0x8EB2,0xB821},{0x8EB3,0xB822},{0x8EB4,0xB823},{0xB7C1,0xB824},{0xB7C2,0xB825},{0x8EB5,0xB826},{0x8EB6,0xB827},{0xB7C3,0xB828},{0x8EB7,0xB829},{0x8EB8,0xB82A},{0x8EB9,0xB82B},{0xB7C4,0xB82C},{0x8EBA,0xB82D},{0x8EBB,0xB82E},{0x8EBC,0xB82F},{0x8EBD,0xB830},{0x8EBE,0xB831},{0x8EBF,0xB832},{0x8EC0,0xB833},{0xB7C5,0xB834},{0xB7C6,0xB835},{0x8EC1,0xB836},{0xB7C7,0xB837},{0xB7C8,0xB838},{0xB7C9,0xB839},{0x8EC2,0xB83A},{0x8EC3,0xB83B},{0x8EC4,0xB83C},{0x8EC5,0xB83D},{0x8EC6,0xB83E},{0x8EC7,0xB83F},{0xB7CA,0xB840},{0x8EC8,0xB841},{0x8EC9,0xB842},{0x8ECA,0xB843},{0xB7CB,0xB844},{0x8ECB,0xB845},{0x8ECC,0xB846},{0x8ECD,0xB847},{0x8ECE,0xB848},{0x8ECF,0xB849},{0x8ED0,0xB84A},{0x8ED1,0xB84B},{0x8ED2,0xB84C},{0x8ED3,0xB84D},{0x8ED4,0xB84E},{0x8ED5,0xB84F},{0x8ED6,0xB850},{0xB7CC,0xB851},{0x8ED7,0xB852},{0xB7CD,0xB853},{0x8ED8,0xB854},{0x8ED9,0xB855},{0x8EDA,0xB856},{0x8EDB,0xB857},{0x8EDC,0xB858},{0x8EDD,0xB859},{0x8EDE,0xB85A},{0x8EDF,0xB85B},{0xB7CE,0xB85C},{0xB7CF,0xB85D},{0x8EE0,0xB85E},{0x8EE1,0xB85F},{0xB7D0,0xB860},{0x8EE2,0xB861},{0x8EE3,0xB862},{0x8EE4,0xB863},{0xB7D1,0xB864},{0x8EE5,0xB865},{0x8EE6,0xB866},{0x8EE7,0xB867},{0x8EE8,0xB868},{0x8EE9,0xB869},{0x8EEA,0xB86A},{0x8EEB,0xB86B},{0xB7D2,0xB86C},{0xB7D3,0xB86D},{0x8EEC,0xB86E},{0xB7D4,0xB86F},{0x8EED,0xB870},{0xB7D5,0xB871},{0x8EEE,0xB872},{0x8EEF,0xB873},{0x8EF0,0xB874},{0x8EF1,0xB875},{0x8EF2,0xB876},{0x8EF3,0xB877},{0xB7D6,0xB878},{0x8EF4,0xB879},{0x8EF5,0xB87A},{0x8EF6,0xB87B},{0xB7D7,0xB87C},{0x8EF7,0xB87D},{0x8EF8,0xB87E},{0x8EF9,0xB87F},{0x8EFA,0xB880},{0x8EFB,0xB881},{0x8EFC,0xB882},{0x8EFD,0xB883},{0x8EFE,0xB884},{0x8F41,0xB885},{0x8F42,0xB886},{0x8F43,0xB887},{0x8F44,0xB888},{0x8F45,0xB889},{0x8F46,0xB88A},
{0x8F47,0xB88B},{0x8F48,0xB88C},{0xB7D8,0xB88D},{0x8F49,0xB88E},{0x8F4A,0xB88F},{0x8F4B,0xB890},{0x8F4C,0xB891},{0x8F4D,0xB892},{0x8F4E,0xB893},{0x8F4F,0xB894},{0x8F50,0xB895},{0x8F51,0xB896},{0x8F52,0xB897},{0x8F53,0xB898},{0x8F54,0xB899},{0x8F55,0xB89A},{0x8F56,0xB89B},{0x8F57,0xB89C},{0x8F58,0xB89D},{0x8F59,0xB89E},{0x8F5A,0xB89F},{0x8F61,0xB8A0},{0x8F62,0xB8A1},{0x8F63,0xB8A2},{0x8F64,0xB8A3},{0x8F65,0xB8A4},{0x8F66,0xB8A5},{0x8F67,0xB8A6},{0x8F68,0xB8A7},{0xB7D9,0xB8A8},{0x8F69,0xB8A9},{0x8F6A,0xB8AA},{0x8F6B,0xB8AB},{0x8F6C,0xB8AC},{0x8F6D,0xB8AD},{0x8F6E,0xB8AE},{0x8F6F,0xB8AF},{0xB7DA,0xB8B0},{0x8F70,0xB8B1},{0x8F71,0xB8B2},{0x8F72,0xB8B3},{0xB7DB,0xB8B4},{0x8F73,0xB8B5},{0x8F74,0xB8B6},{0x8F75,0xB8B7},{0xB7DC,0xB8B8},{0x8F76,0xB8B9},{0x8F77,0xB8BA},{0x8F78,0xB8BB},{0x8F79,0xB8BC},{0x8F7A,0xB8BD},{0x8F81,0xB8BE},{0x8F82,0xB8BF},{0xB7DD,0xB8C0},{0xB7DE,0xB8C1},{0x8F83,0xB8C2},{0xB7DF,0xB8C3},{0x8F84,0xB8C4},{0xB7E0,0xB8C5},{0x8F85,0xB8C6},{0x8F86,0xB8C7},{0x8F87,0xB8C8},{0x8F88,0xB8C9},{0x8F89,0xB8CA},{0x8F8A,0xB8CB},{0xB7E1,0xB8CC},{0x8F8B,0xB8CD},{0x8F8C,0xB8CE},{0x8F8D,0xB8CF},{0xB7E2,0xB8D0},{0x8F8E,0xB8D1},{0x8F8F,0xB8D2},{0x8F90,0xB8D3},{0xB7E3,0xB8D4},{0x8F91,0xB8D5},{0x8F92,0xB8D6},{0x8F93,0xB8D7},{0x8F94,0xB8D8},{0x8F95,0xB8D9},{0x8F96,0xB8DA},{0x8F97,0xB8DB},{0x8F98,0xB8DC},{0xB7E4,0xB8DD},{0x8F99,0xB8DE},{0xB7E5,0xB8DF},{0x8F9A,0xB8E0},{0xB7E6,0xB8E1},{0x8F9B,0xB8E2},{0x8F9C,0xB8E3},{0x8F9D,0xB8E4},{0x8F9E,0xB8E5},{0x8F9F,0xB8E6},{0x8FA0,0xB8E7},{0xB7E7,0xB8E8},{0xB7E8,0xB8E9},{0x8FA1,0xB8EA},{0x8FA2,0xB8EB},{0xB7E9,0xB8EC},{0x8FA3,0xB8ED},{0x8FA4,0xB8EE},{0x8FA5,0xB8EF},{0xB7EA,0xB8F0},{0x8FA6,0xB8F1},{0x8FA7,0xB8F2},{0x8FA8,0xB8F3},{0x8FA9,0xB8F4},{0x8FAA,0xB8F5},{0x8FAB,0xB8F6},{0x8FAC,0xB8F7},{0xB7EB,0xB8F8},{0xB7EC,0xB8F9},{0x8FAD,0xB8FA},{0xB7ED,0xB8FB},{0x8FAE,0xB8FC},{0xB7EE,0xB8FD},{0x8FAF,0xB8FE},{0x8FB0,0xB8FF},{0x8FB1,0xB900},{0x8FB2,0xB901},{0x8FB3,0xB902},{0x8FB4,0xB903},{0xB7EF,0xB904},{0x8FB5,0xB905},{0x8FB6,0xB906},{0x8FB7,0xB907},{0x8FB8,0xB908},{0x8FB9,0xB909},{0x8FBA,0xB90A},{0x8FBB,0xB90B},{0x8FBC,0xB90C},{0x8FBD,0xB90D},{0x8FBE,0xB90E},{0x8FBF,0xB90F},{0x8FC0,0xB910},{0x8FC1,0xB911},{0x8FC2,0xB912},{0x8FC3,0xB913},{0x8FC4,0xB914},{0x8FC5,0xB915},{0x8FC6,0xB916},{0x8FC7,0xB917},{0xB7F0,0xB918},{0x8FC8,0xB919},{0x8FC9,0xB91A},{0x8FCA,0xB91B},{0x8FCB,0xB91C},{0x8FCC,0xB91D},{0x8FCD,0xB91E},{0x8FCE,0xB91F},{0xB7F1,0xB920},{0x8FCF,0xB921},{0x8FD0,0xB922},{0x8FD1,0xB923},{0x8FD2,0xB924},{0x8FD3,0xB925},{0x8FD4,0xB926},{0x8FD5,0xB927},{0x8FD6,0xB928},{0x8FD7,0xB929},{0x8FD8,0xB92A},{0x8FD9,0xB92B},{0x8FDA,0xB92C},{0x8FDB,0xB92D},{0x8FDC,0xB92E},{0x8FDD,0xB92F},{0x8FDE,0xB930},{0x8FDF,0xB931},{0x8FE0,0xB932},{0x8FE1,0xB933},{0x8FE2,0xB934},{0x8FE3,0xB935},{0x8FE4,0xB936},{0x8FE5,0xB937},{0x8FE6,0xB938},{0x8FE7,0xB939},{0x8FE8,0xB93A},{0x8FE9,0xB93B},{0xB7F2,0xB93C},{0xB7F3,0xB93D},{0x8FEA,0xB93E},{0x8FEB,0xB93F},{0xB7F4,0xB940},{0x8FEC,0xB941},{0x8FED,0xB942},{0x8FEE,0xB943},{0xB7F5,0xB944},{0x8FEF,0xB945},{0x8FF0,0xB946},{0x8FF1,0xB947},{0x8FF2,0xB948},{0x8FF3,0xB949},{0x8FF4,0xB94A},{0x8FF5,0xB94B},{0xB7F6,0xB94C},{0x8FF6,0xB94D},{0x8FF7,0xB94E},{0xB7F7,0xB94F},{0x8FF8,0xB950},{0xB7F8,0xB951},{0x8FF9,0xB952},{0x8FFA,0xB953},{0x8FFB,0xB954},{0x8FFC,0xB955},{0x8FFD,0xB956},{0x8FFE,0xB957},{0xB7F9,0xB958},{0xB7FA,0xB959},{0x9041,0xB95A},{0x9042,0xB95B},{0xB7FB,0xB95C},{0x9043,0xB95D},{0x9044,0xB95E},{0x9045,0xB95F},{0xB7FC,0xB960},{0x9046,0xB961},{0x9047,0xB962},{0x9048,0xB963},{0x9049,0xB964},{0x904A,0xB965},{0x904B,0xB966},{0x904C,0xB967},{0xB7FD,0xB968},{0xB7FE,0xB969},{0x904D,0xB96A},{0xB8A1,0xB96B},{0x904E,0xB96C},{0xB8A2,0xB96D},{0x904F,0xB96E},{0x9050,0xB96F},{0x9051,0xB970},{0x9052,0xB971},{0x9053,0xB972},{0x9054,0xB973},{0xB8A3,0xB974},{0xB8A4,0xB975},{0x9055,0xB976},{0x9056,0xB977},{0xB8A5,0xB978},{0x9057,0xB979},{0x9058,0xB97A},{0x9059,0xB97B},{0xB8A6,0xB97C},{0x905A,0xB97D},{0x9061,0xB97E},{0x9062,0xB97F},{0x9063,0xB980},{0x9064,0xB981},
{0x9065,0xB982},{0x9066,0xB983},{0xB8A7,0xB984},{0xB8A8,0xB985},{0x9067,0xB986},{0xB8A9,0xB987},{0x9068,0xB988},{0xB8AA,0xB989},{0xB8AB,0xB98A},{0x9069,0xB98B},{0x906A,0xB98C},{0xB8AC,0xB98D},{0xB8AD,0xB98E},{0x906B,0xB98F},{0x906C,0xB990},{0x906D,0xB991},{0x906E,0xB992},{0x906F,0xB993},{0x9070,0xB994},{0x9071,0xB995},{0x9072,0xB996},{0x9073,0xB997},{0x9074,0xB998},{0x9075,0xB999},{0x9076,0xB99A},{0x9077,0xB99B},{0x9078,0xB99C},{0x9079,0xB99D},{0x907A,0xB99E},{0x9081,0xB99F},{0x9082,0xB9A0},{0x9083,0xB9A1},{0x9084,0xB9A2},{0x9085,0xB9A3},{0x9086,0xB9A4},{0x9087,0xB9A5},{0x9088,0xB9A6},{0x9089,0xB9A7},{0x908A,0xB9A8},{0x908B,0xB9A9},{0x908C,0xB9AA},{0x908D,0xB9AB},{0xB8AE,0xB9AC},{0xB8AF,0xB9AD},{0x908E,0xB9AE},{0x908F,0xB9AF},{0xB8B0,0xB9B0},{0x9090,0xB9B1},{0x9091,0xB9B2},{0x9092,0xB9B3},{0xB8B1,0xB9B4},{0x9093,0xB9B5},{0x9094,0xB9B6},{0x9095,0xB9B7},{0x9096,0xB9B8},{0x9097,0xB9B9},{0x9098,0xB9BA},{0x9099,0xB9BB},{0xB8B2,0xB9BC},{0xB8B3,0xB9BD},{0x909A,0xB9BE},{0xB8B4,0xB9BF},{0x909B,0xB9C0},{0xB8B5,0xB9C1},{0x909C,0xB9C2},{0x909D,0xB9C3},{0x909E,0xB9C4},{0x909F,0xB9C5},{0x90A0,0xB9C6},{0x90A1,0xB9C7},{0xB8B6,0xB9C8},{0xB8B7,0xB9C9},{0x90A2,0xB9CA},{0x90A3,0xB9CB},{0xB8B8,0xB9CC},{0x90A4,0xB9CD},{0xB8B9,0xB9CE},{0xB8BA,0xB9CF},{0xB8BB,0xB9D0},{0xB8BC,0xB9D1},{0xB8BD,0xB9D2},{0x90A5,0xB9D3},{0x90A6,0xB9D4},{0x90A7,0xB9D5},{0x90A8,0xB9D6},{0x90A9,0xB9D7},{0xB8BE,0xB9D8},{0xB8BF,0xB9D9},{0x90AA,0xB9DA},{0xB8C0,0xB9DB},{0x90AB,0xB9DC},{0xB8C1,0xB9DD},{0xB8C2,0xB9DE},{0x90AC,0xB9DF},{0x90AD,0xB9E0},{0xB8C3,0xB9E1},{0x90AE,0xB9E2},{0xB8C4,0xB9E3},{0xB8C5,0xB9E4},{0xB8C6,0xB9E5},{0x90AF,0xB9E6},{0x90B0,0xB9E7},{0xB8C7,0xB9E8},{0x90B1,0xB9E9},{0x90B2,0xB9EA},{0x90B3,0xB9EB},{0xB8C8,0xB9EC},{0x90B4,0xB9ED},{0x90B5,0xB9EE},{0x90B6,0xB9EF},{0x90B7,0xB9F0},{0x90B8,0xB9F1},{0x90B9,0xB9F2},{0x90BA,0xB9F3},{0xB8C9,0xB9F4},{0xB8CA,0xB9F5},{0x90BB,0xB9F6},{0xB8CB,0xB9F7},{0xB8CC,0xB9F8},{0xB8CD,0xB9F9},{0xB8CE,0xB9FA},{0x90BC,0xB9FB},{0x90BD,0xB9FC},{0x90BE,0xB9FD},{0x90BF,0xB9FE},{0x90C0,0xB9FF},{0xB8CF,0xBA00},{0xB8D0,0xBA01},{0x90C1,0xBA02},{0x90C2,0xBA03},{0x90C3,0xBA04},{0x90C4,0xBA05},{0x90C5,0xBA06},{0x90C6,0xBA07},{0xB8D1,0xBA08},{0x90C7,0xBA09},{0x90C8,0xBA0A},{0x90C9,0xBA0B},{0x90CA,0xBA0C},{0x90CB,0xBA0D},{0x90CC,0xBA0E},{0x90CD,0xBA0F},{0x90CE,0xBA10},{0x90CF,0xBA11},{0x90D0,0xBA12},{0x90D1,0xBA13},{0x90D2,0xBA14},{0xB8D2,0xBA15},{0x90D3,0xBA16},{0x90D4,0xBA17},{0x90D5,0xBA18},{0x90D6,0xBA19},{0x90D7,0xBA1A},{0x90D8,0xBA1B},{0x90D9,0xBA1C},{0x90DA,0xBA1D},{0x90DB,0xBA1E},{0x90DC,0xBA1F},{0x90DD,0xBA20},{0x90DE,0xBA21},{0x90DF,0xBA22},{0x90E0,0xBA23},{0x90E1,0xBA24},{0x90E2,0xBA25},{0x90E3,0xBA26},{0x90E4,0xBA27},{0x90E5,0xBA28},{0x90E6,0xBA29},{0x90E7,0xBA2A},{0x90E8,0xBA2B},{0x90E9,0xBA2C},{0x90EA,0xBA2D},{0x90EB,0xBA2E},{0x90EC,0xBA2F},{0x90ED,0xBA30},{0x90EE,0xBA31},{0x90EF,0xBA32},{0x90F0,0xBA33},{0x90F1,0xBA34},{0x90F2,0xBA35},{0x90F3,0xBA36},{0x90F4,0xBA37},{0xB8D3,0xBA38},{0xB8D4,0xBA39},{0x90F5,0xBA3A},{0x90F6,0xBA3B},{0xB8D5,0xBA3C},{0x90F7,0xBA3D},{0x90F8,0xBA3E},{0x90F9,0xBA3F},{0xB8D6,0xBA40},{0x90FA,0xBA41},{0xB8D7,0xBA42},{0x90FB,0xBA43},{0x90FC,0xBA44},{0x90FD,0xBA45},{0x90FE,0xBA46},{0x9141,0xBA47},{0xB8D8,0xBA48},{0xB8D9,0xBA49},{0x9142,0xBA4A},{0xB8DA,0xBA4B},{0x9143,0xBA4C},{0xB8DB,0xBA4D},{0xB8DC,0xBA4E},{0x9144,0xBA4F},{0x9145,0xBA50},{0x9146,0xBA51},{0x9147,0xBA52},{0xB8DD,0xBA53},{0xB8DE,0xBA54},{0xB8DF,0xBA55},{0x9148,0xBA56},{0x9149,0xBA57},{0xB8E0,0xBA58},{0x914A,0xBA59},{0x914B,0xBA5A},{0x914C,0xBA5B},{0xB8E1,0xBA5C},{0x914D,0xBA5D},{0x914E,0xBA5E},{0x914F,0xBA5F},{0x9150,0xBA60},{0x9151,0xBA61},{0x9152,0xBA62},{0x9153,0xBA63},{0xB8E2,0xBA64},{0xB8E3,0xBA65},{0x9154,0xBA66},{0xB8E4,0xBA67},{0xB8E5,0xBA68},{0xB8E6,0xBA69},{0x9155,0xBA6A},{0x9156,0xBA6B},{0x9157,0xBA6C},{0x9158,0xBA6D},{0x9159,0xBA6E},{0x915A,0xBA6F},{0xB8E7,0xBA70},{0xB8E8,0xBA71},{0x9161,0xBA72},{0x9162,0xBA73},{0xB8E9,0xBA74},{0x9163,0xBA75},{0x9164,0xBA76},{0x9165,0xBA77},{0xB8EA,0xBA78},
{0x9166,0xBA79},{0x9167,0xBA7A},{0x9168,0xBA7B},{0x9169,0xBA7C},{0x916A,0xBA7D},{0x916B,0xBA7E},{0x916C,0xBA7F},{0x916D,0xBA80},{0x916E,0xBA81},{0x916F,0xBA82},{0xB8EB,0xBA83},{0xB8EC,0xBA84},{0xB8ED,0xBA85},{0x9170,0xBA86},{0xB8EE,0xBA87},{0x9171,0xBA88},{0x9172,0xBA89},{0x9173,0xBA8A},{0x9174,0xBA8B},{0xB8EF,0xBA8C},{0x9175,0xBA8D},{0x9176,0xBA8E},{0x9177,0xBA8F},{0x9178,0xBA90},{0x9179,0xBA91},{0x917A,0xBA92},{0x9181,0xBA93},{0x9182,0xBA94},{0x9183,0xBA95},{0x9184,0xBA96},{0x9185,0xBA97},{0x9186,0xBA98},{0x9187,0xBA99},{0x9188,0xBA9A},{0x9189,0xBA9B},{0x918A,0xBA9C},{0x918B,0xBA9D},{0x918C,0xBA9E},{0x918D,0xBA9F},{0x918E,0xBAA0},{0x918F,0xBAA1},{0x9190,0xBAA2},{0x9191,0xBAA3},{0x9192,0xBAA4},{0x9193,0xBAA5},{0x9194,0xBAA6},{0x9195,0xBAA7},{0xB8F0,0xBAA8},{0xB8F1,0xBAA9},{0x9196,0xBAAA},{0xB8F2,0xBAAB},{0xB8F3,0xBAAC},{0x9197,0xBAAD},{0x9198,0xBAAE},{0x9199,0xBAAF},{0xB8F4,0xBAB0},{0x919A,0xBAB1},{0xB8F5,0xBAB2},{0x919B,0xBAB3},{0x919C,0xBAB4},{0x919D,0xBAB5},{0x919E,0xBAB6},{0x919F,0xBAB7},{0xB8F6,0xBAB8},{0xB8F7,0xBAB9},{0x91A0,0xBABA},{0xB8F8,0xBABB},{0x91A1,0xBABC},{0xB8F9,0xBABD},{0x91A2,0xBABE},{0x91A3,0xBABF},{0x91A4,0xBAC0},{0x91A5,0xBAC1},{0x91A6,0xBAC2},{0x91A7,0xBAC3},{0xB8FA,0xBAC4},{0x91A8,0xBAC5},{0x91A9,0xBAC6},{0x91AA,0xBAC7},{0xB8FB,0xBAC8},{0x91AB,0xBAC9},{0x91AC,0xBACA},{0x91AD,0xBACB},{0x91AE,0xBACC},{0x91AF,0xBACD},{0x91B0,0xBACE},{0x91B1,0xBACF},{0x91B2,0xBAD0},{0x91B3,0xBAD1},{0x91B4,0xBAD2},{0x91B5,0xBAD3},{0x91B6,0xBAD4},{0x91B7,0xBAD5},{0x91B8,0xBAD6},{0x91B9,0xBAD7},{0xB8FC,0xBAD8},{0xB8FD,0xBAD9},{0x91BA,0xBADA},{0x91BB,0xBADB},{0x91BC,0xBADC},{0x91BD,0xBADD},{0x91BE,0xBADE},{0x91BF,0xBADF},{0x91C0,0xBAE0},{0x91C1,0xBAE1},{0x91C2,0xBAE2},{0x91C3,0xBAE3},{0x91C4,0xBAE4},{0x91C5,0xBAE5},{0x91C6,0xBAE6},{0x91C7,0xBAE7},{0x91C8,0xBAE8},{0x91C9,0xBAE9},{0x91CA,0xBAEA},{0x91CB,0xBAEB},{0x91CC,0xBAEC},{0x91CD,0xBAED},{0x91CE,0xBAEE},{0x91CF,0xBAEF},{0x91D0,0xBAF0},{0x91D1,0xBAF1},{0x91D2,0xBAF2},{0x91D3,0xBAF3},{0x91D4,0xBAF4},{0x91D5,0xBAF5},{0x91D6,0xBAF6},{0x91D7,0xBAF7},{0x91D8,0xBAF8},{0x91D9,0xBAF9},{0x91DA,0xBAFA},{0x91DB,0xBAFB},{0xB8FE,0xBAFC},{0x91DC,0xBAFD},{0x91DD,0xBAFE},{0x91DE,0xBAFF},{0xB9A1,0xBB00},{0x91DF,0xBB01},{0x91E0,0xBB02},{0x91E1,0xBB03},{0xB9A2,0xBB04},{0x91E2,0xBB05},{0x91E3,0xBB06},{0x91E4,0xBB07},{0x91E5,0xBB08},{0x91E6,0xBB09},{0x91E7,0xBB0A},{0x91E8,0xBB0B},{0x91E9,0xBB0C},{0xB9A3,0xBB0D},{0x91EA,0xBB0E},{0xB9A4,0xBB0F},{0x91EB,0xBB10},{0xB9A5,0xBB11},{0x91EC,0xBB12},{0x91ED,0xBB13},{0x91EE,0xBB14},{0x91EF,0xBB15},{0x91F0,0xBB16},{0x91F1,0xBB17},{0xB9A6,0xBB18},{0x91F2,0xBB19},{0x91F3,0xBB1A},{0x91F4,0xBB1B},{0xB9A7,0xBB1C},{0x91F5,0xBB1D},{0x91F6,0xBB1E},{0x91F7,0xBB1F},{0xB9A8,0xBB20},{0x91F8,0xBB21},{0x91F9,0xBB22},{0x91FA,0xBB23},{0x91FB,0xBB24},{0x91FC,0xBB25},{0x91FD,0xBB26},{0x91FE,0xBB27},{0x9241,0xBB28},{0xB9A9,0xBB29},{0x9242,0xBB2A},{0xB9AA,0xBB2B},{0x9243,0xBB2C},{0x9244,0xBB2D},{0x9245,0xBB2E},{0x9246,0xBB2F},{0x9247,0xBB30},{0x9248,0xBB31},{0x9249,0xBB32},{0x924A,0xBB33},{0xB9AB,0xBB34},{0xB9AC,0xBB35},{0xB9AD,0xBB36},{0x924B,0xBB37},{0xB9AE,0xBB38},{0x924C,0xBB39},{0x924D,0xBB3A},{0xB9AF,0xBB3B},{0xB9B0,0xBB3C},{0xB9B1,0xBB3D},{0xB9B2,0xBB3E},{0x924E,0xBB3F},{0x924F,0xBB40},{0x9250,0xBB41},{0x9251,0xBB42},{0x9252,0xBB43},{0xB9B3,0xBB44},{0xB9B4,0xBB45},{0x9253,0xBB46},{0xB9B5,0xBB47},{0x9254,0xBB48},{0xB9B6,0xBB49},{0x9255,0xBB4A},{0x9256,0xBB4B},{0x9257,0xBB4C},{0xB9B7,0xBB4D},{0x9258,0xBB4E},{0xB9B8,0xBB4F},{0xB9B9,0xBB50},{0x9259,0xBB51},{0x925A,0xBB52},{0x9261,0xBB53},{0xB9BA,0xBB54},{0x9262,0xBB55},{0x9263,0xBB56},{0x9264,0xBB57},{0xB9BB,0xBB58},{0x9265,0xBB59},{0x9266,0xBB5A},{0x9267,0xBB5B},{0x9268,0xBB5C},{0x9269,0xBB5D},{0x926A,0xBB5E},{0x926B,0xBB5F},{0x926C,0xBB60},{0xB9BC,0xBB61},{0x926D,0xBB62},{0xB9BD,0xBB63},{0x926E,0xBB64},{0x926F,0xBB65},{0x9270,0xBB66},{0x9271,0xBB67},{0x9272,0xBB68},{0x9273,0xBB69},{0x9274,0xBB6A},{0x9275,0xBB6B},{0xB9BE,0xBB6C},{0x9276,0xBB6D},{0x9277,0xBB6E},{0x9278,0xBB6F},
{0x9279,0xBB70},{0x927A,0xBB71},{0x9281,0xBB72},{0x9282,0xBB73},{0x9283,0xBB74},{0x9284,0xBB75},{0x9285,0xBB76},{0x9286,0xBB77},{0x9287,0xBB78},{0x9288,0xBB79},{0x9289,0xBB7A},{0x928A,0xBB7B},{0x928B,0xBB7C},{0x928C,0xBB7D},{0x928D,0xBB7E},{0x928E,0xBB7F},{0x928F,0xBB80},{0x9290,0xBB81},{0x9291,0xBB82},{0x9292,0xBB83},{0x9293,0xBB84},{0x9294,0xBB85},{0x9295,0xBB86},{0x9296,0xBB87},{0xB9BF,0xBB88},{0x9297,0xBB89},{0x9298,0xBB8A},{0x9299,0xBB8B},{0xB9C0,0xBB8C},{0x929A,0xBB8D},{0x929B,0xBB8E},{0x929C,0xBB8F},{0xB9C1,0xBB90},{0x929D,0xBB91},{0x929E,0xBB92},{0x929F,0xBB93},{0x92A0,0xBB94},{0x92A1,0xBB95},{0x92A2,0xBB96},{0x92A3,0xBB97},{0x92A4,0xBB98},{0x92A5,0xBB99},{0x92A6,0xBB9A},{0x92A7,0xBB9B},{0x92A8,0xBB9C},{0x92A9,0xBB9D},{0x92AA,0xBB9E},{0x92AB,0xBB9F},{0x92AC,0xBBA0},{0x92AD,0xBBA1},{0x92AE,0xBBA2},{0x92AF,0xBBA3},{0xB9C2,0xBBA4},{0x92B0,0xBBA5},{0x92B1,0xBBA6},{0x92B2,0xBBA7},{0xB9C3,0xBBA8},{0x92B3,0xBBA9},{0x92B4,0xBBAA},{0x92B5,0xBBAB},{0xB9C4,0xBBAC},{0x92B6,0xBBAD},{0x92B7,0xBBAE},{0x92B8,0xBBAF},{0x92B9,0xBBB0},{0x92BA,0xBBB1},{0x92BB,0xBBB2},{0x92BC,0xBBB3},{0xB9C5,0xBBB4},{0x92BD,0xBBB5},{0x92BE,0xBBB6},{0xB9C6,0xBBB7},{0x92BF,0xBBB8},{0x92C0,0xBBB9},{0x92C1,0xBBBA},{0x92C2,0xBBBB},{0x92C3,0xBBBC},{0x92C4,0xBBBD},{0x92C5,0xBBBE},{0x92C6,0xBBBF},{0xB9C7,0xBBC0},{0x92C7,0xBBC1},{0x92C8,0xBBC2},{0x92C9,0xBBC3},{0xB9C8,0xBBC4},{0x92CA,0xBBC5},{0x92CB,0xBBC6},{0x92CC,0xBBC7},{0xB9C9,0xBBC8},{0x92CD,0xBBC9},{0x92CE,0xBBCA},{0x92CF,0xBBCB},{0x92D0,0xBBCC},{0x92D1,0xBBCD},{0x92D2,0xBBCE},{0x92D3,0xBBCF},{0xB9CA,0xBBD0},{0x92D4,0xBBD1},{0x92D5,0xBBD2},{0xB9CB,0xBBD3},{0x92D6,0xBBD4},{0x92D7,0xBBD5},{0x92D8,0xBBD6},{0x92D9,0xBBD7},{0x92DA,0xBBD8},{0x92DB,0xBBD9},{0x92DC,0xBBDA},{0x92DD,0xBBDB},{0x92DE,0xBBDC},{0x92DF,0xBBDD},{0x92E0,0xBBDE},{0x92E1,0xBBDF},{0x92E2,0xBBE0},{0x92E3,0xBBE1},{0x92E4,0xBBE2},{0x92E5,0xBBE3},{0x92E6,0xBBE4},{0x92E7,0xBBE5},{0x92E8,0xBBE6},{0x92E9,0xBBE7},{0x92EA,0xBBE8},{0x92EB,0xBBE9},{0x92EC,0xBBEA},{0x92ED,0xBBEB},{0x92EE,0xBBEC},{0x92EF,0xBBED},{0x92F0,0xBBEE},{0x92F1,0xBBEF},{0x92F2,0xBBF0},{0x92F3,0xBBF1},{0x92F4,0xBBF2},{0x92F5,0xBBF3},{0x92F6,0xBBF4},{0x92F7,0xBBF5},{0x92F8,0xBBF6},{0x92F9,0xBBF7},{0xB9CC,0xBBF8},{0xB9CD,0xBBF9},{0x92FA,0xBBFA},{0x92FB,0xBBFB},{0xB9CE,0xBBFC},{0x92FC,0xBBFD},{0x92FD,0xBBFE},{0xB9CF,0xBBFF},{0xB9D0,0xBC00},{0x92FE,0xBC01},{0xB9D1,0xBC02},{0x9341,0xBC03},{0x9342,0xBC04},{0x9343,0xBC05},{0x9344,0xBC06},{0x9345,0xBC07},{0xB9D2,0xBC08},{0xB9D3,0xBC09},{0x9346,0xBC0A},{0xB9D4,0xBC0B},{0xB9D5,0xBC0C},{0xB9D6,0xBC0D},{0x9347,0xBC0E},{0xB9D7,0xBC0F},{0x9348,0xBC10},{0xB9D8,0xBC11},{0x9349,0xBC12},{0x934A,0xBC13},{0xB9D9,0xBC14},{0xB9DA,0xBC15},{0xB9DB,0xBC16},{0xB9DC,0xBC17},{0xB9DD,0xBC18},{0x934B,0xBC19},{0x934C,0xBC1A},{0xB9DE,0xBC1B},{0xB9DF,0xBC1C},{0xB9E0,0xBC1D},{0xB9E1,0xBC1E},{0xB9E2,0xBC1F},{0x934D,0xBC20},{0x934E,0xBC21},{0x934F,0xBC22},{0x9350,0xBC23},{0xB9E3,0xBC24},{0xB9E4,0xBC25},{0x9351,0xBC26},{0xB9E5,0xBC27},{0x9352,0xBC28},{0xB9E6,0xBC29},{0x9353,0xBC2A},{0x9354,0xBC2B},{0x9355,0xBC2C},{0xB9E7,0xBC2D},{0x9356,0xBC2E},{0x9357,0xBC2F},{0xB9E8,0xBC30},{0xB9E9,0xBC31},{0x9358,0xBC32},{0x9359,0xBC33},{0xB9EA,0xBC34},{0x935A,0xBC35},{0x9361,0xBC36},{0x9362,0xBC37},{0xB9EB,0xBC38},{0x9363,0xBC39},{0x9364,0xBC3A},{0x9365,0xBC3B},{0x9366,0xBC3C},{0x9367,0xBC3D},{0x9368,0xBC3E},{0x9369,0xBC3F},{0xB9EC,0xBC40},{0xB9ED,0xBC41},{0x936A,0xBC42},{0xB9EE,0xBC43},{0xB9EF,0xBC44},{0xB9F0,0xBC45},{0x936B,0xBC46},{0x936C,0xBC47},{0x936D,0xBC48},{0xB9F1,0xBC49},{0x936E,0xBC4A},{0x936F,0xBC4B},{0xB9F2,0xBC4C},{0xB9F3,0xBC4D},{0x9370,0xBC4E},{0x9371,0xBC4F},{0xB9F4,0xBC50},{0x9372,0xBC51},{0x9373,0xBC52},{0x9374,0xBC53},{0x9375,0xBC54},{0x9376,0xBC55},{0x9377,0xBC56},{0x9378,0xBC57},{0x9379,0xBC58},{0x937A,0xBC59},{0x9381,0xBC5A},{0x9382,0xBC5B},{0x9383,0xBC5C},{0xB9F5,0xBC5D},{0x9384,0xBC5E},{0x9385,0xBC5F},{0x9386,0xBC60},{0x9387,0xBC61},{0x9388,0xBC62},{0x9389,0xBC63},{0x938A,0xBC64},{0x938B,0xBC65},{0x938C,0xBC66},
{0x938D,0xBC67},{0x938E,0xBC68},{0x938F,0xBC69},{0x9390,0xBC6A},{0x9391,0xBC6B},{0x9392,0xBC6C},{0x9393,0xBC6D},{0x9394,0xBC6E},{0x9395,0xBC6F},{0x9396,0xBC70},{0x9397,0xBC71},{0x9398,0xBC72},{0x9399,0xBC73},{0x939A,0xBC74},{0x939B,0xBC75},{0x939C,0xBC76},{0x939D,0xBC77},{0x939E,0xBC78},{0x939F,0xBC79},{0x93A0,0xBC7A},{0x93A1,0xBC7B},{0x93A2,0xBC7C},{0x93A3,0xBC7D},{0x93A4,0xBC7E},{0x93A5,0xBC7F},{0x93A6,0xBC80},{0x93A7,0xBC81},{0x93A8,0xBC82},{0x93A9,0xBC83},{0xB9F6,0xBC84},{0xB9F7,0xBC85},{0x93AA,0xBC86},{0x93AB,0xBC87},{0xB9F8,0xBC88},{0x93AC,0xBC89},{0x93AD,0xBC8A},{0xB9F9,0xBC8B},{0xB9FA,0xBC8C},{0x93AE,0xBC8D},{0xB9FB,0xBC8E},{0x93AF,0xBC8F},{0x93B0,0xBC90},{0x93B1,0xBC91},{0x93B2,0xBC92},{0x93B3,0xBC93},{0xB9FC,0xBC94},{0xB9FD,0xBC95},{0x93B4,0xBC96},{0xB9FE,0xBC97},{0x93B5,0xBC98},{0xBAA1,0xBC99},{0xBAA2,0xBC9A},{0x93B6,0xBC9B},{0x93B7,0xBC9C},{0x93B8,0xBC9D},{0x93B9,0xBC9E},{0x93BA,0xBC9F},{0xBAA3,0xBCA0},{0xBAA4,0xBCA1},{0x93BB,0xBCA2},{0x93BC,0xBCA3},{0xBAA5,0xBCA4},{0x93BD,0xBCA5},{0x93BE,0xBCA6},{0xBAA6,0xBCA7},{0xBAA7,0xBCA8},{0x93BF,0xBCA9},{0x93C0,0xBCAA},{0x93C1,0xBCAB},{0x93C2,0xBCAC},{0x93C3,0xBCAD},{0x93C4,0xBCAE},{0x93C5,0xBCAF},{0xBAA8,0xBCB0},{0xBAA9,0xBCB1},{0x93C6,0xBCB2},{0xBAAA,0xBCB3},{0xBAAB,0xBCB4},{0xBAAC,0xBCB5},{0x93C7,0xBCB6},{0x93C8,0xBCB7},{0x93C9,0xBCB8},{0x93CA,0xBCB9},{0x93CB,0xBCBA},{0x93CC,0xBCBB},{0xBAAD,0xBCBC},{0xBAAE,0xBCBD},{0x93CD,0xBCBE},{0x93CE,0xBCBF},{0xBAAF,0xBCC0},{0x93CF,0xBCC1},{0x93D0,0xBCC2},{0x93D1,0xBCC3},{0xBAB0,0xBCC4},{0x93D2,0xBCC5},{0x93D3,0xBCC6},{0x93D4,0xBCC7},{0x93D5,0xBCC8},{0x93D6,0xBCC9},{0x93D7,0xBCCA},{0x93D8,0xBCCB},{0x93D9,0xBCCC},{0xBAB1,0xBCCD},{0x93DA,0xBCCE},{0xBAB2,0xBCCF},{0xBAB3,0xBCD0},{0xBAB4,0xBCD1},{0x93DB,0xBCD2},{0x93DC,0xBCD3},{0x93DD,0xBCD4},{0xBAB5,0xBCD5},{0x93DE,0xBCD6},{0x93DF,0xBCD7},{0xBAB6,0xBCD8},{0x93E0,0xBCD9},{0x93E1,0xBCDA},{0x93E2,0xBCDB},{0xBAB7,0xBCDC},{0x93E3,0xBCDD},{0x93E4,0xBCDE},{0x93E5,0xBCDF},{0x93E6,0xBCE0},{0x93E7,0xBCE1},{0x93E8,0xBCE2},{0x93E9,0xBCE3},{0x93EA,0xBCE4},{0x93EB,0xBCE5},{0x93EC,0xBCE6},{0x93ED,0xBCE7},{0x93EE,0xBCE8},{0x93EF,0xBCE9},{0x93F0,0xBCEA},{0x93F1,0xBCEB},{0x93F2,0xBCEC},{0x93F3,0xBCED},{0x93F4,0xBCEE},{0x93F5,0xBCEF},{0x93F6,0xBCF0},{0x93F7,0xBCF1},{0x93F8,0xBCF2},{0x93F9,0xBCF3},{0xBAB8,0xBCF4},{0xBAB9,0xBCF5},{0xBABA,0xBCF6},{0x93FA,0xBCF7},{0xBABB,0xBCF8},{0x93FB,0xBCF9},{0x93FC,0xBCFA},{0x93FD,0xBCFB},{0xBABC,0xBCFC},{0x93FE,0xBCFD},{0x9441,0xBCFE},{0x9442,0xBCFF},{0x9443,0xBD00},{0x9444,0xBD01},{0x9445,0xBD02},{0x9446,0xBD03},{0xBABD,0xBD04},{0xBABE,0xBD05},{0x9447,0xBD06},{0xBABF,0xBD07},{0x9448,0xBD08},{0xBAC0,0xBD09},{0x9449,0xBD0A},{0x944A,0xBD0B},{0x944B,0xBD0C},{0x944C,0xBD0D},{0x944D,0xBD0E},{0x944E,0xBD0F},{0xBAC1,0xBD10},{0x944F,0xBD11},{0x9450,0xBD12},{0x9451,0xBD13},{0xBAC2,0xBD14},{0x9452,0xBD15},{0x9453,0xBD16},{0x9454,0xBD17},{0x9455,0xBD18},{0x9456,0xBD19},{0x9457,0xBD1A},{0x9458,0xBD1B},{0x9459,0xBD1C},{0x945A,0xBD1D},{0x9461,0xBD1E},{0x9462,0xBD1F},{0x9463,0xBD20},{0x9464,0xBD21},{0x9465,0xBD22},{0x9466,0xBD23},{0xBAC3,0xBD24},{0x9467,0xBD25},{0x9468,0xBD26},{0x9469,0xBD27},{0x946A,0xBD28},{0x946B,0xBD29},{0x946C,0xBD2A},{0x946D,0xBD2B},{0xBAC4,0xBD2C},{0x946E,0xBD2D},{0x946F,0xBD2E},{0x9470,0xBD2F},{0x9471,0xBD30},{0x9472,0xBD31},{0x9473,0xBD32},{0x9474,0xBD33},{0x9475,0xBD34},{0x9476,0xBD35},{0x9477,0xBD36},{0x9478,0xBD37},{0x9479,0xBD38},{0x947A,0xBD39},{0x9481,0xBD3A},{0x9482,0xBD3B},{0x9483,0xBD3C},{0x9484,0xBD3D},{0x9485,0xBD3E},{0x9486,0xBD3F},{0xBAC5,0xBD40},{0x9487,0xBD41},{0x9488,0xBD42},{0x9489,0xBD43},{0x948A,0xBD44},{0x948B,0xBD45},{0x948C,0xBD46},{0x948D,0xBD47},{0xBAC6,0xBD48},{0xBAC7,0xBD49},{0x948E,0xBD4A},{0x948F,0xBD4B},{0xBAC8,0xBD4C},{0x9490,0xBD4D},{0x9491,0xBD4E},{0x9492,0xBD4F},{0xBAC9,0xBD50},{0x9493,0xBD51},{0x9494,0xBD52},{0x9495,0xBD53},{0x9496,0xBD54},{0x9497,0xBD55},{0x9498,0xBD56},{0x9499,0xBD57},{0xBACA,0xBD58},{0xBACB,0xBD59},{0x949A,0xBD5A},{0x949B,0xBD5B},{0x949C,0xBD5C},{0x949D,0xBD5D},
{0x949E,0xBD5E},{0x949F,0xBD5F},{0x94A0,0xBD60},{0x94A1,0xBD61},{0x94A2,0xBD62},{0x94A3,0xBD63},{0xBACC,0xBD64},{0x94A4,0xBD65},{0x94A5,0xBD66},{0x94A6,0xBD67},{0xBACD,0xBD68},{0x94A7,0xBD69},{0x94A8,0xBD6A},{0x94A9,0xBD6B},{0x94AA,0xBD6C},{0x94AB,0xBD6D},{0x94AC,0xBD6E},{0x94AD,0xBD6F},{0x94AE,0xBD70},{0x94AF,0xBD71},{0x94B0,0xBD72},{0x94B1,0xBD73},{0x94B2,0xBD74},{0x94B3,0xBD75},{0x94B4,0xBD76},{0x94B5,0xBD77},{0x94B6,0xBD78},{0x94B7,0xBD79},{0x94B8,0xBD7A},{0x94B9,0xBD7B},{0x94BA,0xBD7C},{0x94BB,0xBD7D},{0x94BC,0xBD7E},{0x94BD,0xBD7F},{0xBACE,0xBD80},{0xBACF,0xBD81},{0x94BE,0xBD82},{0x94BF,0xBD83},{0xBAD0,0xBD84},{0x94C0,0xBD85},{0x94C1,0xBD86},{0xBAD1,0xBD87},{0xBAD2,0xBD88},{0xBAD3,0xBD89},{0xBAD4,0xBD8A},{0x94C2,0xBD8B},{0x94C3,0xBD8C},{0x94C4,0xBD8D},{0x94C5,0xBD8E},{0x94C6,0xBD8F},{0xBAD5,0xBD90},{0xBAD6,0xBD91},{0x94C7,0xBD92},{0xBAD7,0xBD93},{0x94C8,0xBD94},{0xBAD8,0xBD95},{0x94C9,0xBD96},{0x94CA,0xBD97},{0x94CB,0xBD98},{0xBAD9,0xBD99},{0xBADA,0xBD9A},{0x94CC,0xBD9B},{0xBADB,0xBD9C},{0x94CD,0xBD9D},{0x94CE,0xBD9E},{0x94CF,0xBD9F},{0x94D0,0xBDA0},{0x94D1,0xBDA1},{0x94D2,0xBDA2},{0x94D3,0xBDA3},{0xBADC,0xBDA4},{0x94D4,0xBDA5},{0x94D5,0xBDA6},{0x94D6,0xBDA7},{0x94D7,0xBDA8},{0x94D8,0xBDA9},{0x94D9,0xBDAA},{0x94DA,0xBDAB},{0x94DB,0xBDAC},{0x94DC,0xBDAD},{0x94DD,0xBDAE},{0x94DE,0xBDAF},{0xBADD,0xBDB0},{0x94DF,0xBDB1},{0x94E0,0xBDB2},{0x94E1,0xBDB3},{0x94E2,0xBDB4},{0x94E3,0xBDB5},{0x94E4,0xBDB6},{0x94E5,0xBDB7},{0xBADE,0xBDB8},{0x94E6,0xBDB9},{0x94E7,0xBDBA},{0x94E8,0xBDBB},{0x94E9,0xBDBC},{0x94EA,0xBDBD},{0x94EB,0xBDBE},{0x94EC,0xBDBF},{0x94ED,0xBDC0},{0x94EE,0xBDC1},{0x94EF,0xBDC2},{0x94F0,0xBDC3},{0x94F1,0xBDC4},{0x94F2,0xBDC5},{0x94F3,0xBDC6},{0x94F4,0xBDC7},{0x94F5,0xBDC8},{0x94F6,0xBDC9},{0x94F7,0xBDCA},{0x94F8,0xBDCB},{0x94F9,0xBDCC},{0x94FA,0xBDCD},{0x94FB,0xBDCE},{0x94FC,0xBDCF},{0x94FD,0xBDD0},{0x94FE,0xBDD1},{0x9541,0xBDD2},{0x9542,0xBDD3},{0xBADF,0xBDD4},{0xBAE0,0xBDD5},{0x9543,0xBDD6},{0x9544,0xBDD7},{0xBAE1,0xBDD8},{0x9545,0xBDD9},{0x9546,0xBDDA},{0x9547,0xBDDB},{0xBAE2,0xBDDC},{0x9548,0xBDDD},{0x9549,0xBDDE},{0x954A,0xBDDF},{0x954B,0xBDE0},{0x954C,0xBDE1},{0x954D,0xBDE2},{0x954E,0xBDE3},{0x954F,0xBDE4},{0x9550,0xBDE5},{0x9551,0xBDE6},{0x9552,0xBDE7},{0x9553,0xBDE8},{0xBAE3,0xBDE9},{0x9554,0xBDEA},{0x9555,0xBDEB},{0x9556,0xBDEC},{0x9557,0xBDED},{0x9558,0xBDEE},{0x9559,0xBDEF},{0xBAE4,0xBDF0},{0x955A,0xBDF1},{0x9561,0xBDF2},{0x9562,0xBDF3},{0xBAE5,0xBDF4},{0x9563,0xBDF5},{0x9564,0xBDF6},{0x9565,0xBDF7},{0xBAE6,0xBDF8},{0x9566,0xBDF9},{0x9567,0xBDFA},{0x9568,0xBDFB},{0x9569,0xBDFC},{0x956A,0xBDFD},{0x956B,0xBDFE},{0x956C,0xBDFF},{0xBAE7,0xBE00},{0x956D,0xBE01},{0x956E,0xBE02},{0xBAE8,0xBE03},{0x956F,0xBE04},{0xBAE9,0xBE05},{0x9570,0xBE06},{0x9571,0xBE07},{0x9572,0xBE08},{0x9573,0xBE09},{0x9574,0xBE0A},{0x9575,0xBE0B},{0xBAEA,0xBE0C},{0xBAEB,0xBE0D},{0x9576,0xBE0E},{0x9577,0xBE0F},{0xBAEC,0xBE10},{0x9578,0xBE11},{0x9579,0xBE12},{0x957A,0xBE13},{0xBAED,0xBE14},{0x9581,0xBE15},{0x9582,0xBE16},{0x9583,0xBE17},{0x9584,0xBE18},{0x9585,0xBE19},{0x9586,0xBE1A},{0x9587,0xBE1B},{0xBAEE,0xBE1C},{0xBAEF,0xBE1D},{0x9588,0xBE1E},{0xBAF0,0xBE1F},{0x9589,0xBE20},{0x958A,0xBE21},{0x958B,0xBE22},{0x958C,0xBE23},{0x958D,0xBE24},{0x958E,0xBE25},{0x958F,0xBE26},{0x9590,0xBE27},{0x9591,0xBE28},{0x9592,0xBE29},{0x9593,0xBE2A},{0x9594,0xBE2B},{0x9595,0xBE2C},{0x9596,0xBE2D},{0x9597,0xBE2E},{0x9598,0xBE2F},{0x9599,0xBE30},{0x959A,0xBE31},{0x959B,0xBE32},{0x959C,0xBE33},{0x959D,0xBE34},{0x959E,0xBE35},{0x959F,0xBE36},{0x95A0,0xBE37},{0x95A1,0xBE38},{0x95A2,0xBE39},{0x95A3,0xBE3A},{0x95A4,0xBE3B},{0x95A5,0xBE3C},{0x95A6,0xBE3D},{0x95A7,0xBE3E},{0x95A8,0xBE3F},{0x95A9,0xBE40},{0x95AA,0xBE41},{0x95AB,0xBE42},{0x95AC,0xBE43},{0xBAF1,0xBE44},{0xBAF2,0xBE45},{0x95AD,0xBE46},{0x95AE,0xBE47},{0xBAF3,0xBE48},{0x95AF,0xBE49},{0x95B0,0xBE4A},{0x95B1,0xBE4B},{0xBAF4,0xBE4C},{0x95B2,0xBE4D},{0xBAF5,0xBE4E},{0x95B3,0xBE4F},{0x95B4,0xBE50},{0x95B5,0xBE51},{0x95B6,0xBE52},{0x95B7,0xBE53},{0xBAF6,0xBE54},
{0xBAF7,0xBE55},{0x95B8,0xBE56},{0xBAF8,0xBE57},{0x95B9,0xBE58},{0xBAF9,0xBE59},{0xBAFA,0xBE5A},{0xBAFB,0xBE5B},{0x95BA,0xBE5C},{0x95BB,0xBE5D},{0x95BC,0xBE5E},{0x95BD,0xBE5F},{0xBAFC,0xBE60},{0xBAFD,0xBE61},{0x95BE,0xBE62},{0x95BF,0xBE63},{0xBAFE,0xBE64},{0x95C0,0xBE65},{0x95C1,0xBE66},{0x95C2,0xBE67},{0xBBA1,0xBE68},{0x95C3,0xBE69},{0xBBA2,0xBE6A},{0x95C4,0xBE6B},{0x95C5,0xBE6C},{0x95C6,0xBE6D},{0x95C7,0xBE6E},{0x95C8,0xBE6F},{0xBBA3,0xBE70},{0xBBA4,0xBE71},{0x95C9,0xBE72},{0xBBA5,0xBE73},{0xBBA6,0xBE74},{0xBBA7,0xBE75},{0x95CA,0xBE76},{0x95CB,0xBE77},{0x95CC,0xBE78},{0x95CD,0xBE79},{0x95CE,0xBE7A},{0xBBA8,0xBE7B},{0xBBA9,0xBE7C},{0xBBAA,0xBE7D},{0x95CF,0xBE7E},{0x95D0,0xBE7F},{0xBBAB,0xBE80},{0x95D1,0xBE81},{0x95D2,0xBE82},{0x95D3,0xBE83},{0xBBAC,0xBE84},{0x95D4,0xBE85},{0x95D5,0xBE86},{0x95D6,0xBE87},{0x95D7,0xBE88},{0x95D8,0xBE89},{0x95D9,0xBE8A},{0x95DA,0xBE8B},{0xBBAD,0xBE8C},{0xBBAE,0xBE8D},{0x95DB,0xBE8E},{0xBBAF,0xBE8F},{0xBBB0,0xBE90},{0xBBB1,0xBE91},{0x95DC,0xBE92},{0x95DD,0xBE93},{0x95DE,0xBE94},{0x95DF,0xBE95},{0x95E0,0xBE96},{0x95E1,0xBE97},{0xBBB2,0xBE98},{0xBBB3,0xBE99},{0x95E2,0xBE9A},{0x95E3,0xBE9B},{0x95E4,0xBE9C},{0x95E5,0xBE9D},{0x95E6,0xBE9E},{0x95E7,0xBE9F},{0x95E8,0xBEA0},{0x95E9,0xBEA1},{0x95EA,0xBEA2},{0x95EB,0xBEA3},{0x95EC,0xBEA4},{0x95ED,0xBEA5},{0x95EE,0xBEA6},{0x95EF,0xBEA7},{0xBBB4,0xBEA8},{0x95F0,0xBEA9},{0x95F1,0xBEAA},{0x95F2,0xBEAB},{0x95F3,0xBEAC},{0x95F4,0xBEAD},{0x95F5,0xBEAE},{0x95F6,0xBEAF},{0x95F7,0xBEB0},{0x95F8,0xBEB1},{0x95F9,0xBEB2},{0x95FA,0xBEB3},{0x95FB,0xBEB4},{0x95FC,0xBEB5},{0x95FD,0xBEB6},{0x95FE,0xBEB7},{0x9641,0xBEB8},{0x9642,0xBEB9},{0x9643,0xBEBA},{0x9644,0xBEBB},{0x9645,0xBEBC},{0x9646,0xBEBD},{0x9647,0xBEBE},{0x9648,0xBEBF},{0x9649,0xBEC0},{0x964A,0xBEC1},{0x964B,0xBEC2},{0x964C,0xBEC3},{0x964D,0xBEC4},{0x964E,0xBEC5},{0x964F,0xBEC6},{0x9650,0xBEC7},{0x9651,0xBEC8},{0x9652,0xBEC9},{0x9653,0xBECA},{0x9654,0xBECB},{0x9655,0xBECC},{0x9656,0xBECD},{0x9657,0xBECE},{0x9658,0xBECF},{0xBBB5,0xBED0},{0xBBB6,0xBED1},{0x9659,0xBED2},{0x965A,0xBED3},{0xBBB7,0xBED4},{0x9661,0xBED5},{0x9662,0xBED6},{0xBBB8,0xBED7},{0xBBB9,0xBED8},{0x9663,0xBED9},{0x9664,0xBEDA},{0x9665,0xBEDB},{0x9666,0xBEDC},{0x9667,0xBEDD},{0x9668,0xBEDE},{0x9669,0xBEDF},{0xBBBA,0xBEE0},{0x966A,0xBEE1},{0x966B,0xBEE2},{0xBBBB,0xBEE3},{0xBBBC,0xBEE4},{0xBBBD,0xBEE5},{0x966C,0xBEE6},{0x966D,0xBEE7},{0x966E,0xBEE8},{0x966F,0xBEE9},{0x9670,0xBEEA},{0x9671,0xBEEB},{0xBBBE,0xBEEC},{0x9672,0xBEED},{0x9673,0xBEEE},{0x9674,0xBEEF},{0x9675,0xBEF0},{0x9676,0xBEF1},{0x9677,0xBEF2},{0x9678,0xBEF3},{0x9679,0xBEF4},{0x967A,0xBEF5},{0x9681,0xBEF6},{0x9682,0xBEF7},{0x9683,0xBEF8},{0x9684,0xBEF9},{0x9685,0xBEFA},{0x9686,0xBEFB},{0x9687,0xBEFC},{0x9688,0xBEFD},{0x9689,0xBEFE},{0x968A,0xBEFF},{0x968B,0xBF00},{0xBBBF,0xBF01},{0x968C,0xBF02},{0x968D,0xBF03},{0x968E,0xBF04},{0x968F,0xBF05},{0x9690,0xBF06},{0x9691,0xBF07},{0xBBC0,0xBF08},{0xBBC1,0xBF09},{0x9692,0xBF0A},{0x9693,0xBF0B},{0x9694,0xBF0C},{0x9695,0xBF0D},{0x9696,0xBF0E},{0x9697,0xBF0F},{0x9698,0xBF10},{0x9699,0xBF11},{0x969A,0xBF12},{0x969B,0xBF13},{0x969C,0xBF14},{0x969D,0xBF15},{0x969E,0xBF16},{0x969F,0xBF17},{0xBBC2,0xBF18},{0xBBC3,0xBF19},{0x96A0,0xBF1A},{0xBBC4,0xBF1B},{0xBBC5,0xBF1C},{0xBBC6,0xBF1D},{0x96A1,0xBF1E},{0x96A2,0xBF1F},{0x96A3,0xBF20},{0x96A4,0xBF21},{0x96A5,0xBF22},{0x96A6,0xBF23},{0x96A7,0xBF24},{0x96A8,0xBF25},{0x96A9,0xBF26},{0x96AA,0xBF27},{0x96AB,0xBF28},{0x96AC,0xBF29},{0x96AD,0xBF2A},{0x96AE,0xBF2B},{0x96AF,0xBF2C},{0x96B0,0xBF2D},{0x96B1,0xBF2E},{0x96B2,0xBF2F},{0x96B3,0xBF30},{0x96B4,0xBF31},{0x96B5,0xBF32},{0x96B6,0xBF33},{0x96B7,0xBF34},{0x96B8,0xBF35},{0x96B9,0xBF36},{0x96BA,0xBF37},{0x96BB,0xBF38},{0x96BC,0xBF39},{0x96BD,0xBF3A},{0x96BE,0xBF3B},{0x96BF,0xBF3C},{0x96C0,0xBF3D},{0x96C1,0xBF3E},{0x96C2,0xBF3F},{0xBBC7,0xBF40},{0xBBC8,0xBF41},{0x96C3,0xBF42},{0x96C4,0xBF43},{0xBBC9,0xBF44},{0x96C5,0xBF45},{0x96C6,0xBF46},{0x96C7,0xBF47},{0xBBCA,0xBF48},{0x96C8,0xBF49},{0x96C9,0xBF4A},{0x96CA,0xBF4B},
{0x96CB,0xBF4C},{0x96CC,0xBF4D},{0x96CD,0xBF4E},{0x96CE,0xBF4F},{0xBBCB,0xBF50},{0xBBCC,0xBF51},{0x96CF,0xBF52},{0x96D0,0xBF53},{0x96D1,0xBF54},{0xBBCD,0xBF55},{0x96D2,0xBF56},{0x96D3,0xBF57},{0x96D4,0xBF58},{0x96D5,0xBF59},{0x96D6,0xBF5A},{0x96D7,0xBF5B},{0x96D8,0xBF5C},{0x96D9,0xBF5D},{0x96DA,0xBF5E},{0x96DB,0xBF5F},{0x96DC,0xBF60},{0x96DD,0xBF61},{0x96DE,0xBF62},{0x96DF,0xBF63},{0x96E0,0xBF64},{0x96E1,0xBF65},{0x96E2,0xBF66},{0x96E3,0xBF67},{0x96E4,0xBF68},{0x96E5,0xBF69},{0x96E6,0xBF6A},{0x96E7,0xBF6B},{0x96E8,0xBF6C},{0x96E9,0xBF6D},{0x96EA,0xBF6E},{0x96EB,0xBF6F},{0x96EC,0xBF70},{0x96ED,0xBF71},{0x96EE,0xBF72},{0x96EF,0xBF73},{0x96F0,0xBF74},{0x96F1,0xBF75},{0x96F2,0xBF76},{0x96F3,0xBF77},{0x96F4,0xBF78},{0x96F5,0xBF79},{0x96F6,0xBF7A},{0x96F7,0xBF7B},{0x96F8,0xBF7C},{0x96F9,0xBF7D},{0x96FA,0xBF7E},{0x96FB,0xBF7F},{0x96FC,0xBF80},{0x96FD,0xBF81},{0x96FE,0xBF82},{0x9741,0xBF83},{0x9742,0xBF84},{0x9743,0xBF85},{0x9744,0xBF86},{0x9745,0xBF87},{0x9746,0xBF88},{0x9747,0xBF89},{0x9748,0xBF8A},{0x9749,0xBF8B},{0x974A,0xBF8C},{0x974B,0xBF8D},{0x974C,0xBF8E},{0x974D,0xBF8F},{0x974E,0xBF90},{0x974F,0xBF91},{0x9750,0xBF92},{0x9751,0xBF93},{0xBBCE,0xBF94},{0x9752,0xBF95},{0x9753,0xBF96},{0x9754,0xBF97},{0x9755,0xBF98},{0x9756,0xBF99},{0x9757,0xBF9A},{0x9758,0xBF9B},{0x9759,0xBF9C},{0x975A,0xBF9D},{0x9761,0xBF9E},{0x9762,0xBF9F},{0x9763,0xBFA0},{0x9764,0xBFA1},{0x9765,0xBFA2},{0x9766,0xBFA3},{0x9767,0xBFA4},{0x9768,0xBFA5},{0x9769,0xBFA6},{0x976A,0xBFA7},{0x976B,0xBFA8},{0x976C,0xBFA9},{0x976D,0xBFAA},{0x976E,0xBFAB},{0x976F,0xBFAC},{0x9770,0xBFAD},{0x9771,0xBFAE},{0x9772,0xBFAF},{0xBBCF,0xBFB0},{0x9773,0xBFB1},{0x9774,0xBFB2},{0x9775,0xBFB3},{0x9776,0xBFB4},{0x9777,0xBFB5},{0x9778,0xBFB6},{0x9779,0xBFB7},{0x977A,0xBFB8},{0x9781,0xBFB9},{0x9782,0xBFBA},{0x9783,0xBFBB},{0x9784,0xBFBC},{0x9785,0xBFBD},{0x9786,0xBFBE},{0x9787,0xBFBF},{0x9788,0xBFC0},{0x9789,0xBFC1},{0x978A,0xBFC2},{0x978B,0xBFC3},{0x978C,0xBFC4},{0xBBD0,0xBFC5},{0x978D,0xBFC6},{0x978E,0xBFC7},{0x978F,0xBFC8},{0x9790,0xBFC9},{0x9791,0xBFCA},{0x9792,0xBFCB},{0xBBD1,0xBFCC},{0xBBD2,0xBFCD},{0x9793,0xBFCE},{0x9794,0xBFCF},{0xBBD3,0xBFD0},{0x9795,0xBFD1},{0x9796,0xBFD2},{0x9797,0xBFD3},{0xBBD4,0xBFD4},{0x9798,0xBFD5},{0x9799,0xBFD6},{0x979A,0xBFD7},{0x979B,0xBFD8},{0x979C,0xBFD9},{0x979D,0xBFDA},{0x979E,0xBFDB},{0xBBD5,0xBFDC},{0x979F,0xBFDD},{0x97A0,0xBFDE},{0xBBD6,0xBFDF},{0x97A1,0xBFE0},{0xBBD7,0xBFE1},{0x97A2,0xBFE2},{0x97A3,0xBFE3},{0x97A4,0xBFE4},{0x97A5,0xBFE5},{0x97A6,0xBFE6},{0x97A7,0xBFE7},{0x97A8,0xBFE8},{0x97A9,0xBFE9},{0x97AA,0xBFEA},{0x97AB,0xBFEB},{0x97AC,0xBFEC},{0x97AD,0xBFED},{0x97AE,0xBFEE},{0x97AF,0xBFEF},{0x97B0,0xBFF0},{0x97B1,0xBFF1},{0x97B2,0xBFF2},{0x97B3,0xBFF3},{0x97B4,0xBFF4},{0x97B5,0xBFF5},{0x97B6,0xBFF6},{0x97B7,0xBFF7},{0x97B8,0xBFF8},{0x97B9,0xBFF9},{0x97BA,0xBFFA},{0x97BB,0xBFFB},{0x97BC,0xBFFC},{0x97BD,0xBFFD},{0x97BE,0xBFFE},{0x97BF,0xBFFF},{0x97C0,0xC000},{0x97C1,0xC001},{0x97C2,0xC002},{0x97C3,0xC003},{0x97C4,0xC004},{0x97C5,0xC005},{0x97C6,0xC006},{0x97C7,0xC007},{0x97C8,0xC008},{0x97C9,0xC009},{0x97CA,0xC00A},{0x97CB,0xC00B},{0x97CC,0xC00C},{0x97CD,0xC00D},{0x97CE,0xC00E},{0x97CF,0xC00F},{0x97D0,0xC010},{0x97D1,0xC011},{0x97D2,0xC012},{0x97D3,0xC013},{0x97D4,0xC014},{0x97D5,0xC015},{0x97D6,0xC016},{0x97D7,0xC017},{0x97D8,0xC018},{0x97D9,0xC019},{0x97DA,0xC01A},{0x97DB,0xC01B},{0x97DC,0xC01C},{0x97DD,0xC01D},{0x97DE,0xC01E},{0x97DF,0xC01F},{0x97E0,0xC020},{0x97E1,0xC021},{0x97E2,0xC022},{0x97E3,0xC023},{0x97E4,0xC024},{0x97E5,0xC025},{0x97E6,0xC026},{0x97E7,0xC027},{0x97E8,0xC028},{0x97E9,0xC029},{0x97EA,0xC02A},{0x97EB,0xC02B},{0x97EC,0xC02C},{0x97ED,0xC02D},{0x97EE,0xC02E},{0x97EF,0xC02F},{0x97F0,0xC030},{0x97F1,0xC031},{0x97F2,0xC032},{0x97F3,0xC033},{0x97F4,0xC034},{0x97F5,0xC035},{0x97F6,0xC036},{0x97F7,0xC037},{0x97F8,0xC038},{0x97F9,0xC039},{0x97FA,0xC03A},{0x97FB,0xC03B},{0xBBD8,0xC03C},{0x97FC,0xC03D},{0x97FD,0xC03E},{0x97FE,0xC03F},{0x9841,0xC040},{0x9842,0xC041},{0x9843,0xC042},
{0x9844,0xC043},{0x9845,0xC044},{0x9846,0xC045},{0x9847,0xC046},{0x9848,0xC047},{0x9849,0xC048},{0x984A,0xC049},{0x984B,0xC04A},{0x984C,0xC04B},{0x984D,0xC04C},{0x984E,0xC04D},{0x984F,0xC04E},{0x9850,0xC04F},{0x9851,0xC050},{0xBBD9,0xC051},{0x9852,0xC052},{0x9853,0xC053},{0x9854,0xC054},{0x9855,0xC055},{0x9856,0xC056},{0x9857,0xC057},{0xBBDA,0xC058},{0x9858,0xC059},{0x9859,0xC05A},{0x985A,0xC05B},{0xBBDB,0xC05C},{0x9861,0xC05D},{0x9862,0xC05E},{0x9863,0xC05F},{0xBBDC,0xC060},{0x9864,0xC061},{0x9865,0xC062},{0x9866,0xC063},{0x9867,0xC064},{0x9868,0xC065},{0x9869,0xC066},{0x986A,0xC067},{0xBBDD,0xC068},{0xBBDE,0xC069},{0x986B,0xC06A},{0x986C,0xC06B},{0x986D,0xC06C},{0x986E,0xC06D},{0x986F,0xC06E},{0x9870,0xC06F},{0x9871,0xC070},{0x9872,0xC071},{0x9873,0xC072},{0x9874,0xC073},{0x9875,0xC074},{0x9876,0xC075},{0x9877,0xC076},{0x9878,0xC077},{0x9879,0xC078},{0x987A,0xC079},{0x9881,0xC07A},{0x9882,0xC07B},{0x9883,0xC07C},{0x9884,0xC07D},{0x9885,0xC07E},{0x9886,0xC07F},{0x9887,0xC080},{0x9888,0xC081},{0x9889,0xC082},{0x988A,0xC083},{0x988B,0xC084},{0x988C,0xC085},{0x988D,0xC086},{0x988E,0xC087},{0x988F,0xC088},{0x9890,0xC089},{0x9891,0xC08A},{0x9892,0xC08B},{0x9893,0xC08C},{0x9894,0xC08D},{0x9895,0xC08E},{0x9896,0xC08F},{0xBBDF,0xC090},{0xBBE0,0xC091},{0x9897,0xC092},{0x9898,0xC093},{0xBBE1,0xC094},{0x9899,0xC095},{0x989A,0xC096},{0x989B,0xC097},{0xBBE2,0xC098},{0x989C,0xC099},{0x989D,0xC09A},{0x989E,0xC09B},{0x989F,0xC09C},{0x98A0,0xC09D},{0x98A1,0xC09E},{0x98A2,0xC09F},{0xBBE3,0xC0A0},{0xBBE4,0xC0A1},{0x98A3,0xC0A2},{0xBBE5,0xC0A3},{0x98A4,0xC0A4},{0xBBE6,0xC0A5},{0x98A5,0xC0A6},{0x98A6,0xC0A7},{0x98A7,0xC0A8},{0x98A8,0xC0A9},{0x98A9,0xC0AA},{0x98AA,0xC0AB},{0xBBE7,0xC0AC},{0xBBE8,0xC0AD},{0x98AB,0xC0AE},{0xBBE9,0xC0AF},{0xBBEA,0xC0B0},{0x98AC,0xC0B1},{0x98AD,0xC0B2},{0xBBEB,0xC0B3},{0xBBEC,0xC0B4},{0xBBED,0xC0B5},{0xBBEE,0xC0B6},{0x98AE,0xC0B7},{0x98AF,0xC0B8},{0x98B0,0xC0B9},{0x98B1,0xC0BA},{0x98B2,0xC0BB},{0xBBEF,0xC0BC},{0xBBF0,0xC0BD},{0x98B3,0xC0BE},{0xBBF1,0xC0BF},{0xBBF2,0xC0C0},{0xBBF3,0xC0C1},{0x98B4,0xC0C2},{0x98B5,0xC0C3},{0x98B6,0xC0C4},{0xBBF4,0xC0C5},{0x98B7,0xC0C6},{0x98B8,0xC0C7},{0xBBF5,0xC0C8},{0xBBF6,0xC0C9},{0x98B9,0xC0CA},{0x98BA,0xC0CB},{0xBBF7,0xC0CC},{0x98BB,0xC0CD},{0x98BC,0xC0CE},{0x98BD,0xC0CF},{0xBBF8,0xC0D0},{0x98BE,0xC0D1},{0x98BF,0xC0D2},{0x98C0,0xC0D3},{0x98C1,0xC0D4},{0x98C2,0xC0D5},{0x98C3,0xC0D6},{0x98C4,0xC0D7},{0xBBF9,0xC0D8},{0xBBFA,0xC0D9},{0x98C5,0xC0DA},{0xBBFB,0xC0DB},{0xBBFC,0xC0DC},{0xBBFD,0xC0DD},{0x98C6,0xC0DE},{0x98C7,0xC0DF},{0x98C8,0xC0E0},{0x98C9,0xC0E1},{0x98CA,0xC0E2},{0x98CB,0xC0E3},{0xBBFE,0xC0E4},{0xBCA1,0xC0E5},{0x98CC,0xC0E6},{0x98CD,0xC0E7},{0xBCA2,0xC0E8},{0x98CE,0xC0E9},{0x98CF,0xC0EA},{0x98D0,0xC0EB},{0xBCA3,0xC0EC},{0x98D1,0xC0ED},{0x98D2,0xC0EE},{0x98D3,0xC0EF},{0x98D4,0xC0F0},{0x98D5,0xC0F1},{0x98D6,0xC0F2},{0x98D7,0xC0F3},{0xBCA4,0xC0F4},{0xBCA5,0xC0F5},{0x98D8,0xC0F6},{0xBCA6,0xC0F7},{0x98D9,0xC0F8},{0xBCA7,0xC0F9},{0x98DA,0xC0FA},{0x98DB,0xC0FB},{0x98DC,0xC0FC},{0x98DD,0xC0FD},{0x98DE,0xC0FE},{0x98DF,0xC0FF},{0xBCA8,0xC100},{0x98E0,0xC101},{0x98E1,0xC102},{0x98E2,0xC103},{0xBCA9,0xC104},{0x98E3,0xC105},{0x98E4,0xC106},{0x98E5,0xC107},{0xBCAA,0xC108},{0x98E6,0xC109},{0x98E7,0xC10A},{0x98E8,0xC10B},{0x98E9,0xC10C},{0x98EA,0xC10D},{0x98EB,0xC10E},{0x98EC,0xC10F},{0xBCAB,0xC110},{0x98ED,0xC111},{0x98EE,0xC112},{0x98EF,0xC113},{0x98F0,0xC114},{0xBCAC,0xC115},{0x98F1,0xC116},{0x98F2,0xC117},{0x98F3,0xC118},{0x98F4,0xC119},{0x98F5,0xC11A},{0x98F6,0xC11B},{0xBCAD,0xC11C},{0xBCAE,0xC11D},{0xBCAF,0xC11E},{0xBCB0,0xC11F},{0xBCB1,0xC120},{0x98F7,0xC121},{0x98F8,0xC122},{0xBCB2,0xC123},{0xBCB3,0xC124},{0x98F9,0xC125},{0xBCB4,0xC126},{0xBCB5,0xC127},{0x98FA,0xC128},{0x98FB,0xC129},{0x98FC,0xC12A},{0x98FD,0xC12B},{0xBCB6,0xC12C},{0xBCB7,0xC12D},{0x98FE,0xC12E},{0xBCB8,0xC12F},{0xBCB9,0xC130},{0xBCBA,0xC131},{0x9941,0xC132},{0x9942,0xC133},{0x9943,0xC134},{0x9944,0xC135},{0xBCBB,0xC136},{0x9945,0xC137},{0xBCBC,0xC138},{0xBCBD,0xC139},
{0x9946,0xC13A},{0x9947,0xC13B},{0xBCBE,0xC13C},{0x9948,0xC13D},{0x9949,0xC13E},{0x994A,0xC13F},{0xBCBF,0xC140},{0x994B,0xC141},{0x994C,0xC142},{0x994D,0xC143},{0x994E,0xC144},{0x994F,0xC145},{0x9950,0xC146},{0x9951,0xC147},{0xBCC0,0xC148},{0xBCC1,0xC149},{0x9952,0xC14A},{0xBCC2,0xC14B},{0xBCC3,0xC14C},{0xBCC4,0xC14D},{0x9953,0xC14E},{0x9954,0xC14F},{0x9955,0xC150},{0x9956,0xC151},{0x9957,0xC152},{0x9958,0xC153},{0xBCC5,0xC154},{0xBCC6,0xC155},{0x9959,0xC156},{0x995A,0xC157},{0xBCC7,0xC158},{0x9961,0xC159},{0x9962,0xC15A},{0x9963,0xC15B},{0xBCC8,0xC15C},{0x9964,0xC15D},{0x9965,0xC15E},{0x9966,0xC15F},{0x9967,0xC160},{0x9968,0xC161},{0x9969,0xC162},{0x996A,0xC163},{0xBCC9,0xC164},{0xBCCA,0xC165},{0x996B,0xC166},{0xBCCB,0xC167},{0xBCCC,0xC168},{0xBCCD,0xC169},{0x996C,0xC16A},{0x996D,0xC16B},{0x996E,0xC16C},{0x996F,0xC16D},{0x9970,0xC16E},{0x9971,0xC16F},{0xBCCE,0xC170},{0x9972,0xC171},{0x9973,0xC172},{0x9974,0xC173},{0xBCCF,0xC174},{0x9975,0xC175},{0x9976,0xC176},{0x9977,0xC177},{0xBCD0,0xC178},{0x9978,0xC179},{0x9979,0xC17A},{0x997A,0xC17B},{0x9981,0xC17C},{0x9982,0xC17D},{0x9983,0xC17E},{0x9984,0xC17F},{0x9985,0xC180},{0x9986,0xC181},{0x9987,0xC182},{0x9988,0xC183},{0x9989,0xC184},{0xBCD1,0xC185},{0x998A,0xC186},{0x998B,0xC187},{0x998C,0xC188},{0x998D,0xC189},{0x998E,0xC18A},{0x998F,0xC18B},{0xBCD2,0xC18C},{0xBCD3,0xC18D},{0xBCD4,0xC18E},{0x9990,0xC18F},{0xBCD5,0xC190},{0x9991,0xC191},{0x9992,0xC192},{0x9993,0xC193},{0xBCD6,0xC194},{0x9994,0xC195},{0xBCD7,0xC196},{0x9995,0xC197},{0x9996,0xC198},{0x9997,0xC199},{0x9998,0xC19A},{0x9999,0xC19B},{0xBCD8,0xC19C},{0xBCD9,0xC19D},{0x999A,0xC19E},{0xBCDA,0xC19F},{0x999B,0xC1A0},{0xBCDB,0xC1A1},{0x999C,0xC1A2},{0x999D,0xC1A3},{0x999E,0xC1A4},{0xBCDC,0xC1A5},{0x999F,0xC1A6},{0x99A0,0xC1A7},{0xBCDD,0xC1A8},{0xBCDE,0xC1A9},{0x99A1,0xC1AA},{0x99A2,0xC1AB},{0xBCDF,0xC1AC},{0x99A3,0xC1AD},{0x99A4,0xC1AE},{0x99A5,0xC1AF},{0xBCE0,0xC1B0},{0x99A6,0xC1B1},{0x99A7,0xC1B2},{0x99A8,0xC1B3},{0x99A9,0xC1B4},{0x99AA,0xC1B5},{0x99AB,0xC1B6},{0x99AC,0xC1B7},{0x99AD,0xC1B8},{0x99AE,0xC1B9},{0x99AF,0xC1BA},{0x99B0,0xC1BB},{0x99B1,0xC1BC},{0xBCE1,0xC1BD},{0x99B2,0xC1BE},{0x99B3,0xC1BF},{0x99B4,0xC1C0},{0x99B5,0xC1C1},{0x99B6,0xC1C2},{0x99B7,0xC1C3},{0xBCE2,0xC1C4},{0x99B8,0xC1C5},{0x99B9,0xC1C6},{0x99BA,0xC1C7},{0xBCE3,0xC1C8},{0x99BB,0xC1C9},{0x99BC,0xC1CA},{0x99BD,0xC1CB},{0xBCE4,0xC1CC},{0x99BE,0xC1CD},{0x99BF,0xC1CE},{0x99C0,0xC1CF},{0x99C1,0xC1D0},{0x99C2,0xC1D1},{0x99C3,0xC1D2},{0x99C4,0xC1D3},{0xBCE5,0xC1D4},{0x99C5,0xC1D5},{0x99C6,0xC1D6},{0xBCE6,0xC1D7},{0xBCE7,0xC1D8},{0x99C7,0xC1D9},{0x99C8,0xC1DA},{0x99C9,0xC1DB},{0x99CA,0xC1DC},{0x99CB,0xC1DD},{0x99CC,0xC1DE},{0x99CD,0xC1DF},{0xBCE8,0xC1E0},{0x99CE,0xC1E1},{0x99CF,0xC1E2},{0x99D0,0xC1E3},{0xBCE9,0xC1E4},{0x99D1,0xC1E5},{0x99D2,0xC1E6},{0x99D3,0xC1E7},{0xBCEA,0xC1E8},{0x99D4,0xC1E9},{0x99D5,0xC1EA},{0x99D6,0xC1EB},{0x99D7,0xC1EC},{0x99D8,0xC1ED},{0x99D9,0xC1EE},{0x99DA,0xC1EF},{0xBCEB,0xC1F0},{0xBCEC,0xC1F1},{0x99DB,0xC1F2},{0xBCED,0xC1F3},{0x99DC,0xC1F4},{0x99DD,0xC1F5},{0x99DE,0xC1F6},{0x99DF,0xC1F7},{0x99E0,0xC1F8},{0x99E1,0xC1F9},{0x99E2,0xC1FA},{0x99E3,0xC1FB},{0xBCEE,0xC1FC},{0xBCEF,0xC1FD},{0x99E4,0xC1FE},{0x99E5,0xC1FF},{0xBCF0,0xC200},{0x99E6,0xC201},{0x99E7,0xC202},{0x99E8,0xC203},{0xBCF1,0xC204},{0x99E9,0xC205},{0x99EA,0xC206},{0x99EB,0xC207},{0x99EC,0xC208},{0x99ED,0xC209},{0x99EE,0xC20A},{0x99EF,0xC20B},{0xBCF2,0xC20C},{0xBCF3,0xC20D},{0x99F0,0xC20E},{0xBCF4,0xC20F},{0x99F1,0xC210},{0xBCF5,0xC211},{0x99F2,0xC212},{0x99F3,0xC213},{0x99F4,0xC214},{0x99F5,0xC215},{0x99F6,0xC216},{0x99F7,0xC217},{0xBCF6,0xC218},{0xBCF7,0xC219},{0x99F8,0xC21A},{0x99F9,0xC21B},{0xBCF8,0xC21C},{0x99FA,0xC21D},{0x99FB,0xC21E},{0xBCF9,0xC21F},{0xBCFA,0xC220},{0x99FC,0xC221},{0x99FD,0xC222},{0x99FE,0xC223},{0x9A41,0xC224},{0x9A42,0xC225},{0x9A43,0xC226},{0x9A44,0xC227},{0xBCFB,0xC228},{0xBCFC,0xC229},{0x9A45,0xC22A},{0xBCFD,0xC22B},{0x9A46,0xC22C},{0xBCFE,0xC22D},{0x9A47,0xC22E},{0xBDA1,0xC22F},{0x9A48,0xC230},
{0xBDA2,0xC231},{0xBDA3,0xC232},{0x9A49,0xC233},{0xBDA4,0xC234},{0x9A4A,0xC235},{0x9A4B,0xC236},{0x9A4C,0xC237},{0x9A4D,0xC238},{0x9A4E,0xC239},{0x9A4F,0xC23A},{0x9A50,0xC23B},{0x9A51,0xC23C},{0x9A52,0xC23D},{0x9A53,0xC23E},{0x9A54,0xC23F},{0x9A55,0xC240},{0x9A56,0xC241},{0x9A57,0xC242},{0x9A58,0xC243},{0x9A59,0xC244},{0x9A5A,0xC245},{0x9A61,0xC246},{0x9A62,0xC247},{0xBDA5,0xC248},{0x9A63,0xC249},{0x9A64,0xC24A},{0x9A65,0xC24B},{0x9A66,0xC24C},{0x9A67,0xC24D},{0x9A68,0xC24E},{0x9A69,0xC24F},{0xBDA6,0xC250},{0xBDA7,0xC251},{0x9A6A,0xC252},{0x9A6B,0xC253},{0xBDA8,0xC254},{0x9A6C,0xC255},{0x9A6D,0xC256},{0x9A6E,0xC257},{0xBDA9,0xC258},{0x9A6F,0xC259},{0x9A70,0xC25A},{0x9A71,0xC25B},{0x9A72,0xC25C},{0x9A73,0xC25D},{0x9A74,0xC25E},{0x9A75,0xC25F},{0xBDAA,0xC260},{0x9A76,0xC261},{0x9A77,0xC262},{0x9A78,0xC263},{0x9A79,0xC264},{0xBDAB,0xC265},{0x9A7A,0xC266},{0x9A81,0xC267},{0x9A82,0xC268},{0x9A83,0xC269},{0x9A84,0xC26A},{0x9A85,0xC26B},{0xBDAC,0xC26C},{0xBDAD,0xC26D},{0x9A86,0xC26E},{0x9A87,0xC26F},{0xBDAE,0xC270},{0x9A88,0xC271},{0x9A89,0xC272},{0x9A8A,0xC273},{0xBDAF,0xC274},{0x9A8B,0xC275},{0x9A8C,0xC276},{0x9A8D,0xC277},{0x9A8E,0xC278},{0x9A8F,0xC279},{0x9A90,0xC27A},{0x9A91,0xC27B},{0xBDB0,0xC27C},{0xBDB1,0xC27D},{0x9A92,0xC27E},{0xBDB2,0xC27F},{0x9A93,0xC280},{0xBDB3,0xC281},{0x9A94,0xC282},{0x9A95,0xC283},{0x9A96,0xC284},{0x9A97,0xC285},{0x9A98,0xC286},{0x9A99,0xC287},{0xBDB4,0xC288},{0xBDB5,0xC289},{0x9A9A,0xC28A},{0x9A9B,0xC28B},{0x9A9C,0xC28C},{0x9A9D,0xC28D},{0x9A9E,0xC28E},{0x9A9F,0xC28F},{0xBDB6,0xC290},{0x9AA0,0xC291},{0x9AA1,0xC292},{0x9AA2,0xC293},{0x9AA3,0xC294},{0x9AA4,0xC295},{0x9AA5,0xC296},{0x9AA6,0xC297},{0xBDB7,0xC298},{0x9AA7,0xC299},{0x9AA8,0xC29A},{0xBDB8,0xC29B},{0x9AA9,0xC29C},{0xBDB9,0xC29D},{0x9AAA,0xC29E},{0x9AAB,0xC29F},{0x9AAC,0xC2A0},{0x9AAD,0xC2A1},{0x9AAE,0xC2A2},{0x9AAF,0xC2A3},{0xBDBA,0xC2A4},{0xBDBB,0xC2A5},{0x9AB0,0xC2A6},{0x9AB1,0xC2A7},{0xBDBC,0xC2A8},{0x9AB2,0xC2A9},{0x9AB3,0xC2AA},{0x9AB4,0xC2AB},{0xBDBD,0xC2AC},{0xBDBE,0xC2AD},{0x9AB5,0xC2AE},{0x9AB6,0xC2AF},{0x9AB7,0xC2B0},{0x9AB8,0xC2B1},{0x9AB9,0xC2B2},{0x9ABA,0xC2B3},{0xBDBF,0xC2B4},{0xBDC0,0xC2B5},{0x9ABB,0xC2B6},{0xBDC1,0xC2B7},{0x9ABC,0xC2B8},{0xBDC2,0xC2B9},{0x9ABD,0xC2BA},{0x9ABE,0xC2BB},{0x9ABF,0xC2BC},{0x9AC0,0xC2BD},{0x9AC1,0xC2BE},{0x9AC2,0xC2BF},{0x9AC3,0xC2C0},{0x9AC4,0xC2C1},{0x9AC5,0xC2C2},{0x9AC6,0xC2C3},{0x9AC7,0xC2C4},{0x9AC8,0xC2C5},{0x9AC9,0xC2C6},{0x9ACA,0xC2C7},{0x9ACB,0xC2C8},{0x9ACC,0xC2C9},{0x9ACD,0xC2CA},{0x9ACE,0xC2CB},{0x9ACF,0xC2CC},{0x9AD0,0xC2CD},{0x9AD1,0xC2CE},{0x9AD2,0xC2CF},{0x9AD3,0xC2D0},{0x9AD4,0xC2D1},{0x9AD5,0xC2D2},{0x9AD6,0xC2D3},{0x9AD7,0xC2D4},{0x9AD8,0xC2D5},{0x9AD9,0xC2D6},{0x9ADA,0xC2D7},{0x9ADB,0xC2D8},{0x9ADC,0xC2D9},{0x9ADD,0xC2DA},{0x9ADE,0xC2DB},{0xBDC3,0xC2DC},{0xBDC4,0xC2DD},{0x9ADF,0xC2DE},{0x9AE0,0xC2DF},{0xBDC5,0xC2E0},{0x9AE1,0xC2E1},{0x9AE2,0xC2E2},{0xBDC6,0xC2E3},{0xBDC7,0xC2E4},{0x9AE3,0xC2E5},{0x9AE4,0xC2E6},{0x9AE5,0xC2E7},{0x9AE6,0xC2E8},{0x9AE7,0xC2E9},{0x9AE8,0xC2EA},{0xBDC8,0xC2EB},{0xBDC9,0xC2EC},{0xBDCA,0xC2ED},{0x9AE9,0xC2EE},{0xBDCB,0xC2EF},{0x9AEA,0xC2F0},{0xBDCC,0xC2F1},{0x9AEB,0xC2F2},{0x9AEC,0xC2F3},{0x9AED,0xC2F4},{0x9AEE,0xC2F5},{0xBDCD,0xC2F6},{0x9AEF,0xC2F7},{0xBDCE,0xC2F8},{0xBDCF,0xC2F9},{0x9AF0,0xC2FA},{0xBDD0,0xC2FB},{0xBDD1,0xC2FC},{0x9AF1,0xC2FD},{0x9AF2,0xC2FE},{0x9AF3,0xC2FF},{0xBDD2,0xC300},{0x9AF4,0xC301},{0x9AF5,0xC302},{0x9AF6,0xC303},{0x9AF7,0xC304},{0x9AF8,0xC305},{0x9AF9,0xC306},{0x9AFA,0xC307},{0xBDD3,0xC308},{0xBDD4,0xC309},{0x9AFB,0xC30A},{0x9AFC,0xC30B},{0xBDD5,0xC30C},{0xBDD6,0xC30D},{0x9AFD,0xC30E},{0x9AFE,0xC30F},{0x9B41,0xC310},{0x9B42,0xC311},{0x9B43,0xC312},{0xBDD7,0xC313},{0xBDD8,0xC314},{0xBDD9,0xC315},{0x9B44,0xC316},{0x9B45,0xC317},{0xBDDA,0xC318},{0x9B46,0xC319},{0x9B47,0xC31A},{0x9B48,0xC31B},{0xBDDB,0xC31C},{0x9B49,0xC31D},{0x9B4A,0xC31E},{0x9B4B,0xC31F},{0x9B4C,0xC320},{0x9B4D,0xC321},{0x9B4E,0xC322},{0x9B4F,0xC323},{0xBDDC,0xC324},{0xBDDD,0xC325},{0x9B50,0xC326},{0x9B51,0xC327},
{0xBDDE,0xC328},{0xBDDF,0xC329},{0x9B52,0xC32A},{0x9B53,0xC32B},{0x9B54,0xC32C},{0x9B55,0xC32D},{0x9B56,0xC32E},{0x9B57,0xC32F},{0x9B58,0xC330},{0x9B59,0xC331},{0x9B5A,0xC332},{0x9B61,0xC333},{0x9B62,0xC334},{0x9B63,0xC335},{0x9B64,0xC336},{0x9B65,0xC337},{0x9B66,0xC338},{0x9B67,0xC339},{0x9B68,0xC33A},{0x9B69,0xC33B},{0x9B6A,0xC33C},{0x9B6B,0xC33D},{0x9B6C,0xC33E},{0x9B6D,0xC33F},{0x9B6E,0xC340},{0x9B6F,0xC341},{0x9B70,0xC342},{0x9B71,0xC343},{0x9B72,0xC344},{0xBDE0,0xC345},{0x9B73,0xC346},{0x9B74,0xC347},{0x9B75,0xC348},{0x9B76,0xC349},{0x9B77,0xC34A},{0x9B78,0xC34B},{0x9B79,0xC34C},{0x9B7A,0xC34D},{0x9B81,0xC34E},{0x9B82,0xC34F},{0x9B83,0xC350},{0x9B84,0xC351},{0x9B85,0xC352},{0x9B86,0xC353},{0x9B87,0xC354},{0x9B88,0xC355},{0x9B89,0xC356},{0x9B8A,0xC357},{0x9B8B,0xC358},{0x9B8C,0xC359},{0x9B8D,0xC35A},{0x9B8E,0xC35B},{0x9B8F,0xC35C},{0x9B90,0xC35D},{0x9B91,0xC35E},{0x9B92,0xC35F},{0x9B93,0xC360},{0x9B94,0xC361},{0x9B95,0xC362},{0x9B96,0xC363},{0x9B97,0xC364},{0x9B98,0xC365},{0x9B99,0xC366},{0x9B9A,0xC367},{0xBDE1,0xC368},{0xBDE2,0xC369},{0x9B9B,0xC36A},{0x9B9C,0xC36B},{0xBDE3,0xC36C},{0x9B9D,0xC36D},{0x9B9E,0xC36E},{0x9B9F,0xC36F},{0xBDE4,0xC370},{0x9BA0,0xC371},{0xBDE5,0xC372},{0x9BA1,0xC373},{0x9BA2,0xC374},{0x9BA3,0xC375},{0x9BA4,0xC376},{0x9BA5,0xC377},{0xBDE6,0xC378},{0xBDE7,0xC379},{0x9BA6,0xC37A},{0x9BA7,0xC37B},{0xBDE8,0xC37C},{0xBDE9,0xC37D},{0x9BA8,0xC37E},{0x9BA9,0xC37F},{0x9BAA,0xC380},{0x9BAB,0xC381},{0x9BAC,0xC382},{0x9BAD,0xC383},{0xBDEA,0xC384},{0x9BAE,0xC385},{0x9BAF,0xC386},{0x9BB0,0xC387},{0xBDEB,0xC388},{0x9BB1,0xC389},{0x9BB2,0xC38A},{0x9BB3,0xC38B},{0xBDEC,0xC38C},{0x9BB4,0xC38D},{0x9BB5,0xC38E},{0x9BB6,0xC38F},{0x9BB7,0xC390},{0x9BB8,0xC391},{0x9BB9,0xC392},{0x9BBA,0xC393},{0x9BBB,0xC394},{0x9BBC,0xC395},{0x9BBD,0xC396},{0x9BBE,0xC397},{0x9BBF,0xC398},{0x9BC0,0xC399},{0x9BC1,0xC39A},{0x9BC2,0xC39B},{0x9BC3,0xC39C},{0x9BC4,0xC39D},{0x9BC5,0xC39E},{0x9BC6,0xC39F},{0x9BC7,0xC3A0},{0x9BC8,0xC3A1},{0x9BC9,0xC3A2},{0x9BCA,0xC3A3},{0x9BCB,0xC3A4},{0x9BCC,0xC3A5},{0x9BCD,0xC3A6},{0x9BCE,0xC3A7},{0x9BCF,0xC3A8},{0x9BD0,0xC3A9},{0x9BD1,0xC3AA},{0x9BD2,0xC3AB},{0x9BD3,0xC3AC},{0x9BD4,0xC3AD},{0x9BD5,0xC3AE},{0x9BD6,0xC3AF},{0x9BD7,0xC3B0},{0x9BD8,0xC3B1},{0x9BD9,0xC3B2},{0x9BDA,0xC3B3},{0x9BDB,0xC3B4},{0x9BDC,0xC3B5},{0x9BDD,0xC3B6},{0x9BDE,0xC3B7},{0x9BDF,0xC3B8},{0x9BE0,0xC3B9},{0x9BE1,0xC3BA},{0x9BE2,0xC3BB},{0x9BE3,0xC3BC},{0x9BE4,0xC3BD},{0x9BE5,0xC3BE},{0x9BE6,0xC3BF},{0xBDED,0xC3C0},{0x9BE7,0xC3C1},{0x9BE8,0xC3C2},{0x9BE9,0xC3C3},{0x9BEA,0xC3C4},{0x9BEB,0xC3C5},{0x9BEC,0xC3C6},{0x9BED,0xC3C7},{0x9BEE,0xC3C8},{0x9BEF,0xC3C9},{0x9BF0,0xC3CA},{0x9BF1,0xC3CB},{0x9BF2,0xC3CC},{0x9BF3,0xC3CD},{0x9BF4,0xC3CE},{0x9BF5,0xC3CF},{0x9BF6,0xC3D0},{0x9BF7,0xC3D1},{0x9BF8,0xC3D2},{0x9BF9,0xC3D3},{0x9BFA,0xC3D4},{0x9BFB,0xC3D5},{0x9BFC,0xC3D6},{0x9BFD,0xC3D7},{0xBDEE,0xC3D8},{0xBDEF,0xC3D9},{0x9BFE,0xC3DA},{0x9C41,0xC3DB},{0xBDF0,0xC3DC},{0x9C42,0xC3DD},{0x9C43,0xC3DE},{0xBDF1,0xC3DF},{0xBDF2,0xC3E0},{0x9C44,0xC3E1},{0xBDF3,0xC3E2},{0x9C45,0xC3E3},{0x9C46,0xC3E4},{0x9C47,0xC3E5},{0x9C48,0xC3E6},{0x9C49,0xC3E7},{0xBDF4,0xC3E8},{0xBDF5,0xC3E9},{0x9C4A,0xC3EA},{0x9C4B,0xC3EB},{0x9C4C,0xC3EC},{0xBDF6,0xC3ED},{0x9C4D,0xC3EE},{0x9C4E,0xC3EF},{0x9C4F,0xC3F0},{0x9C50,0xC3F1},{0x9C51,0xC3F2},{0x9C52,0xC3F3},{0xBDF7,0xC3F4},{0xBDF8,0xC3F5},{0x9C53,0xC3F6},{0x9C54,0xC3F7},{0xBDF9,0xC3F8},{0x9C55,0xC3F9},{0x9C56,0xC3FA},{0x9C57,0xC3FB},{0x9C58,0xC3FC},{0x9C59,0xC3FD},{0x9C5A,0xC3FE},{0x9C61,0xC3FF},{0x9C62,0xC400},{0x9C63,0xC401},{0x9C64,0xC402},{0x9C65,0xC403},{0x9C66,0xC404},{0x9C67,0xC405},{0x9C68,0xC406},{0x9C69,0xC407},{0xBDFA,0xC408},{0x9C6A,0xC409},{0x9C6B,0xC40A},{0x9C6C,0xC40B},{0x9C6D,0xC40C},{0x9C6E,0xC40D},{0x9C6F,0xC40E},{0x9C70,0xC40F},{0xBDFB,0xC410},{0x9C71,0xC411},{0x9C72,0xC412},{0x9C73,0xC413},{0x9C74,0xC414},{0x9C75,0xC415},{0x9C76,0xC416},{0x9C77,0xC417},{0x9C78,0xC418},{0x9C79,0xC419},{0x9C7A,0xC41A},{0x9C81,0xC41B},{0x9C82,0xC41C},{0x9C83,0xC41D},{0x9C84,0xC41E},
{0x9C85,0xC41F},{0x9C86,0xC420},{0x9C87,0xC421},{0x9C88,0xC422},{0x9C89,0xC423},{0xBDFC,0xC424},{0x9C8A,0xC425},{0x9C8B,0xC426},{0x9C8C,0xC427},{0x9C8D,0xC428},{0x9C8E,0xC429},{0x9C8F,0xC42A},{0x9C90,0xC42B},{0xBDFD,0xC42C},{0x9C91,0xC42D},{0x9C92,0xC42E},{0x9C93,0xC42F},{0xBDFE,0xC430},{0x9C94,0xC431},{0x9C95,0xC432},{0x9C96,0xC433},{0xBEA1,0xC434},{0x9C97,0xC435},{0x9C98,0xC436},{0x9C99,0xC437},{0x9C9A,0xC438},{0x9C9B,0xC439},{0x9C9C,0xC43A},{0x9C9D,0xC43B},{0xBEA2,0xC43C},{0xBEA3,0xC43D},{0x9C9E,0xC43E},{0x9C9F,0xC43F},{0x9CA0,0xC440},{0x9CA1,0xC441},{0x9CA2,0xC442},{0x9CA3,0xC443},{0x9CA4,0xC444},{0x9CA5,0xC445},{0x9CA6,0xC446},{0x9CA7,0xC447},{0xBEA4,0xC448},{0x9CA8,0xC449},{0x9CA9,0xC44A},{0x9CAA,0xC44B},{0x9CAB,0xC44C},{0x9CAC,0xC44D},{0x9CAD,0xC44E},{0x9CAE,0xC44F},{0x9CAF,0xC450},{0x9CB0,0xC451},{0x9CB1,0xC452},{0x9CB2,0xC453},{0x9CB3,0xC454},{0x9CB4,0xC455},{0x9CB5,0xC456},{0x9CB6,0xC457},{0x9CB7,0xC458},{0x9CB8,0xC459},{0x9CB9,0xC45A},{0x9CBA,0xC45B},{0x9CBB,0xC45C},{0x9CBC,0xC45D},{0x9CBD,0xC45E},{0x9CBE,0xC45F},{0x9CBF,0xC460},{0x9CC0,0xC461},{0x9CC1,0xC462},{0x9CC2,0xC463},{0xBEA5,0xC464},{0xBEA6,0xC465},{0x9CC3,0xC466},{0x9CC4,0xC467},{0xBEA7,0xC468},{0x9CC5,0xC469},{0x9CC6,0xC46A},{0x9CC7,0xC46B},{0xBEA8,0xC46C},{0x9CC8,0xC46D},{0x9CC9,0xC46E},{0x9CCA,0xC46F},{0x9CCB,0xC470},{0x9CCC,0xC471},{0x9CCD,0xC472},{0x9CCE,0xC473},{0xBEA9,0xC474},{0xBEAA,0xC475},{0x9CCF,0xC476},{0x9CD0,0xC477},{0x9CD1,0xC478},{0xBEAB,0xC479},{0x9CD2,0xC47A},{0x9CD3,0xC47B},{0x9CD4,0xC47C},{0x9CD5,0xC47D},{0x9CD6,0xC47E},{0x9CD7,0xC47F},{0xBEAC,0xC480},{0x9CD8,0xC481},{0x9CD9,0xC482},{0x9CDA,0xC483},{0x9CDB,0xC484},{0x9CDC,0xC485},{0x9CDD,0xC486},{0x9CDE,0xC487},{0x9CDF,0xC488},{0x9CE0,0xC489},{0x9CE1,0xC48A},{0x9CE2,0xC48B},{0x9CE3,0xC48C},{0x9CE4,0xC48D},{0x9CE5,0xC48E},{0x9CE6,0xC48F},{0x9CE7,0xC490},{0x9CE8,0xC491},{0x9CE9,0xC492},{0x9CEA,0xC493},{0xBEAD,0xC494},{0x9CEB,0xC495},{0x9CEC,0xC496},{0x9CED,0xC497},{0x9CEE,0xC498},{0x9CEF,0xC499},{0x9CF0,0xC49A},{0x9CF1,0xC49B},{0xBEAE,0xC49C},{0x9CF2,0xC49D},{0x9CF3,0xC49E},{0x9CF4,0xC49F},{0x9CF5,0xC4A0},{0x9CF6,0xC4A1},{0x9CF7,0xC4A2},{0x9CF8,0xC4A3},{0x9CF9,0xC4A4},{0x9CFA,0xC4A5},{0x9CFB,0xC4A6},{0x9CFC,0xC4A7},{0x9CFD,0xC4A8},{0x9CFE,0xC4A9},{0x9D41,0xC4AA},{0x9D42,0xC4AB},{0x9D43,0xC4AC},{0x9D44,0xC4AD},{0x9D45,0xC4AE},{0x9D46,0xC4AF},{0x9D47,0xC4B0},{0x9D48,0xC4B1},{0x9D49,0xC4B2},{0x9D4A,0xC4B3},{0x9D4B,0xC4B4},{0x9D4C,0xC4B5},{0x9D4D,0xC4B6},{0x9D4E,0xC4B7},{0xBEAF,0xC4B8},{0x9D4F,0xC4B9},{0x9D50,0xC4BA},{0x9D51,0xC4BB},{0xBEB0,0xC4BC},{0x9D52,0xC4BD},{0x9D53,0xC4BE},{0x9D54,0xC4BF},{0x9D55,0xC4C0},{0x9D56,0xC4C1},{0x9D57,0xC4C2},{0x9D58,0xC4C3},{0x9D59,0xC4C4},{0x9D5A,0xC4C5},{0x9D61,0xC4C6},{0x9D62,0xC4C7},{0x9D63,0xC4C8},{0x9D64,0xC4C9},{0x9D65,0xC4CA},{0x9D66,0xC4CB},{0x9D67,0xC4CC},{0x9D68,0xC4CD},{0x9D69,0xC4CE},{0x9D6A,0xC4CF},{0x9D6B,0xC4D0},{0x9D6C,0xC4D1},{0x9D6D,0xC4D2},{0x9D6E,0xC4D3},{0x9D6F,0xC4D4},{0x9D70,0xC4D5},{0x9D71,0xC4D6},{0x9D72,0xC4D7},{0x9D73,0xC4D8},{0x9D74,0xC4D9},{0x9D75,0xC4DA},{0x9D76,0xC4DB},{0x9D77,0xC4DC},{0x9D78,0xC4DD},{0x9D79,0xC4DE},{0x9D7A,0xC4DF},{0x9D81,0xC4E0},{0x9D82,0xC4E1},{0x9D83,0xC4E2},{0x9D84,0xC4E3},{0x9D85,0xC4E4},{0x9D86,0xC4E5},{0x9D87,0xC4E6},{0x9D88,0xC4E7},{0x9D89,0xC4E8},{0xBEB1,0xC4E9},{0x9D8A,0xC4EA},{0x9D8B,0xC4EB},{0x9D8C,0xC4EC},{0x9D8D,0xC4ED},{0x9D8E,0xC4EE},{0x9D8F,0xC4EF},{0xBEB2,0xC4F0},{0xBEB3,0xC4F1},{0x9D90,0xC4F2},{0x9D91,0xC4F3},{0xBEB4,0xC4F4},{0x9D92,0xC4F5},{0x9D93,0xC4F6},{0x9D94,0xC4F7},{0xBEB5,0xC4F8},{0x9D95,0xC4F9},{0xBEB6,0xC4FA},{0x9D96,0xC4FB},{0x9D97,0xC4FC},{0x9D98,0xC4FD},{0x9D99,0xC4FE},{0xBEB7,0xC4FF},{0xBEB8,0xC500},{0xBEB9,0xC501},{0x9D9A,0xC502},{0x9D9B,0xC503},{0x9D9C,0xC504},{0x9D9D,0xC505},{0x9D9E,0xC506},{0x9D9F,0xC507},{0x9DA0,0xC508},{0x9DA1,0xC509},{0x9DA2,0xC50A},{0x9DA3,0xC50B},{0xBEBA,0xC50C},{0x9DA4,0xC50D},{0x9DA5,0xC50E},{0x9DA6,0xC50F},{0xBEBB,0xC510},{0x9DA7,0xC511},{0x9DA8,0xC512},{0x9DA9,0xC513},{0xBEBC,0xC514},{0x9DAA,0xC515},
{0x9DAB,0xC516},{0x9DAC,0xC517},{0x9DAD,0xC518},{0x9DAE,0xC519},{0x9DAF,0xC51A},{0x9DB0,0xC51B},{0xBEBD,0xC51C},{0x9DB1,0xC51D},{0x9DB2,0xC51E},{0x9DB3,0xC51F},{0x9DB4,0xC520},{0x9DB5,0xC521},{0x9DB6,0xC522},{0x9DB7,0xC523},{0x9DB8,0xC524},{0x9DB9,0xC525},{0x9DBA,0xC526},{0x9DBB,0xC527},{0xBEBE,0xC528},{0xBEBF,0xC529},{0x9DBC,0xC52A},{0x9DBD,0xC52B},{0xBEC0,0xC52C},{0x9DBE,0xC52D},{0x9DBF,0xC52E},{0x9DC0,0xC52F},{0xBEC1,0xC530},{0x9DC1,0xC531},{0x9DC2,0xC532},{0x9DC3,0xC533},{0x9DC4,0xC534},{0x9DC5,0xC535},{0x9DC6,0xC536},{0x9DC7,0xC537},{0xBEC2,0xC538},{0xBEC3,0xC539},{0x9DC8,0xC53A},{0xBEC4,0xC53B},{0x9DC9,0xC53C},{0xBEC5,0xC53D},{0x9DCA,0xC53E},{0x9DCB,0xC53F},{0x9DCC,0xC540},{0x9DCD,0xC541},{0x9DCE,0xC542},{0x9DCF,0xC543},{0xBEC6,0xC544},{0xBEC7,0xC545},{0x9DD0,0xC546},{0x9DD1,0xC547},{0xBEC8,0xC548},{0xBEC9,0xC549},{0xBECA,0xC54A},{0x9DD2,0xC54B},{0xBECB,0xC54C},{0xBECC,0xC54D},{0xBECD,0xC54E},{0x9DD3,0xC54F},{0x9DD4,0xC550},{0x9DD5,0xC551},{0x9DD6,0xC552},{0xBECE,0xC553},{0xBECF,0xC554},{0xBED0,0xC555},{0x9DD7,0xC556},{0xBED1,0xC557},{0xBED2,0xC558},{0xBED3,0xC559},{0x9DD8,0xC55A},{0x9DD9,0xC55B},{0x9DDA,0xC55C},{0xBED4,0xC55D},{0xBED5,0xC55E},{0x9DDB,0xC55F},{0xBED6,0xC560},{0xBED7,0xC561},{0x9DDC,0xC562},{0x9DDD,0xC563},{0xBED8,0xC564},{0x9DDE,0xC565},{0x9DDF,0xC566},{0x9DE0,0xC567},{0xBED9,0xC568},{0x9DE1,0xC569},{0x9DE2,0xC56A},{0x9DE3,0xC56B},{0x9DE4,0xC56C},{0x9DE5,0xC56D},{0x9DE6,0xC56E},{0x9DE7,0xC56F},{0xBEDA,0xC570},{0xBEDB,0xC571},{0x9DE8,0xC572},{0xBEDC,0xC573},{0xBEDD,0xC574},{0xBEDE,0xC575},{0x9DE9,0xC576},{0x9DEA,0xC577},{0x9DEB,0xC578},{0x9DEC,0xC579},{0x9DED,0xC57A},{0x9DEE,0xC57B},{0xBEDF,0xC57C},{0xBEE0,0xC57D},{0x9DEF,0xC57E},{0x9DF0,0xC57F},{0xBEE1,0xC580},{0x9DF1,0xC581},{0x9DF2,0xC582},{0x9DF3,0xC583},{0xBEE2,0xC584},{0x9DF4,0xC585},{0x9DF5,0xC586},{0xBEE3,0xC587},{0x9DF6,0xC588},{0x9DF7,0xC589},{0x9DF8,0xC58A},{0x9DF9,0xC58B},{0xBEE4,0xC58C},{0xBEE5,0xC58D},{0x9DFA,0xC58E},{0xBEE6,0xC58F},{0x9DFB,0xC590},{0xBEE7,0xC591},{0x9DFC,0xC592},{0x9DFD,0xC593},{0x9DFE,0xC594},{0xBEE8,0xC595},{0x9E41,0xC596},{0xBEE9,0xC597},{0xBEEA,0xC598},{0x9E42,0xC599},{0x9E43,0xC59A},{0x9E44,0xC59B},{0xBEEB,0xC59C},{0x9E45,0xC59D},{0x9E46,0xC59E},{0x9E47,0xC59F},{0xBEEC,0xC5A0},{0x9E48,0xC5A1},{0x9E49,0xC5A2},{0x9E4A,0xC5A3},{0x9E4B,0xC5A4},{0x9E4C,0xC5A5},{0x9E4D,0xC5A6},{0x9E4E,0xC5A7},{0x9E4F,0xC5A8},{0xBEED,0xC5A9},{0x9E50,0xC5AA},{0x9E51,0xC5AB},{0x9E52,0xC5AC},{0x9E53,0xC5AD},{0x9E54,0xC5AE},{0x9E55,0xC5AF},{0x9E56,0xC5B0},{0x9E57,0xC5B1},{0x9E58,0xC5B2},{0x9E59,0xC5B3},{0xBEEE,0xC5B4},{0xBEEF,0xC5B5},{0x9E5A,0xC5B6},{0x9E61,0xC5B7},{0xBEF0,0xC5B8},{0xBEF1,0xC5B9},{0x9E62,0xC5BA},{0xBEF2,0xC5BB},{0xBEF3,0xC5BC},{0xBEF4,0xC5BD},{0xBEF5,0xC5BE},{0x9E63,0xC5BF},{0x9E64,0xC5C0},{0x9E65,0xC5C1},{0x9E66,0xC5C2},{0x9E67,0xC5C3},{0xBEF6,0xC5C4},{0xBEF7,0xC5C5},{0xBEF8,0xC5C6},{0xBEF9,0xC5C7},{0xBEFA,0xC5C8},{0xBEFB,0xC5C9},{0xBEFC,0xC5CA},{0x9E68,0xC5CB},{0xBEFD,0xC5CC},{0x9E69,0xC5CD},{0xBEFE,0xC5CE},{0x9E6A,0xC5CF},{0xBFA1,0xC5D0},{0xBFA2,0xC5D1},{0x9E6B,0xC5D2},{0x9E6C,0xC5D3},{0xBFA3,0xC5D4},{0x9E6D,0xC5D5},{0x9E6E,0xC5D6},{0x9E6F,0xC5D7},{0xBFA4,0xC5D8},{0x9E70,0xC5D9},{0x9E71,0xC5DA},{0x9E72,0xC5DB},{0x9E73,0xC5DC},{0x9E74,0xC5DD},{0x9E75,0xC5DE},{0x9E76,0xC5DF},{0xBFA5,0xC5E0},{0xBFA6,0xC5E1},{0x9E77,0xC5E2},{0xBFA7,0xC5E3},{0x9E78,0xC5E4},{0xBFA8,0xC5E5},{0x9E79,0xC5E6},{0x9E7A,0xC5E7},{0x9E81,0xC5E8},{0x9E82,0xC5E9},{0x9E83,0xC5EA},{0x9E84,0xC5EB},{0xBFA9,0xC5EC},{0xBFAA,0xC5ED},{0xBFAB,0xC5EE},{0x9E85,0xC5EF},{0xBFAC,0xC5F0},{0x9E86,0xC5F1},{0x9E87,0xC5F2},{0x9E88,0xC5F3},{0xBFAD,0xC5F4},{0x9E89,0xC5F5},{0xBFAE,0xC5F6},{0xBFAF,0xC5F7},{0x9E8A,0xC5F8},{0x9E8B,0xC5F9},{0x9E8C,0xC5FA},{0x9E8D,0xC5FB},{0xBFB0,0xC5FC},{0xBFB1,0xC5FD},{0xBFB2,0xC5FE},{0xBFB3,0xC5FF},{0xBFB4,0xC600},{0xBFB5,0xC601},{0x9E8E,0xC602},{0x9E8F,0xC603},{0x9E90,0xC604},{0xBFB6,0xC605},{0xBFB7,0xC606},{0xBFB8,0xC607},{0xBFB9,0xC608},{0x9E91,0xC609},{0x9E92,0xC60A},{0x9E93,0xC60B},{0xBFBA,0xC60C},
{0x9E94,0xC60D},{0x9E95,0xC60E},{0x9E96,0xC60F},{0xBFBB,0xC610},{0x9E97,0xC611},{0x9E98,0xC612},{0x9E99,0xC613},{0x9E9A,0xC614},{0x9E9B,0xC615},{0x9E9C,0xC616},{0x9E9D,0xC617},{0xBFBC,0xC618},{0xBFBD,0xC619},{0x9E9E,0xC61A},{0xBFBE,0xC61B},{0xBFBF,0xC61C},{0x9E9F,0xC61D},{0x9EA0,0xC61E},{0x9EA1,0xC61F},{0x9EA2,0xC620},{0x9EA3,0xC621},{0x9EA4,0xC622},{0x9EA5,0xC623},{0xBFC0,0xC624},{0xBFC1,0xC625},{0x9EA6,0xC626},{0x9EA7,0xC627},{0xBFC2,0xC628},{0x9EA8,0xC629},{0x9EA9,0xC62A},{0x9EAA,0xC62B},{0xBFC3,0xC62C},{0xBFC4,0xC62D},{0xBFC5,0xC62E},{0x9EAB,0xC62F},{0xBFC6,0xC630},{0x9EAC,0xC631},{0x9EAD,0xC632},{0xBFC7,0xC633},{0xBFC8,0xC634},{0xBFC9,0xC635},{0x9EAE,0xC636},{0xBFCA,0xC637},{0x9EAF,0xC638},{0xBFCB,0xC639},{0x9EB0,0xC63A},{0xBFCC,0xC63B},{0x9EB1,0xC63C},{0x9EB2,0xC63D},{0x9EB3,0xC63E},{0x9EB4,0xC63F},{0xBFCD,0xC640},{0xBFCE,0xC641},{0x9EB5,0xC642},{0x9EB6,0xC643},{0xBFCF,0xC644},{0x9EB7,0xC645},{0x9EB8,0xC646},{0x9EB9,0xC647},{0xBFD0,0xC648},{0x9EBA,0xC649},{0x9EBB,0xC64A},{0x9EBC,0xC64B},{0x9EBD,0xC64C},{0x9EBE,0xC64D},{0x9EBF,0xC64E},{0x9EC0,0xC64F},{0xBFD1,0xC650},{0xBFD2,0xC651},{0x9EC1,0xC652},{0xBFD3,0xC653},{0xBFD4,0xC654},{0xBFD5,0xC655},{0x9EC2,0xC656},{0x9EC3,0xC657},{0x9EC4,0xC658},{0x9EC5,0xC659},{0x9EC6,0xC65A},{0x9EC7,0xC65B},{0xBFD6,0xC65C},{0xBFD7,0xC65D},{0x9EC8,0xC65E},{0x9EC9,0xC65F},{0xBFD8,0xC660},{0x9ECA,0xC661},{0x9ECB,0xC662},{0x9ECC,0xC663},{0x9ECD,0xC664},{0x9ECE,0xC665},{0x9ECF,0xC666},{0x9ED0,0xC667},{0x9ED1,0xC668},{0x9ED2,0xC669},{0x9ED3,0xC66A},{0x9ED4,0xC66B},{0xBFD9,0xC66C},{0x9ED5,0xC66D},{0x9ED6,0xC66E},{0xBFDA,0xC66F},{0x9ED7,0xC670},{0xBFDB,0xC671},{0x9ED8,0xC672},{0x9ED9,0xC673},{0x9EDA,0xC674},{0x9EDB,0xC675},{0x9EDC,0xC676},{0x9EDD,0xC677},{0xBFDC,0xC678},{0xBFDD,0xC679},{0x9EDE,0xC67A},{0x9EDF,0xC67B},{0xBFDE,0xC67C},{0x9EE0,0xC67D},{0x9EE1,0xC67E},{0x9EE2,0xC67F},{0xBFDF,0xC680},{0x9EE3,0xC681},{0x9EE4,0xC682},{0x9EE5,0xC683},{0x9EE6,0xC684},{0x9EE7,0xC685},{0x9EE8,0xC686},{0x9EE9,0xC687},{0xBFE0,0xC688},{0xBFE1,0xC689},{0x9EEA,0xC68A},{0xBFE2,0xC68B},{0x9EEB,0xC68C},{0xBFE3,0xC68D},{0x9EEC,0xC68E},{0x9EED,0xC68F},{0x9EEE,0xC690},{0x9EEF,0xC691},{0x9EF0,0xC692},{0x9EF1,0xC693},{0xBFE4,0xC694},{0xBFE5,0xC695},{0x9EF2,0xC696},{0x9EF3,0xC697},{0xBFE6,0xC698},{0x9EF4,0xC699},{0x9EF5,0xC69A},{0x9EF6,0xC69B},{0xBFE7,0xC69C},{0x9EF7,0xC69D},{0x9EF8,0xC69E},{0x9EF9,0xC69F},{0x9EFA,0xC6A0},{0x9EFB,0xC6A1},{0x9EFC,0xC6A2},{0x9EFD,0xC6A3},{0xBFE8,0xC6A4},{0xBFE9,0xC6A5},{0x9EFE,0xC6A6},{0xBFEA,0xC6A7},{0x9F41,0xC6A8},{0xBFEB,0xC6A9},{0x9F42,0xC6AA},{0x9F43,0xC6AB},{0x9F44,0xC6AC},{0x9F45,0xC6AD},{0x9F46,0xC6AE},{0x9F47,0xC6AF},{0xBFEC,0xC6B0},{0xBFED,0xC6B1},{0x9F48,0xC6B2},{0x9F49,0xC6B3},{0xBFEE,0xC6B4},{0x9F4A,0xC6B5},{0x9F4B,0xC6B6},{0x9F4C,0xC6B7},{0xBFEF,0xC6B8},{0xBFF0,0xC6B9},{0xBFF1,0xC6BA},{0x9F4D,0xC6BB},{0x9F4E,0xC6BC},{0x9F4F,0xC6BD},{0x9F50,0xC6BE},{0x9F51,0xC6BF},{0xBFF2,0xC6C0},{0xBFF3,0xC6C1},{0x9F52,0xC6C2},{0xBFF4,0xC6C3},{0x9F53,0xC6C4},{0xBFF5,0xC6C5},{0x9F54,0xC6C6},{0x9F55,0xC6C7},{0x9F56,0xC6C8},{0x9F57,0xC6C9},{0x9F58,0xC6CA},{0x9F59,0xC6CB},{0xBFF6,0xC6CC},{0xBFF7,0xC6CD},{0x9F5A,0xC6CE},{0x9F61,0xC6CF},{0xBFF8,0xC6D0},{0x9F62,0xC6D1},{0x9F63,0xC6D2},{0x9F64,0xC6D3},{0xBFF9,0xC6D4},{0x9F65,0xC6D5},{0x9F66,0xC6D6},{0x9F67,0xC6D7},{0x9F68,0xC6D8},{0x9F69,0xC6D9},{0x9F6A,0xC6DA},{0x9F6B,0xC6DB},{0xBFFA,0xC6DC},{0xBFFB,0xC6DD},{0x9F6C,0xC6DE},{0x9F6D,0xC6DF},{0xBFFC,0xC6E0},{0xBFFD,0xC6E1},{0x9F6E,0xC6E2},{0x9F6F,0xC6E3},{0x9F70,0xC6E4},{0x9F71,0xC6E5},{0x9F72,0xC6E6},{0x9F73,0xC6E7},{0xBFFE,0xC6E8},{0xC0A1,0xC6E9},{0x9F74,0xC6EA},{0x9F75,0xC6EB},{0xC0A2,0xC6EC},{0x9F76,0xC6ED},{0x9F77,0xC6EE},{0x9F78,0xC6EF},{0xC0A3,0xC6F0},{0x9F79,0xC6F1},{0x9F7A,0xC6F2},{0x9F81,0xC6F3},{0x9F82,0xC6F4},{0x9F83,0xC6F5},{0x9F84,0xC6F6},{0x9F85,0xC6F7},{0xC0A4,0xC6F8},{0xC0A5,0xC6F9},{0x9F86,0xC6FA},{0x9F87,0xC6FB},{0x9F88,0xC6FC},{0xC0A6,0xC6FD},{0x9F89,0xC6FE},{0x9F8A,0xC6FF},{0x9F8B,0xC700},{0x9F8C,0xC701},{0x9F8D,0xC702},{0x9F8E,0xC703},
{0xC0A7,0xC704},{0xC0A8,0xC705},{0x9F8F,0xC706},{0x9F90,0xC707},{0xC0A9,0xC708},{0x9F91,0xC709},{0x9F92,0xC70A},{0x9F93,0xC70B},{0xC0AA,0xC70C},{0x9F94,0xC70D},{0x9F95,0xC70E},{0x9F96,0xC70F},{0x9F97,0xC710},{0x9F98,0xC711},{0x9F99,0xC712},{0x9F9A,0xC713},{0xC0AB,0xC714},{0xC0AC,0xC715},{0x9F9B,0xC716},{0xC0AD,0xC717},{0x9F9C,0xC718},{0xC0AE,0xC719},{0x9F9D,0xC71A},{0x9F9E,0xC71B},{0x9F9F,0xC71C},{0x9FA0,0xC71D},{0x9FA1,0xC71E},{0x9FA2,0xC71F},{0xC0AF,0xC720},{0xC0B0,0xC721},{0x9FA3,0xC722},{0x9FA4,0xC723},{0xC0B1,0xC724},{0x9FA5,0xC725},{0x9FA6,0xC726},{0x9FA7,0xC727},{0xC0B2,0xC728},{0x9FA8,0xC729},{0x9FA9,0xC72A},{0x9FAA,0xC72B},{0x9FAB,0xC72C},{0x9FAC,0xC72D},{0x9FAD,0xC72E},{0x9FAE,0xC72F},{0xC0B3,0xC730},{0xC0B4,0xC731},{0x9FAF,0xC732},{0xC0B5,0xC733},{0x9FB0,0xC734},{0xC0B6,0xC735},{0x9FB1,0xC736},{0xC0B7,0xC737},{0x9FB2,0xC738},{0x9FB3,0xC739},{0x9FB4,0xC73A},{0x9FB5,0xC73B},{0xC0B8,0xC73C},{0xC0B9,0xC73D},{0x9FB6,0xC73E},{0x9FB7,0xC73F},{0xC0BA,0xC740},{0x9FB8,0xC741},{0x9FB9,0xC742},{0x9FBA,0xC743},{0xC0BB,0xC744},{0x9FBB,0xC745},{0x9FBC,0xC746},{0x9FBD,0xC747},{0x9FBE,0xC748},{0x9FBF,0xC749},{0xC0BC,0xC74A},{0x9FC0,0xC74B},{0xC0BD,0xC74C},{0xC0BE,0xC74D},{0x9FC1,0xC74E},{0xC0BF,0xC74F},{0x9FC2,0xC750},{0xC0C0,0xC751},{0xC0C1,0xC752},{0xC0C2,0xC753},{0xC0C3,0xC754},{0xC0C4,0xC755},{0xC0C5,0xC756},{0xC0C6,0xC757},{0xC0C7,0xC758},{0x9FC3,0xC759},{0x9FC4,0xC75A},{0x9FC5,0xC75B},{0xC0C8,0xC75C},{0x9FC6,0xC75D},{0x9FC7,0xC75E},{0x9FC8,0xC75F},{0xC0C9,0xC760},{0x9FC9,0xC761},{0x9FCA,0xC762},{0x9FCB,0xC763},{0x9FCC,0xC764},{0x9FCD,0xC765},{0x9FCE,0xC766},{0x9FCF,0xC767},{0xC0CA,0xC768},{0x9FD0,0xC769},{0x9FD1,0xC76A},{0xC0CB,0xC76B},{0x9FD2,0xC76C},{0x9FD3,0xC76D},{0x9FD4,0xC76E},{0x9FD5,0xC76F},{0x9FD6,0xC770},{0x9FD7,0xC771},{0x9FD8,0xC772},{0x9FD9,0xC773},{0xC0CC,0xC774},{0xC0CD,0xC775},{0x9FDA,0xC776},{0x9FDB,0xC777},{0xC0CE,0xC778},{0x9FDC,0xC779},{0x9FDD,0xC77A},{0x9FDE,0xC77B},{0xC0CF,0xC77C},{0xC0D0,0xC77D},{0xC0D1,0xC77E},{0x9FDF,0xC77F},{0x9FE0,0xC780},{0x9FE1,0xC781},{0x9FE2,0xC782},{0xC0D2,0xC783},{0xC0D3,0xC784},{0xC0D4,0xC785},{0x9FE3,0xC786},{0xC0D5,0xC787},{0xC0D6,0xC788},{0xC0D7,0xC789},{0xC0D8,0xC78A},{0x9FE4,0xC78B},{0x9FE5,0xC78C},{0x9FE6,0xC78D},{0xC0D9,0xC78E},{0x9FE7,0xC78F},{0xC0DA,0xC790},{0xC0DB,0xC791},{0x9FE8,0xC792},{0x9FE9,0xC793},{0xC0DC,0xC794},{0x9FEA,0xC795},{0xC0DD,0xC796},{0xC0DE,0xC797},{0xC0DF,0xC798},{0x9FEB,0xC799},{0xC0E0,0xC79A},{0x9FEC,0xC79B},{0x9FED,0xC79C},{0x9FEE,0xC79D},{0x9FEF,0xC79E},{0x9FF0,0xC79F},{0xC0E1,0xC7A0},{0xC0E2,0xC7A1},{0x9FF1,0xC7A2},{0xC0E3,0xC7A3},{0xC0E4,0xC7A4},{0xC0E5,0xC7A5},{0xC0E6,0xC7A6},{0x9FF2,0xC7A7},{0x9FF3,0xC7A8},{0x9FF4,0xC7A9},{0x9FF5,0xC7AA},{0x9FF6,0xC7AB},{0xC0E7,0xC7AC},{0xC0E8,0xC7AD},{0x9FF7,0xC7AE},{0x9FF8,0xC7AF},{0xC0E9,0xC7B0},{0x9FF9,0xC7B1},{0x9FFA,0xC7B2},{0x9FFB,0xC7B3},{0xC0EA,0xC7B4},{0x9FFC,0xC7B5},{0x9FFD,0xC7B6},{0x9FFE,0xC7B7},{0xA041,0xC7B8},{0xA042,0xC7B9},{0xA043,0xC7BA},{0xA044,0xC7BB},{0xC0EB,0xC7BC},{0xC0EC,0xC7BD},{0xA045,0xC7BE},{0xC0ED,0xC7BF},{0xC0EE,0xC7C0},{0xC0EF,0xC7C1},{0xA046,0xC7C2},{0xA047,0xC7C3},{0xA048,0xC7C4},{0xA049,0xC7C5},{0xA04A,0xC7C6},{0xA04B,0xC7C7},{0xC0F0,0xC7C8},{0xC0F1,0xC7C9},{0xA04C,0xC7CA},{0xA04D,0xC7CB},{0xC0F2,0xC7CC},{0xA04E,0xC7CD},{0xC0F3,0xC7CE},{0xA04F,0xC7CF},{0xC0F4,0xC7D0},{0xA050,0xC7D1},{0xA051,0xC7D2},{0xA052,0xC7D3},{0xA053,0xC7D4},{0xA054,0xC7D5},{0xA055,0xC7D6},{0xA056,0xC7D7},{0xC0F5,0xC7D8},{0xA057,0xC7D9},{0xA058,0xC7DA},{0xA059,0xC7DB},{0xA05A,0xC7DC},{0xC0F6,0xC7DD},{0xA061,0xC7DE},{0xA062,0xC7DF},{0xA063,0xC7E0},{0xA064,0xC7E1},{0xA065,0xC7E2},{0xA066,0xC7E3},{0xC0F7,0xC7E4},{0xA067,0xC7E5},{0xA068,0xC7E6},{0xA069,0xC7E7},{0xC0F8,0xC7E8},{0xA06A,0xC7E9},{0xA06B,0xC7EA},{0xA06C,0xC7EB},{0xC0F9,0xC7EC},{0xA06D,0xC7ED},{0xA06E,0xC7EE},{0xA06F,0xC7EF},{0xA070,0xC7F0},{0xA071,0xC7F1},{0xA072,0xC7F2},{0xA073,0xC7F3},{0xA074,0xC7F4},{0xA075,0xC7F5},{0xA076,0xC7F6},{0xA077,0xC7F7},{0xA078,0xC7F8},{0xA079,0xC7F9},{0xA07A,0xC7FA},
{0xA081,0xC7FB},{0xA082,0xC7FC},{0xA083,0xC7FD},{0xA084,0xC7FE},{0xA085,0xC7FF},{0xC0FA,0xC800},{0xC0FB,0xC801},{0xA086,0xC802},{0xA087,0xC803},{0xC0FC,0xC804},{0xA088,0xC805},{0xA089,0xC806},{0xA08A,0xC807},{0xC0FD,0xC808},{0xA08B,0xC809},{0xC0FE,0xC80A},{0xA08C,0xC80B},{0xA08D,0xC80C},{0xA08E,0xC80D},{0xA08F,0xC80E},{0xA090,0xC80F},{0xC1A1,0xC810},{0xC1A2,0xC811},{0xA091,0xC812},{0xC1A3,0xC813},{0xA092,0xC814},{0xC1A4,0xC815},{0xC1A5,0xC816},{0xA093,0xC817},{0xA094,0xC818},{0xA095,0xC819},{0xA096,0xC81A},{0xA097,0xC81B},{0xC1A6,0xC81C},{0xC1A7,0xC81D},{0xA098,0xC81E},{0xA099,0xC81F},{0xC1A8,0xC820},{0xA09A,0xC821},{0xA09B,0xC822},{0xA09C,0xC823},{0xC1A9,0xC824},{0xA09D,0xC825},{0xA09E,0xC826},{0xA09F,0xC827},{0xA0A0,0xC828},{0xA0A1,0xC829},{0xA0A2,0xC82A},{0xA0A3,0xC82B},{0xC1AA,0xC82C},{0xC1AB,0xC82D},{0xA0A4,0xC82E},{0xC1AC,0xC82F},{0xA0A5,0xC830},{0xC1AD,0xC831},{0xA0A6,0xC832},{0xA0A7,0xC833},{0xA0A8,0xC834},{0xA0A9,0xC835},{0xA0AA,0xC836},{0xA0AB,0xC837},{0xC1AE,0xC838},{0xA0AC,0xC839},{0xA0AD,0xC83A},{0xA0AE,0xC83B},{0xC1AF,0xC83C},{0xA0AF,0xC83D},{0xA0B0,0xC83E},{0xA0B1,0xC83F},{0xC1B0,0xC840},{0xA0B2,0xC841},{0xA0B3,0xC842},{0xA0B4,0xC843},{0xA0B5,0xC844},{0xA0B6,0xC845},{0xA0B7,0xC846},{0xA0B8,0xC847},{0xC1B1,0xC848},{0xC1B2,0xC849},{0xA0B9,0xC84A},{0xA0BA,0xC84B},{0xC1B3,0xC84C},{0xC1B4,0xC84D},{0xA0BB,0xC84E},{0xA0BC,0xC84F},{0xA0BD,0xC850},{0xA0BE,0xC851},{0xA0BF,0xC852},{0xA0C0,0xC853},{0xC1B5,0xC854},{0xA0C1,0xC855},{0xA0C2,0xC856},{0xA0C3,0xC857},{0xA0C4,0xC858},{0xA0C5,0xC859},{0xA0C6,0xC85A},{0xA0C7,0xC85B},{0xA0C8,0xC85C},{0xA0C9,0xC85D},{0xA0CA,0xC85E},{0xA0CB,0xC85F},{0xA0CC,0xC860},{0xA0CD,0xC861},{0xA0CE,0xC862},{0xA0CF,0xC863},{0xA0D0,0xC864},{0xA0D1,0xC865},{0xA0D2,0xC866},{0xA0D3,0xC867},{0xA0D4,0xC868},{0xA0D5,0xC869},{0xA0D6,0xC86A},{0xA0D7,0xC86B},{0xA0D8,0xC86C},{0xA0D9,0xC86D},{0xA0DA,0xC86E},{0xA0DB,0xC86F},{0xC1B6,0xC870},{0xC1B7,0xC871},{0xA0DC,0xC872},{0xA0DD,0xC873},{0xC1B8,0xC874},{0xA0DE,0xC875},{0xA0DF,0xC876},{0xA0E0,0xC877},{0xC1B9,0xC878},{0xA0E1,0xC879},{0xC1BA,0xC87A},{0xA0E2,0xC87B},{0xA0E3,0xC87C},{0xA0E4,0xC87D},{0xA0E5,0xC87E},{0xA0E6,0xC87F},{0xC1BB,0xC880},{0xC1BC,0xC881},{0xA0E7,0xC882},{0xC1BD,0xC883},{0xA0E8,0xC884},{0xC1BE,0xC885},{0xC1BF,0xC886},{0xC1C0,0xC887},{0xA0E9,0xC888},{0xA0EA,0xC889},{0xA0EB,0xC88A},{0xC1C1,0xC88B},{0xC1C2,0xC88C},{0xC1C3,0xC88D},{0xA0EC,0xC88E},{0xA0ED,0xC88F},{0xA0EE,0xC890},{0xA0EF,0xC891},{0xA0F0,0xC892},{0xA0F1,0xC893},{0xC1C4,0xC894},{0xA0F2,0xC895},{0xA0F3,0xC896},{0xA0F4,0xC897},{0xA0F5,0xC898},{0xA0F6,0xC899},{0xA0F7,0xC89A},{0xA0F8,0xC89B},{0xA0F9,0xC89C},{0xC1C5,0xC89D},{0xA0FA,0xC89E},{0xC1C6,0xC89F},{0xA0FB,0xC8A0},{0xC1C7,0xC8A1},{0xA0FC,0xC8A2},{0xA0FD,0xC8A3},{0xA0FE,0xC8A4},{0xA141,0xC8A5},{0xA142,0xC8A6},{0xA143,0xC8A7},{0xC1C8,0xC8A8},{0xA144,0xC8A9},{0xA145,0xC8AA},{0xA146,0xC8AB},{0xA147,0xC8AC},{0xA148,0xC8AD},{0xA149,0xC8AE},{0xA14A,0xC8AF},{0xA14B,0xC8B0},{0xA14C,0xC8B1},{0xA14D,0xC8B2},{0xA14E,0xC8B3},{0xA14F,0xC8B4},{0xA150,0xC8B5},{0xA151,0xC8B6},{0xA152,0xC8B7},{0xA153,0xC8B8},{0xA154,0xC8B9},{0xA155,0xC8BA},{0xA156,0xC8BB},{0xC1C9,0xC8BC},{0xC1CA,0xC8BD},{0xA157,0xC8BE},{0xA158,0xC8BF},{0xA159,0xC8C0},{0xA15A,0xC8C1},{0xA161,0xC8C2},{0xA162,0xC8C3},{0xC1CB,0xC8C4},{0xA163,0xC8C5},{0xA164,0xC8C6},{0xA165,0xC8C7},{0xC1CC,0xC8C8},{0xA166,0xC8C9},{0xA167,0xC8CA},{0xA168,0xC8CB},{0xC1CD,0xC8CC},{0xA169,0xC8CD},{0xA16A,0xC8CE},{0xA16B,0xC8CF},{0xA16C,0xC8D0},{0xA16D,0xC8D1},{0xA16E,0xC8D2},{0xA16F,0xC8D3},{0xC1CE,0xC8D4},{0xC1CF,0xC8D5},{0xA170,0xC8D6},{0xC1D0,0xC8D7},{0xA171,0xC8D8},{0xC1D1,0xC8D9},{0xA172,0xC8DA},{0xA173,0xC8DB},{0xA174,0xC8DC},{0xA175,0xC8DD},{0xA176,0xC8DE},{0xA177,0xC8DF},{0xC1D2,0xC8E0},{0xC1D3,0xC8E1},{0xA178,0xC8E2},{0xA179,0xC8E3},{0xC1D4,0xC8E4},{0xA17A,0xC8E5},{0xA181,0xC8E6},{0xA182,0xC8E7},{0xA183,0xC8E8},{0xA184,0xC8E9},{0xA185,0xC8EA},{0xA186,0xC8EB},{0xA187,0xC8EC},{0xA188,0xC8ED},{0xA189,0xC8EE},{0xA18A,0xC8EF},{0xA18B,0xC8F0},{0xA18C,0xC8F1},
{0xA18D,0xC8F2},{0xA18E,0xC8F3},{0xA18F,0xC8F4},{0xC1D5,0xC8F5},{0xA190,0xC8F6},{0xA191,0xC8F7},{0xA192,0xC8F8},{0xA193,0xC8F9},{0xA194,0xC8FA},{0xA195,0xC8FB},{0xC1D6,0xC8FC},{0xC1D7,0xC8FD},{0xA196,0xC8FE},{0xA197,0xC8FF},{0xC1D8,0xC900},{0xA198,0xC901},{0xA199,0xC902},{0xA19A,0xC903},{0xC1D9,0xC904},{0xC1DA,0xC905},{0xC1DB,0xC906},{0xA19B,0xC907},{0xA19C,0xC908},{0xA19D,0xC909},{0xA19E,0xC90A},{0xA19F,0xC90B},{0xC1DC,0xC90C},{0xC1DD,0xC90D},{0xA1A0,0xC90E},{0xC1DE,0xC90F},{0xA241,0xC910},{0xC1DF,0xC911},{0xA242,0xC912},{0xA243,0xC913},{0xA244,0xC914},{0xA245,0xC915},{0xA246,0xC916},{0xA247,0xC917},{0xC1E0,0xC918},{0xA248,0xC919},{0xA249,0xC91A},{0xA24A,0xC91B},{0xA24B,0xC91C},{0xA24C,0xC91D},{0xA24D,0xC91E},{0xA24E,0xC91F},{0xA24F,0xC920},{0xA250,0xC921},{0xA251,0xC922},{0xA252,0xC923},{0xA253,0xC924},{0xA254,0xC925},{0xA255,0xC926},{0xA256,0xC927},{0xA257,0xC928},{0xA258,0xC929},{0xA259,0xC92A},{0xA25A,0xC92B},{0xC1E1,0xC92C},{0xA261,0xC92D},{0xA262,0xC92E},{0xA263,0xC92F},{0xA264,0xC930},{0xA265,0xC931},{0xA266,0xC932},{0xA267,0xC933},{0xC1E2,0xC934},{0xA268,0xC935},{0xA269,0xC936},{0xA26A,0xC937},{0xA26B,0xC938},{0xA26C,0xC939},{0xA26D,0xC93A},{0xA26E,0xC93B},{0xA26F,0xC93C},{0xA270,0xC93D},{0xA271,0xC93E},{0xA272,0xC93F},{0xA273,0xC940},{0xA274,0xC941},{0xA275,0xC942},{0xA276,0xC943},{0xA277,0xC944},{0xA278,0xC945},{0xA279,0xC946},{0xA27A,0xC947},{0xA281,0xC948},{0xA282,0xC949},{0xA283,0xC94A},{0xA284,0xC94B},{0xA285,0xC94C},{0xA286,0xC94D},{0xA287,0xC94E},{0xA288,0xC94F},{0xC1E3,0xC950},{0xC1E4,0xC951},{0xA289,0xC952},{0xA28A,0xC953},{0xC1E5,0xC954},{0xA28B,0xC955},{0xA28C,0xC956},{0xA28D,0xC957},{0xC1E6,0xC958},{0xA28E,0xC959},{0xA28F,0xC95A},{0xA290,0xC95B},{0xA291,0xC95C},{0xA292,0xC95D},{0xA293,0xC95E},{0xA294,0xC95F},{0xC1E7,0xC960},{0xC1E8,0xC961},{0xA295,0xC962},{0xC1E9,0xC963},{0xA296,0xC964},{0xA297,0xC965},{0xA298,0xC966},{0xA299,0xC967},{0xA29A,0xC968},{0xA29B,0xC969},{0xA29C,0xC96A},{0xA29D,0xC96B},{0xC1EA,0xC96C},{0xA29E,0xC96D},{0xA29F,0xC96E},{0xA2A0,0xC96F},{0xC1EB,0xC970},{0xA341,0xC971},{0xA342,0xC972},{0xA343,0xC973},{0xC1EC,0xC974},{0xA344,0xC975},{0xA345,0xC976},{0xA346,0xC977},{0xA347,0xC978},{0xA348,0xC979},{0xA349,0xC97A},{0xA34A,0xC97B},{0xC1ED,0xC97C},{0xA34B,0xC97D},{0xA34C,0xC97E},{0xA34D,0xC97F},{0xA34E,0xC980},{0xA34F,0xC981},{0xA350,0xC982},{0xA351,0xC983},{0xA352,0xC984},{0xA353,0xC985},{0xA354,0xC986},{0xA355,0xC987},{0xC1EE,0xC988},{0xC1EF,0xC989},{0xA356,0xC98A},{0xA357,0xC98B},{0xC1F0,0xC98C},{0xA358,0xC98D},{0xA359,0xC98E},{0xA35A,0xC98F},{0xC1F1,0xC990},{0xA361,0xC991},{0xA362,0xC992},{0xA363,0xC993},{0xA364,0xC994},{0xA365,0xC995},{0xA366,0xC996},{0xA367,0xC997},{0xC1F2,0xC998},{0xC1F3,0xC999},{0xA368,0xC99A},{0xC1F4,0xC99B},{0xA369,0xC99C},{0xC1F5,0xC99D},{0xA36A,0xC99E},{0xA36B,0xC99F},{0xA36C,0xC9A0},{0xA36D,0xC9A1},{0xA36E,0xC9A2},{0xA36F,0xC9A3},{0xA370,0xC9A4},{0xA371,0xC9A5},{0xA372,0xC9A6},{0xA373,0xC9A7},{0xA374,0xC9A8},{0xA375,0xC9A9},{0xA376,0xC9AA},{0xA377,0xC9AB},{0xA378,0xC9AC},{0xA379,0xC9AD},{0xA37A,0xC9AE},{0xA381,0xC9AF},{0xA382,0xC9B0},{0xA383,0xC9B1},{0xA384,0xC9B2},{0xA385,0xC9B3},{0xA386,0xC9B4},{0xA387,0xC9B5},{0xA388,0xC9B6},{0xA389,0xC9B7},{0xA38A,0xC9B8},{0xA38B,0xC9B9},{0xA38C,0xC9BA},{0xA38D,0xC9BB},{0xA38E,0xC9BC},{0xA38F,0xC9BD},{0xA390,0xC9BE},{0xA391,0xC9BF},{0xC1F6,0xC9C0},{0xC1F7,0xC9C1},{0xA392,0xC9C2},{0xA393,0xC9C3},{0xC1F8,0xC9C4},{0xA394,0xC9C5},{0xA395,0xC9C6},{0xC1F9,0xC9C7},{0xC1FA,0xC9C8},{0xA396,0xC9C9},{0xC1FB,0xC9CA},{0xA397,0xC9CB},{0xA398,0xC9CC},{0xA399,0xC9CD},{0xA39A,0xC9CE},{0xA39B,0xC9CF},{0xC1FC,0xC9D0},{0xC1FD,0xC9D1},{0xA39C,0xC9D2},{0xC1FE,0xC9D3},{0xA39D,0xC9D4},{0xC2A1,0xC9D5},{0xC2A2,0xC9D6},{0xA39E,0xC9D7},{0xA39F,0xC9D8},{0xC2A3,0xC9D9},{0xC2A4,0xC9DA},{0xA3A0,0xC9DB},{0xC2A5,0xC9DC},{0xC2A6,0xC9DD},{0xA441,0xC9DE},{0xA442,0xC9DF},{0xC2A7,0xC9E0},{0xA443,0xC9E1},{0xC2A8,0xC9E2},{0xA444,0xC9E3},{0xC2A9,0xC9E4},{0xA445,0xC9E5},{0xA446,0xC9E6},{0xC2AA,0xC9E7},{0xA447,0xC9E8},
{0xA448,0xC9E9},{0xA449,0xC9EA},{0xA44A,0xC9EB},{0xC2AB,0xC9EC},{0xC2AC,0xC9ED},{0xA44B,0xC9EE},{0xC2AD,0xC9EF},{0xC2AE,0xC9F0},{0xC2AF,0xC9F1},{0xA44C,0xC9F2},{0xA44D,0xC9F3},{0xA44E,0xC9F4},{0xA44F,0xC9F5},{0xA450,0xC9F6},{0xA451,0xC9F7},{0xC2B0,0xC9F8},{0xC2B1,0xC9F9},{0xA452,0xC9FA},{0xA453,0xC9FB},{0xC2B2,0xC9FC},{0xA454,0xC9FD},{0xA455,0xC9FE},{0xA456,0xC9FF},{0xC2B3,0xCA00},{0xA457,0xCA01},{0xA458,0xCA02},{0xA459,0xCA03},{0xA45A,0xCA04},{0xA461,0xCA05},{0xA462,0xCA06},{0xA463,0xCA07},{0xC2B4,0xCA08},{0xC2B5,0xCA09},{0xA464,0xCA0A},{0xC2B6,0xCA0B},{0xC2B7,0xCA0C},{0xC2B8,0xCA0D},{0xA465,0xCA0E},{0xA466,0xCA0F},{0xA467,0xCA10},{0xA468,0xCA11},{0xA469,0xCA12},{0xA46A,0xCA13},{0xC2B9,0xCA14},{0xA46B,0xCA15},{0xA46C,0xCA16},{0xA46D,0xCA17},{0xC2BA,0xCA18},{0xA46E,0xCA19},{0xA46F,0xCA1A},{0xA470,0xCA1B},{0xA471,0xCA1C},{0xA472,0xCA1D},{0xA473,0xCA1E},{0xA474,0xCA1F},{0xA475,0xCA20},{0xA476,0xCA21},{0xA477,0xCA22},{0xA478,0xCA23},{0xA479,0xCA24},{0xA47A,0xCA25},{0xA481,0xCA26},{0xA482,0xCA27},{0xA483,0xCA28},{0xC2BB,0xCA29},{0xA484,0xCA2A},{0xA485,0xCA2B},{0xA486,0xCA2C},{0xA487,0xCA2D},{0xA488,0xCA2E},{0xA489,0xCA2F},{0xA48A,0xCA30},{0xA48B,0xCA31},{0xA48C,0xCA32},{0xA48D,0xCA33},{0xA48E,0xCA34},{0xA48F,0xCA35},{0xA490,0xCA36},{0xA491,0xCA37},{0xA492,0xCA38},{0xA493,0xCA39},{0xA494,0xCA3A},{0xA495,0xCA3B},{0xA496,0xCA3C},{0xA497,0xCA3D},{0xA498,0xCA3E},{0xA499,0xCA3F},{0xA49A,0xCA40},{0xA49B,0xCA41},{0xA49C,0xCA42},{0xA49D,0xCA43},{0xA49E,0xCA44},{0xA49F,0xCA45},{0xA4A0,0xCA46},{0xA541,0xCA47},{0xA542,0xCA48},{0xA543,0xCA49},{0xA544,0xCA4A},{0xA545,0xCA4B},{0xC2BC,0xCA4C},{0xC2BD,0xCA4D},{0xA546,0xCA4E},{0xA547,0xCA4F},{0xC2BE,0xCA50},{0xA548,0xCA51},{0xA549,0xCA52},{0xA54A,0xCA53},{0xC2BF,0xCA54},{0xA54B,0xCA55},{0xA54C,0xCA56},{0xA54D,0xCA57},{0xA54E,0xCA58},{0xA54F,0xCA59},{0xA550,0xCA5A},{0xA551,0xCA5B},{0xC2C0,0xCA5C},{0xC2C1,0xCA5D},{0xA552,0xCA5E},{0xC2C2,0xCA5F},{0xC2C3,0xCA60},{0xC2C4,0xCA61},{0xA553,0xCA62},{0xA554,0xCA63},{0xA555,0xCA64},{0xA556,0xCA65},{0xA557,0xCA66},{0xA558,0xCA67},{0xC2C5,0xCA68},{0xA559,0xCA69},{0xA55A,0xCA6A},{0xA561,0xCA6B},{0xA562,0xCA6C},{0xA563,0xCA6D},{0xA564,0xCA6E},{0xA565,0xCA6F},{0xA566,0xCA70},{0xA567,0xCA71},{0xA568,0xCA72},{0xA569,0xCA73},{0xA56A,0xCA74},{0xA56B,0xCA75},{0xA56C,0xCA76},{0xA56D,0xCA77},{0xA56E,0xCA78},{0xA56F,0xCA79},{0xA570,0xCA7A},{0xA571,0xCA7B},{0xA572,0xCA7C},{0xC2C6,0xCA7D},{0xA573,0xCA7E},{0xA574,0xCA7F},{0xA575,0xCA80},{0xA576,0xCA81},{0xA577,0xCA82},{0xA578,0xCA83},{0xC2C7,0xCA84},{0xA579,0xCA85},{0xA57A,0xCA86},{0xA581,0xCA87},{0xA582,0xCA88},{0xA583,0xCA89},{0xA584,0xCA8A},{0xA585,0xCA8B},{0xA586,0xCA8C},{0xA587,0xCA8D},{0xA588,0xCA8E},{0xA589,0xCA8F},{0xA58A,0xCA90},{0xA58B,0xCA91},{0xA58C,0xCA92},{0xA58D,0xCA93},{0xA58E,0xCA94},{0xA58F,0xCA95},{0xA590,0xCA96},{0xA591,0xCA97},{0xC2C8,0xCA98},{0xA592,0xCA99},{0xA593,0xCA9A},{0xA594,0xCA9B},{0xA595,0xCA9C},{0xA596,0xCA9D},{0xA597,0xCA9E},{0xA598,0xCA9F},{0xA599,0xCAA0},{0xA59A,0xCAA1},{0xA59B,0xCAA2},{0xA59C,0xCAA3},{0xA59D,0xCAA4},{0xA59E,0xCAA5},{0xA59F,0xCAA6},{0xA5A0,0xCAA7},{0xA641,0xCAA8},{0xA642,0xCAA9},{0xA643,0xCAAA},{0xA644,0xCAAB},{0xA645,0xCAAC},{0xA646,0xCAAD},{0xA647,0xCAAE},{0xA648,0xCAAF},{0xA649,0xCAB0},{0xA64A,0xCAB1},{0xA64B,0xCAB2},{0xA64C,0xCAB3},{0xA64D,0xCAB4},{0xA64E,0xCAB5},{0xA64F,0xCAB6},{0xA650,0xCAB7},{0xA651,0xCAB8},{0xA652,0xCAB9},{0xA653,0xCABA},{0xA654,0xCABB},{0xC2C9,0xCABC},{0xC2CA,0xCABD},{0xA655,0xCABE},{0xA656,0xCABF},{0xC2CB,0xCAC0},{0xA657,0xCAC1},{0xA658,0xCAC2},{0xA659,0xCAC3},{0xC2CC,0xCAC4},{0xA65A,0xCAC5},{0xA661,0xCAC6},{0xA662,0xCAC7},{0xA663,0xCAC8},{0xA664,0xCAC9},{0xA665,0xCACA},{0xA666,0xCACB},{0xC2CD,0xCACC},{0xC2CE,0xCACD},{0xA667,0xCACE},{0xC2CF,0xCACF},{0xA668,0xCAD0},{0xC2D0,0xCAD1},{0xA669,0xCAD2},{0xC2D1,0xCAD3},{0xA66A,0xCAD4},{0xA66B,0xCAD5},{0xA66C,0xCAD6},{0xA66D,0xCAD7},{0xC2D2,0xCAD8},{0xC2D3,0xCAD9},{0xA66E,0xCADA},{0xA66F,0xCADB},{0xA670,0xCADC},{0xA671,0xCADD},{0xA672,0xCADE},{0xA673,0xCADF},
{0xC2D4,0xCAE0},{0xA674,0xCAE1},{0xA675,0xCAE2},{0xA676,0xCAE3},{0xA677,0xCAE4},{0xA678,0xCAE5},{0xA679,0xCAE6},{0xA67A,0xCAE7},{0xA681,0xCAE8},{0xA682,0xCAE9},{0xA683,0xCAEA},{0xA684,0xCAEB},{0xC2D5,0xCAEC},{0xA685,0xCAED},{0xA686,0xCAEE},{0xA687,0xCAEF},{0xA688,0xCAF0},{0xA689,0xCAF1},{0xA68A,0xCAF2},{0xA68B,0xCAF3},{0xC2D6,0xCAF4},{0xA68C,0xCAF5},{0xA68D,0xCAF6},{0xA68E,0xCAF7},{0xA68F,0xCAF8},{0xA690,0xCAF9},{0xA691,0xCAFA},{0xA692,0xCAFB},{0xA693,0xCAFC},{0xA694,0xCAFD},{0xA695,0xCAFE},{0xA696,0xCAFF},{0xA697,0xCB00},{0xA698,0xCB01},{0xA699,0xCB02},{0xA69A,0xCB03},{0xA69B,0xCB04},{0xA69C,0xCB05},{0xA69D,0xCB06},{0xA69E,0xCB07},{0xC2D7,0xCB08},{0xA69F,0xCB09},{0xA6A0,0xCB0A},{0xA741,0xCB0B},{0xA742,0xCB0C},{0xA743,0xCB0D},{0xA744,0xCB0E},{0xA745,0xCB0F},{0xC2D8,0xCB10},{0xA746,0xCB11},{0xA747,0xCB12},{0xA748,0xCB13},{0xC2D9,0xCB14},{0xA749,0xCB15},{0xA74A,0xCB16},{0xA74B,0xCB17},{0xC2DA,0xCB18},{0xA74C,0xCB19},{0xA74D,0xCB1A},{0xA74E,0xCB1B},{0xA74F,0xCB1C},{0xA750,0xCB1D},{0xA751,0xCB1E},{0xA752,0xCB1F},{0xC2DB,0xCB20},{0xC2DC,0xCB21},{0xA753,0xCB22},{0xA754,0xCB23},{0xA755,0xCB24},{0xA756,0xCB25},{0xA757,0xCB26},{0xA758,0xCB27},{0xA759,0xCB28},{0xA75A,0xCB29},{0xA761,0xCB2A},{0xA762,0xCB2B},{0xA763,0xCB2C},{0xA764,0xCB2D},{0xA765,0xCB2E},{0xA766,0xCB2F},{0xA767,0xCB30},{0xA768,0xCB31},{0xA769,0xCB32},{0xA76A,0xCB33},{0xA76B,0xCB34},{0xA76C,0xCB35},{0xA76D,0xCB36},{0xA76E,0xCB37},{0xA76F,0xCB38},{0xA770,0xCB39},{0xA771,0xCB3A},{0xA772,0xCB3B},{0xA773,0xCB3C},{0xA774,0xCB3D},{0xA775,0xCB3E},{0xA776,0xCB3F},{0xA777,0xCB40},{0xC2DD,0xCB41},{0xA778,0xCB42},{0xA779,0xCB43},{0xA77A,0xCB44},{0xA781,0xCB45},{0xA782,0xCB46},{0xA783,0xCB47},{0xC2DE,0xCB48},{0xC2DF,0xCB49},{0xA784,0xCB4A},{0xA785,0xCB4B},{0xC2E0,0xCB4C},{0xA786,0xCB4D},{0xA787,0xCB4E},{0xA788,0xCB4F},{0xC2E1,0xCB50},{0xA789,0xCB51},{0xA78A,0xCB52},{0xA78B,0xCB53},{0xA78C,0xCB54},{0xA78D,0xCB55},{0xA78E,0xCB56},{0xA78F,0xCB57},{0xC2E2,0xCB58},{0xC2E3,0xCB59},{0xA790,0xCB5A},{0xA791,0xCB5B},{0xA792,0xCB5C},{0xC2E4,0xCB5D},{0xA793,0xCB5E},{0xA794,0xCB5F},{0xA795,0xCB60},{0xA796,0xCB61},{0xA797,0xCB62},{0xA798,0xCB63},{0xC2E5,0xCB64},{0xA799,0xCB65},{0xA79A,0xCB66},{0xA79B,0xCB67},{0xA79C,0xCB68},{0xA79D,0xCB69},{0xA79E,0xCB6A},{0xA79F,0xCB6B},{0xA7A0,0xCB6C},{0xA841,0xCB6D},{0xA842,0xCB6E},{0xA843,0xCB6F},{0xA844,0xCB70},{0xA845,0xCB71},{0xA846,0xCB72},{0xA847,0xCB73},{0xA848,0xCB74},{0xA849,0xCB75},{0xA84A,0xCB76},{0xA84B,0xCB77},{0xC2E6,0xCB78},{0xC2E7,0xCB79},{0xA84C,0xCB7A},{0xA84D,0xCB7B},{0xA84E,0xCB7C},{0xA84F,0xCB7D},{0xA850,0xCB7E},{0xA851,0xCB7F},{0xA852,0xCB80},{0xA853,0xCB81},{0xA854,0xCB82},{0xA855,0xCB83},{0xA856,0xCB84},{0xA857,0xCB85},{0xA858,0xCB86},{0xA859,0xCB87},{0xA85A,0xCB88},{0xA861,0xCB89},{0xA862,0xCB8A},{0xA863,0xCB8B},{0xA864,0xCB8C},{0xA865,0xCB8D},{0xA866,0xCB8E},{0xA867,0xCB8F},{0xA868,0xCB90},{0xA869,0xCB91},{0xA86A,0xCB92},{0xA86B,0xCB93},{0xA86C,0xCB94},{0xA86D,0xCB95},{0xA86E,0xCB96},{0xA86F,0xCB97},{0xA870,0xCB98},{0xA871,0xCB99},{0xA872,0xCB9A},{0xA873,0xCB9B},{0xC2E8,0xCB9C},{0xA874,0xCB9D},{0xA875,0xCB9E},{0xA876,0xCB9F},{0xA877,0xCBA0},{0xA878,0xCBA1},{0xA879,0xCBA2},{0xA87A,0xCBA3},{0xA881,0xCBA4},{0xA882,0xCBA5},{0xA883,0xCBA6},{0xA884,0xCBA7},{0xA885,0xCBA8},{0xA886,0xCBA9},{0xA887,0xCBAA},{0xA888,0xCBAB},{0xA889,0xCBAC},{0xA88A,0xCBAD},{0xA88B,0xCBAE},{0xA88C,0xCBAF},{0xA88D,0xCBB0},{0xA88E,0xCBB1},{0xA88F,0xCBB2},{0xA890,0xCBB3},{0xA891,0xCBB4},{0xA892,0xCBB5},{0xA893,0xCBB6},{0xA894,0xCBB7},{0xC2E9,0xCBB8},{0xA895,0xCBB9},{0xA896,0xCBBA},{0xA897,0xCBBB},{0xA898,0xCBBC},{0xA899,0xCBBD},{0xA89A,0xCBBE},{0xA89B,0xCBBF},{0xA89C,0xCBC0},{0xA89D,0xCBC1},{0xA89E,0xCBC2},{0xA89F,0xCBC3},{0xA8A0,0xCBC4},{0xA941,0xCBC5},{0xA942,0xCBC6},{0xA943,0xCBC7},{0xA944,0xCBC8},{0xA945,0xCBC9},{0xA946,0xCBCA},{0xA947,0xCBCB},{0xA948,0xCBCC},{0xA949,0xCBCD},{0xA94A,0xCBCE},{0xA94B,0xCBCF},{0xA94C,0xCBD0},{0xA94D,0xCBD1},{0xA94E,0xCBD2},{0xA94F,0xCBD3},{0xC2EA,0xCBD4},{0xA950,0xCBD5},{0xA951,0xCBD6},
{0xA952,0xCBD7},{0xA953,0xCBD8},{0xA954,0xCBD9},{0xA955,0xCBDA},{0xA956,0xCBDB},{0xA957,0xCBDC},{0xA958,0xCBDD},{0xA959,0xCBDE},{0xA95A,0xCBDF},{0xA961,0xCBE0},{0xA962,0xCBE1},{0xA963,0xCBE2},{0xA964,0xCBE3},{0xC2EB,0xCBE4},{0xA965,0xCBE5},{0xA966,0xCBE6},{0xC2EC,0xCBE7},{0xA967,0xCBE8},{0xC2ED,0xCBE9},{0xA968,0xCBEA},{0xA969,0xCBEB},{0xA96A,0xCBEC},{0xA96B,0xCBED},{0xA96C,0xCBEE},{0xA96D,0xCBEF},{0xA96E,0xCBF0},{0xA96F,0xCBF1},{0xA970,0xCBF2},{0xA971,0xCBF3},{0xA972,0xCBF4},{0xA973,0xCBF5},{0xA974,0xCBF6},{0xA975,0xCBF7},{0xA976,0xCBF8},{0xA977,0xCBF9},{0xA978,0xCBFA},{0xA979,0xCBFB},{0xA97A,0xCBFC},{0xA981,0xCBFD},{0xA982,0xCBFE},{0xA983,0xCBFF},{0xA984,0xCC00},{0xA985,0xCC01},{0xA986,0xCC02},{0xA987,0xCC03},{0xA988,0xCC04},{0xA989,0xCC05},{0xA98A,0xCC06},{0xA98B,0xCC07},{0xA98C,0xCC08},{0xA98D,0xCC09},{0xA98E,0xCC0A},{0xA98F,0xCC0B},{0xC2EE,0xCC0C},{0xC2EF,0xCC0D},{0xA990,0xCC0E},{0xA991,0xCC0F},{0xC2F0,0xCC10},{0xA992,0xCC11},{0xA993,0xCC12},{0xA994,0xCC13},{0xC2F1,0xCC14},{0xA995,0xCC15},{0xA996,0xCC16},{0xA997,0xCC17},{0xA998,0xCC18},{0xA999,0xCC19},{0xA99A,0xCC1A},{0xA99B,0xCC1B},{0xC2F2,0xCC1C},{0xC2F3,0xCC1D},{0xA99C,0xCC1E},{0xA99D,0xCC1F},{0xA99E,0xCC20},{0xC2F4,0xCC21},{0xC2F5,0xCC22},{0xA99F,0xCC23},{0xA9A0,0xCC24},{0xAA41,0xCC25},{0xAA42,0xCC26},{0xC2F6,0xCC27},{0xC2F7,0xCC28},{0xC2F8,0xCC29},{0xAA43,0xCC2A},{0xAA44,0xCC2B},{0xC2F9,0xCC2C},{0xAA45,0xCC2D},{0xC2FA,0xCC2E},{0xAA46,0xCC2F},{0xC2FB,0xCC30},{0xAA47,0xCC31},{0xAA48,0xCC32},{0xAA49,0xCC33},{0xAA4A,0xCC34},{0xAA4B,0xCC35},{0xAA4C,0xCC36},{0xAA4D,0xCC37},{0xC2FC,0xCC38},{0xC2FD,0xCC39},{0xAA4E,0xCC3A},{0xC2FE,0xCC3B},{0xC3A1,0xCC3C},{0xC3A2,0xCC3D},{0xC3A3,0xCC3E},{0xAA4F,0xCC3F},{0xAA50,0xCC40},{0xAA51,0xCC41},{0xAA52,0xCC42},{0xAA53,0xCC43},{0xC3A4,0xCC44},{0xC3A5,0xCC45},{0xAA54,0xCC46},{0xAA55,0xCC47},{0xC3A6,0xCC48},{0xAA56,0xCC49},{0xAA57,0xCC4A},{0xAA58,0xCC4B},{0xC3A7,0xCC4C},{0xAA59,0xCC4D},{0xAA5A,0xCC4E},{0xAA61,0xCC4F},{0xAA62,0xCC50},{0xAA63,0xCC51},{0xAA64,0xCC52},{0xAA65,0xCC53},{0xC3A8,0xCC54},{0xC3A9,0xCC55},{0xAA66,0xCC56},{0xC3AA,0xCC57},{0xC3AB,0xCC58},{0xC3AC,0xCC59},{0xAA67,0xCC5A},{0xAA68,0xCC5B},{0xAA69,0xCC5C},{0xAA6A,0xCC5D},{0xAA6B,0xCC5E},{0xAA6C,0xCC5F},{0xC3AD,0xCC60},{0xAA6D,0xCC61},{0xAA6E,0xCC62},{0xAA6F,0xCC63},{0xC3AE,0xCC64},{0xAA70,0xCC65},{0xC3AF,0xCC66},{0xAA71,0xCC67},{0xC3B0,0xCC68},{0xAA72,0xCC69},{0xAA73,0xCC6A},{0xAA74,0xCC6B},{0xAA75,0xCC6C},{0xAA76,0xCC6D},{0xAA77,0xCC6E},{0xAA78,0xCC6F},{0xC3B1,0xCC70},{0xAA79,0xCC71},{0xAA7A,0xCC72},{0xAA81,0xCC73},{0xAA82,0xCC74},{0xC3B2,0xCC75},{0xAA83,0xCC76},{0xAA84,0xCC77},{0xAA85,0xCC78},{0xAA86,0xCC79},{0xAA87,0xCC7A},{0xAA88,0xCC7B},{0xAA89,0xCC7C},{0xAA8A,0xCC7D},{0xAA8B,0xCC7E},{0xAA8C,0xCC7F},{0xAA8D,0xCC80},{0xAA8E,0xCC81},{0xAA8F,0xCC82},{0xAA90,0xCC83},{0xAA91,0xCC84},{0xAA92,0xCC85},{0xAA93,0xCC86},{0xAA94,0xCC87},{0xAA95,0xCC88},{0xAA96,0xCC89},{0xAA97,0xCC8A},{0xAA98,0xCC8B},{0xAA99,0xCC8C},{0xAA9A,0xCC8D},{0xAA9B,0xCC8E},{0xAA9C,0xCC8F},{0xAA9D,0xCC90},{0xAA9E,0xCC91},{0xAA9F,0xCC92},{0xAAA0,0xCC93},{0xAB41,0xCC94},{0xAB42,0xCC95},{0xAB43,0xCC96},{0xAB44,0xCC97},{0xC3B3,0xCC98},{0xC3B4,0xCC99},{0xAB45,0xCC9A},{0xAB46,0xCC9B},{0xC3B5,0xCC9C},{0xAB47,0xCC9D},{0xAB48,0xCC9E},{0xAB49,0xCC9F},{0xC3B6,0xCCA0},{0xAB4A,0xCCA1},{0xAB4B,0xCCA2},{0xAB4C,0xCCA3},{0xAB4D,0xCCA4},{0xAB4E,0xCCA5},{0xAB4F,0xCCA6},{0xAB50,0xCCA7},{0xC3B7,0xCCA8},{0xC3B8,0xCCA9},{0xAB51,0xCCAA},{0xC3B9,0xCCAB},{0xC3BA,0xCCAC},{0xC3BB,0xCCAD},{0xAB52,0xCCAE},{0xAB53,0xCCAF},{0xAB54,0xCCB0},{0xAB55,0xCCB1},{0xAB56,0xCCB2},{0xAB57,0xCCB3},{0xC3BC,0xCCB4},{0xC3BD,0xCCB5},{0xAB58,0xCCB6},{0xAB59,0xCCB7},{0xC3BE,0xCCB8},{0xAB5A,0xCCB9},{0xAB61,0xCCBA},{0xAB62,0xCCBB},{0xC3BF,0xCCBC},{0xAB63,0xCCBD},{0xAB64,0xCCBE},{0xAB65,0xCCBF},{0xAB66,0xCCC0},{0xAB67,0xCCC1},{0xAB68,0xCCC2},{0xAB69,0xCCC3},{0xC3C0,0xCCC4},{0xC3C1,0xCCC5},{0xAB6A,0xCCC6},{0xC3C2,0xCCC7},{0xAB6B,0xCCC8},{0xC3C3,0xCCC9},{0xAB6C,0xCCCA},{0xAB6D,0xCCCB},{0xAB6E,0xCCCC},{0xAB6F,0xCCCD},
{0xAB70,0xCCCE},{0xAB71,0xCCCF},{0xC3C4,0xCCD0},{0xAB72,0xCCD1},{0xAB73,0xCCD2},{0xAB74,0xCCD3},{0xC3C5,0xCCD4},{0xAB75,0xCCD5},{0xAB76,0xCCD6},{0xAB77,0xCCD7},{0xAB78,0xCCD8},{0xAB79,0xCCD9},{0xAB7A,0xCCDA},{0xAB81,0xCCDB},{0xAB82,0xCCDC},{0xAB83,0xCCDD},{0xAB84,0xCCDE},{0xAB85,0xCCDF},{0xAB86,0xCCE0},{0xAB87,0xCCE1},{0xAB88,0xCCE2},{0xAB89,0xCCE3},{0xC3C6,0xCCE4},{0xAB8A,0xCCE5},{0xAB8B,0xCCE6},{0xAB8C,0xCCE7},{0xAB8D,0xCCE8},{0xAB8E,0xCCE9},{0xAB8F,0xCCEA},{0xAB90,0xCCEB},{0xC3C7,0xCCEC},{0xAB91,0xCCED},{0xAB92,0xCCEE},{0xAB93,0xCCEF},{0xC3C8,0xCCF0},{0xAB94,0xCCF1},{0xAB95,0xCCF2},{0xAB96,0xCCF3},{0xAB97,0xCCF4},{0xAB98,0xCCF5},{0xAB99,0xCCF6},{0xAB9A,0xCCF7},{0xAB9B,0xCCF8},{0xAB9C,0xCCF9},{0xAB9D,0xCCFA},{0xAB9E,0xCCFB},{0xAB9F,0xCCFC},{0xABA0,0xCCFD},{0xAC41,0xCCFE},{0xAC42,0xCCFF},{0xAC43,0xCD00},{0xC3C9,0xCD01},{0xAC44,0xCD02},{0xAC45,0xCD03},{0xAC46,0xCD04},{0xAC47,0xCD05},{0xAC48,0xCD06},{0xAC49,0xCD07},{0xC3CA,0xCD08},{0xC3CB,0xCD09},{0xAC4A,0xCD0A},{0xAC4B,0xCD0B},{0xC3CC,0xCD0C},{0xAC4C,0xCD0D},{0xAC4D,0xCD0E},{0xAC4E,0xCD0F},{0xC3CD,0xCD10},{0xAC4F,0xCD11},{0xAC50,0xCD12},{0xAC51,0xCD13},{0xAC52,0xCD14},{0xAC53,0xCD15},{0xAC54,0xCD16},{0xAC55,0xCD17},{0xC3CE,0xCD18},{0xC3CF,0xCD19},{0xAC56,0xCD1A},{0xC3D0,0xCD1B},{0xAC57,0xCD1C},{0xC3D1,0xCD1D},{0xAC58,0xCD1E},{0xAC59,0xCD1F},{0xAC5A,0xCD20},{0xAC61,0xCD21},{0xAC62,0xCD22},{0xAC63,0xCD23},{0xC3D2,0xCD24},{0xAC64,0xCD25},{0xAC65,0xCD26},{0xAC66,0xCD27},{0xC3D3,0xCD28},{0xAC67,0xCD29},{0xAC68,0xCD2A},{0xAC69,0xCD2B},{0xC3D4,0xCD2C},{0xAC6A,0xCD2D},{0xAC6B,0xCD2E},{0xAC6C,0xCD2F},{0xAC6D,0xCD30},{0xAC6E,0xCD31},{0xAC6F,0xCD32},{0xAC70,0xCD33},{0xAC71,0xCD34},{0xAC72,0xCD35},{0xAC73,0xCD36},{0xAC74,0xCD37},{0xAC75,0xCD38},{0xC3D5,0xCD39},{0xAC76,0xCD3A},{0xAC77,0xCD3B},{0xAC78,0xCD3C},{0xAC79,0xCD3D},{0xAC7A,0xCD3E},{0xAC81,0xCD3F},{0xAC82,0xCD40},{0xAC83,0xCD41},{0xAC84,0xCD42},{0xAC85,0xCD43},{0xAC86,0xCD44},{0xAC87,0xCD45},{0xAC88,0xCD46},{0xAC89,0xCD47},{0xAC8A,0xCD48},{0xAC8B,0xCD49},{0xAC8C,0xCD4A},{0xAC8D,0xCD4B},{0xAC8E,0xCD4C},{0xAC8F,0xCD4D},{0xAC90,0xCD4E},{0xAC91,0xCD4F},{0xAC92,0xCD50},{0xAC93,0xCD51},{0xAC94,0xCD52},{0xAC95,0xCD53},{0xAC96,0xCD54},{0xAC97,0xCD55},{0xAC98,0xCD56},{0xAC99,0xCD57},{0xAC9A,0xCD58},{0xAC9B,0xCD59},{0xAC9C,0xCD5A},{0xAC9D,0xCD5B},{0xC3D6,0xCD5C},{0xAC9E,0xCD5D},{0xAC9F,0xCD5E},{0xACA0,0xCD5F},{0xC3D7,0xCD60},{0xAD41,0xCD61},{0xAD42,0xCD62},{0xAD43,0xCD63},{0xC3D8,0xCD64},{0xAD44,0xCD65},{0xAD45,0xCD66},{0xAD46,0xCD67},{0xAD47,0xCD68},{0xAD48,0xCD69},{0xAD49,0xCD6A},{0xAD4A,0xCD6B},{0xC3D9,0xCD6C},{0xC3DA,0xCD6D},{0xAD4B,0xCD6E},{0xC3DB,0xCD6F},{0xAD4C,0xCD70},{0xC3DC,0xCD71},{0xAD4D,0xCD72},{0xAD4E,0xCD73},{0xAD4F,0xCD74},{0xAD50,0xCD75},{0xAD51,0xCD76},{0xAD52,0xCD77},{0xC3DD,0xCD78},{0xAD53,0xCD79},{0xAD54,0xCD7A},{0xAD55,0xCD7B},{0xAD56,0xCD7C},{0xAD57,0xCD7D},{0xAD58,0xCD7E},{0xAD59,0xCD7F},{0xAD5A,0xCD80},{0xAD61,0xCD81},{0xAD62,0xCD82},{0xAD63,0xCD83},{0xAD64,0xCD84},{0xAD65,0xCD85},{0xAD66,0xCD86},{0xAD67,0xCD87},{0xC3DE,0xCD88},{0xAD68,0xCD89},{0xAD69,0xCD8A},{0xAD6A,0xCD8B},{0xAD6B,0xCD8C},{0xAD6C,0xCD8D},{0xAD6D,0xCD8E},{0xAD6E,0xCD8F},{0xAD6F,0xCD90},{0xAD70,0xCD91},{0xAD71,0xCD92},{0xAD72,0xCD93},{0xC3DF,0xCD94},{0xC3E0,0xCD95},{0xAD73,0xCD96},{0xAD74,0xCD97},{0xC3E1,0xCD98},{0xAD75,0xCD99},{0xAD76,0xCD9A},{0xAD77,0xCD9B},{0xC3E2,0xCD9C},{0xAD78,0xCD9D},{0xAD79,0xCD9E},{0xAD7A,0xCD9F},{0xAD81,0xCDA0},{0xAD82,0xCDA1},{0xAD83,0xCDA2},{0xAD84,0xCDA3},{0xC3E3,0xCDA4},{0xC3E4,0xCDA5},{0xAD85,0xCDA6},{0xC3E5,0xCDA7},{0xAD86,0xCDA8},{0xC3E6,0xCDA9},{0xAD87,0xCDAA},{0xAD88,0xCDAB},{0xAD89,0xCDAC},{0xAD8A,0xCDAD},{0xAD8B,0xCDAE},{0xAD8C,0xCDAF},{0xC3E7,0xCDB0},{0xAD8D,0xCDB1},{0xAD8E,0xCDB2},{0xAD8F,0xCDB3},{0xAD90,0xCDB4},{0xAD91,0xCDB5},{0xAD92,0xCDB6},{0xAD93,0xCDB7},{0xAD94,0xCDB8},{0xAD95,0xCDB9},{0xAD96,0xCDBA},{0xAD97,0xCDBB},{0xAD98,0xCDBC},{0xAD99,0xCDBD},{0xAD9A,0xCDBE},{0xAD9B,0xCDBF},{0xAD9C,0xCDC0},{0xAD9D,0xCDC1},{0xAD9E,0xCDC2},{0xAD9F,0xCDC3},{0xC3E8,0xCDC4},
{0xADA0,0xCDC5},{0xAE41,0xCDC6},{0xAE42,0xCDC7},{0xAE43,0xCDC8},{0xAE44,0xCDC9},{0xAE45,0xCDCA},{0xAE46,0xCDCB},{0xC3E9,0xCDCC},{0xAE47,0xCDCD},{0xAE48,0xCDCE},{0xAE49,0xCDCF},{0xC3EA,0xCDD0},{0xAE4A,0xCDD1},{0xAE4B,0xCDD2},{0xAE4C,0xCDD3},{0xAE4D,0xCDD4},{0xAE4E,0xCDD5},{0xAE4F,0xCDD6},{0xAE50,0xCDD7},{0xAE51,0xCDD8},{0xAE52,0xCDD9},{0xAE53,0xCDDA},{0xAE54,0xCDDB},{0xAE55,0xCDDC},{0xAE56,0xCDDD},{0xAE57,0xCDDE},{0xAE58,0xCDDF},{0xAE59,0xCDE0},{0xAE5A,0xCDE1},{0xAE61,0xCDE2},{0xAE62,0xCDE3},{0xAE63,0xCDE4},{0xAE64,0xCDE5},{0xAE65,0xCDE6},{0xAE66,0xCDE7},{0xC3EB,0xCDE8},{0xAE67,0xCDE9},{0xAE68,0xCDEA},{0xAE69,0xCDEB},{0xC3EC,0xCDEC},{0xAE6A,0xCDED},{0xAE6B,0xCDEE},{0xAE6C,0xCDEF},{0xC3ED,0xCDF0},{0xAE6D,0xCDF1},{0xAE6E,0xCDF2},{0xAE6F,0xCDF3},{0xAE70,0xCDF4},{0xAE71,0xCDF5},{0xAE72,0xCDF6},{0xAE73,0xCDF7},{0xC3EE,0xCDF8},{0xC3EF,0xCDF9},{0xAE74,0xCDFA},{0xC3F0,0xCDFB},{0xAE75,0xCDFC},{0xC3F1,0xCDFD},{0xAE76,0xCDFE},{0xAE77,0xCDFF},{0xAE78,0xCE00},{0xAE79,0xCE01},{0xAE7A,0xCE02},{0xAE81,0xCE03},{0xC3F2,0xCE04},{0xAE82,0xCE05},{0xAE83,0xCE06},{0xAE84,0xCE07},{0xC3F3,0xCE08},{0xAE85,0xCE09},{0xAE86,0xCE0A},{0xAE87,0xCE0B},{0xC3F4,0xCE0C},{0xAE88,0xCE0D},{0xAE89,0xCE0E},{0xAE8A,0xCE0F},{0xAE8B,0xCE10},{0xAE8C,0xCE11},{0xAE8D,0xCE12},{0xAE8E,0xCE13},{0xC3F5,0xCE14},{0xAE8F,0xCE15},{0xAE90,0xCE16},{0xAE91,0xCE17},{0xAE92,0xCE18},{0xC3F6,0xCE19},{0xAE93,0xCE1A},{0xAE94,0xCE1B},{0xAE95,0xCE1C},{0xAE96,0xCE1D},{0xAE97,0xCE1E},{0xAE98,0xCE1F},{0xC3F7,0xCE20},{0xC3F8,0xCE21},{0xAE99,0xCE22},{0xAE9A,0xCE23},{0xC3F9,0xCE24},{0xAE9B,0xCE25},{0xAE9C,0xCE26},{0xAE9D,0xCE27},{0xC3FA,0xCE28},{0xAE9E,0xCE29},{0xAE9F,0xCE2A},{0xAEA0,0xCE2B},{0xAF41,0xCE2C},{0xAF42,0xCE2D},{0xAF43,0xCE2E},{0xAF44,0xCE2F},{0xC3FB,0xCE30},{0xC3FC,0xCE31},{0xAF45,0xCE32},{0xC3FD,0xCE33},{0xAF46,0xCE34},{0xC3FE,0xCE35},{0xAF47,0xCE36},{0xAF48,0xCE37},{0xAF49,0xCE38},{0xAF4A,0xCE39},{0xAF4B,0xCE3A},{0xAF4C,0xCE3B},{0xAF4D,0xCE3C},{0xAF4E,0xCE3D},{0xAF4F,0xCE3E},{0xAF50,0xCE3F},{0xAF51,0xCE40},{0xAF52,0xCE41},{0xAF53,0xCE42},{0xAF54,0xCE43},{0xAF55,0xCE44},{0xAF56,0xCE45},{0xAF57,0xCE46},{0xAF58,0xCE47},{0xAF59,0xCE48},{0xAF5A,0xCE49},{0xAF61,0xCE4A},{0xAF62,0xCE4B},{0xAF63,0xCE4C},{0xAF64,0xCE4D},{0xAF65,0xCE4E},{0xAF66,0xCE4F},{0xAF67,0xCE50},{0xAF68,0xCE51},{0xAF69,0xCE52},{0xAF6A,0xCE53},{0xAF6B,0xCE54},{0xAF6C,0xCE55},{0xAF6D,0xCE56},{0xAF6E,0xCE57},{0xC4A1,0xCE58},{0xC4A2,0xCE59},{0xAF6F,0xCE5A},{0xAF70,0xCE5B},{0xC4A3,0xCE5C},{0xAF71,0xCE5D},{0xAF72,0xCE5E},{0xC4A4,0xCE5F},{0xC4A5,0xCE60},{0xC4A6,0xCE61},{0xAF73,0xCE62},{0xAF74,0xCE63},{0xAF75,0xCE64},{0xAF76,0xCE65},{0xAF77,0xCE66},{0xAF78,0xCE67},{0xC4A7,0xCE68},{0xC4A8,0xCE69},{0xAF79,0xCE6A},{0xC4A9,0xCE6B},{0xAF7A,0xCE6C},{0xC4AA,0xCE6D},{0xAF81,0xCE6E},{0xAF82,0xCE6F},{0xAF83,0xCE70},{0xAF84,0xCE71},{0xAF85,0xCE72},{0xAF86,0xCE73},{0xC4AB,0xCE74},{0xC4AC,0xCE75},{0xAF87,0xCE76},{0xAF88,0xCE77},{0xC4AD,0xCE78},{0xAF89,0xCE79},{0xAF8A,0xCE7A},{0xAF8B,0xCE7B},{0xC4AE,0xCE7C},{0xAF8C,0xCE7D},{0xAF8D,0xCE7E},{0xAF8E,0xCE7F},{0xAF8F,0xCE80},{0xAF90,0xCE81},{0xAF91,0xCE82},{0xAF92,0xCE83},{0xC4AF,0xCE84},{0xC4B0,0xCE85},{0xAF93,0xCE86},{0xC4B1,0xCE87},{0xAF94,0xCE88},{0xC4B2,0xCE89},{0xAF95,0xCE8A},{0xAF96,0xCE8B},{0xAF97,0xCE8C},{0xAF98,0xCE8D},{0xAF99,0xCE8E},{0xAF9A,0xCE8F},{0xC4B3,0xCE90},{0xC4B4,0xCE91},{0xAF9B,0xCE92},{0xAF9C,0xCE93},{0xC4B5,0xCE94},{0xAF9D,0xCE95},{0xAF9E,0xCE96},{0xAF9F,0xCE97},{0xC4B6,0xCE98},{0xAFA0,0xCE99},{0xB041,0xCE9A},{0xB042,0xCE9B},{0xB043,0xCE9C},{0xB044,0xCE9D},{0xB045,0xCE9E},{0xB046,0xCE9F},{0xC4B7,0xCEA0},{0xC4B8,0xCEA1},{0xB047,0xCEA2},{0xC4B9,0xCEA3},{0xC4BA,0xCEA4},{0xC4BB,0xCEA5},{0xB048,0xCEA6},{0xB049,0xCEA7},{0xB04A,0xCEA8},{0xB04B,0xCEA9},{0xB04C,0xCEAA},{0xB04D,0xCEAB},{0xC4BC,0xCEAC},{0xC4BD,0xCEAD},{0xB04E,0xCEAE},{0xB04F,0xCEAF},{0xB050,0xCEB0},{0xB051,0xCEB1},{0xB052,0xCEB2},{0xB053,0xCEB3},{0xB054,0xCEB4},{0xB055,0xCEB5},{0xB056,0xCEB6},{0xB057,0xCEB7},{0xB058,0xCEB8},{0xB059,0xCEB9},{0xB05A,0xCEBA},{0xB061,0xCEBB},
{0xB062,0xCEBC},{0xB063,0xCEBD},{0xB064,0xCEBE},{0xB065,0xCEBF},{0xB066,0xCEC0},{0xC4BE,0xCEC1},{0xB067,0xCEC2},{0xB068,0xCEC3},{0xB069,0xCEC4},{0xB06A,0xCEC5},{0xB06B,0xCEC6},{0xB06C,0xCEC7},{0xB06D,0xCEC8},{0xB06E,0xCEC9},{0xB06F,0xCECA},{0xB070,0xCECB},{0xB071,0xCECC},{0xB072,0xCECD},{0xB073,0xCECE},{0xB074,0xCECF},{0xB075,0xCED0},{0xB076,0xCED1},{0xB077,0xCED2},{0xB078,0xCED3},{0xB079,0xCED4},{0xB07A,0xCED5},{0xB081,0xCED6},{0xB082,0xCED7},{0xB083,0xCED8},{0xB084,0xCED9},{0xB085,0xCEDA},{0xB086,0xCEDB},{0xB087,0xCEDC},{0xB088,0xCEDD},{0xB089,0xCEDE},{0xB08A,0xCEDF},{0xB08B,0xCEE0},{0xB08C,0xCEE1},{0xB08D,0xCEE2},{0xB08E,0xCEE3},{0xC4BF,0xCEE4},{0xC4C0,0xCEE5},{0xB08F,0xCEE6},{0xB090,0xCEE7},{0xC4C1,0xCEE8},{0xB091,0xCEE9},{0xB092,0xCEEA},{0xC4C2,0xCEEB},{0xC4C3,0xCEEC},{0xB093,0xCEED},{0xB094,0xCEEE},{0xB095,0xCEEF},{0xB096,0xCEF0},{0xB097,0xCEF1},{0xB098,0xCEF2},{0xB099,0xCEF3},{0xC4C4,0xCEF4},{0xC4C5,0xCEF5},{0xB09A,0xCEF6},{0xC4C6,0xCEF7},{0xC4C7,0xCEF8},{0xC4C8,0xCEF9},{0xB09B,0xCEFA},{0xB09C,0xCEFB},{0xB09D,0xCEFC},{0xB09E,0xCEFD},{0xB09F,0xCEFE},{0xB0A0,0xCEFF},{0xC4C9,0xCF00},{0xC4CA,0xCF01},{0xB141,0xCF02},{0xB142,0xCF03},{0xC4CB,0xCF04},{0xB143,0xCF05},{0xB144,0xCF06},{0xB145,0xCF07},{0xC4CC,0xCF08},{0xB146,0xCF09},{0xB147,0xCF0A},{0xB148,0xCF0B},{0xB149,0xCF0C},{0xB14A,0xCF0D},{0xB14B,0xCF0E},{0xB14C,0xCF0F},{0xC4CD,0xCF10},{0xC4CE,0xCF11},{0xB14D,0xCF12},{0xC4CF,0xCF13},{0xB14E,0xCF14},{0xC4D0,0xCF15},{0xB14F,0xCF16},{0xB150,0xCF17},{0xB151,0xCF18},{0xB152,0xCF19},{0xB153,0xCF1A},{0xB154,0xCF1B},{0xC4D1,0xCF1C},{0xB155,0xCF1D},{0xB156,0xCF1E},{0xB157,0xCF1F},{0xC4D2,0xCF20},{0xB158,0xCF21},{0xB159,0xCF22},{0xB15A,0xCF23},{0xC4D3,0xCF24},{0xB161,0xCF25},{0xB162,0xCF26},{0xB163,0xCF27},{0xB164,0xCF28},{0xB165,0xCF29},{0xB166,0xCF2A},{0xB167,0xCF2B},{0xC4D4,0xCF2C},{0xC4D5,0xCF2D},{0xB168,0xCF2E},{0xC4D6,0xCF2F},{0xC4D7,0xCF30},{0xC4D8,0xCF31},{0xB169,0xCF32},{0xB16A,0xCF33},{0xB16B,0xCF34},{0xB16C,0xCF35},{0xB16D,0xCF36},{0xB16E,0xCF37},{0xC4D9,0xCF38},{0xB16F,0xCF39},{0xB170,0xCF3A},{0xB171,0xCF3B},{0xB172,0xCF3C},{0xB173,0xCF3D},{0xB174,0xCF3E},{0xB175,0xCF3F},{0xB176,0xCF40},{0xB177,0xCF41},{0xB178,0xCF42},{0xB179,0xCF43},{0xB17A,0xCF44},{0xB181,0xCF45},{0xB182,0xCF46},{0xB183,0xCF47},{0xB184,0xCF48},{0xB185,0xCF49},{0xB186,0xCF4A},{0xB187,0xCF4B},{0xB188,0xCF4C},{0xB189,0xCF4D},{0xB18A,0xCF4E},{0xB18B,0xCF4F},{0xB18C,0xCF50},{0xB18D,0xCF51},{0xB18E,0xCF52},{0xB18F,0xCF53},{0xC4DA,0xCF54},{0xC4DB,0xCF55},{0xB190,0xCF56},{0xB191,0xCF57},{0xC4DC,0xCF58},{0xB192,0xCF59},{0xB193,0xCF5A},{0xB194,0xCF5B},{0xC4DD,0xCF5C},{0xB195,0xCF5D},{0xB196,0xCF5E},{0xB197,0xCF5F},{0xB198,0xCF60},{0xB199,0xCF61},{0xB19A,0xCF62},{0xB19B,0xCF63},{0xC4DE,0xCF64},{0xC4DF,0xCF65},{0xB19C,0xCF66},{0xC4E0,0xCF67},{0xB19D,0xCF68},{0xC4E1,0xCF69},{0xB19E,0xCF6A},{0xB19F,0xCF6B},{0xB1A0,0xCF6C},{0xB241,0xCF6D},{0xB242,0xCF6E},{0xB243,0xCF6F},{0xC4E2,0xCF70},{0xC4E3,0xCF71},{0xB244,0xCF72},{0xB245,0xCF73},{0xC4E4,0xCF74},{0xB246,0xCF75},{0xB247,0xCF76},{0xB248,0xCF77},{0xC4E5,0xCF78},{0xB249,0xCF79},{0xB24A,0xCF7A},{0xB24B,0xCF7B},{0xB24C,0xCF7C},{0xB24D,0xCF7D},{0xB24E,0xCF7E},{0xB24F,0xCF7F},{0xC4E6,0xCF80},{0xB250,0xCF81},{0xB251,0xCF82},{0xB252,0xCF83},{0xB253,0xCF84},{0xC4E7,0xCF85},{0xB254,0xCF86},{0xB255,0xCF87},{0xB256,0xCF88},{0xB257,0xCF89},{0xB258,0xCF8A},{0xB259,0xCF8B},{0xC4E8,0xCF8C},{0xB25A,0xCF8D},{0xB261,0xCF8E},{0xB262,0xCF8F},{0xB263,0xCF90},{0xB264,0xCF91},{0xB265,0xCF92},{0xB266,0xCF93},{0xB267,0xCF94},{0xB268,0xCF95},{0xB269,0xCF96},{0xB26A,0xCF97},{0xB26B,0xCF98},{0xB26C,0xCF99},{0xB26D,0xCF9A},{0xB26E,0xCF9B},{0xB26F,0xCF9C},{0xB270,0xCF9D},{0xB271,0xCF9E},{0xB272,0xCF9F},{0xB273,0xCFA0},{0xC4E9,0xCFA1},{0xB274,0xCFA2},{0xB275,0xCFA3},{0xB276,0xCFA4},{0xB277,0xCFA5},{0xB278,0xCFA6},{0xB279,0xCFA7},{0xC4EA,0xCFA8},{0xB27A,0xCFA9},{0xB281,0xCFAA},{0xB282,0xCFAB},{0xB283,0xCFAC},{0xB284,0xCFAD},{0xB285,0xCFAE},{0xB286,0xCFAF},{0xC4EB,0xCFB0},{0xB287,0xCFB1},{0xB288,0xCFB2},
{0xB289,0xCFB3},{0xB28A,0xCFB4},{0xB28B,0xCFB5},{0xB28C,0xCFB6},{0xB28D,0xCFB7},{0xB28E,0xCFB8},{0xB28F,0xCFB9},{0xB290,0xCFBA},{0xB291,0xCFBB},{0xB292,0xCFBC},{0xB293,0xCFBD},{0xB294,0xCFBE},{0xB295,0xCFBF},{0xB296,0xCFC0},{0xB297,0xCFC1},{0xB298,0xCFC2},{0xB299,0xCFC3},{0xC4EC,0xCFC4},{0xB29A,0xCFC5},{0xB29B,0xCFC6},{0xB29C,0xCFC7},{0xB29D,0xCFC8},{0xB29E,0xCFC9},{0xB29F,0xCFCA},{0xB2A0,0xCFCB},{0xB341,0xCFCC},{0xB342,0xCFCD},{0xB343,0xCFCE},{0xB344,0xCFCF},{0xB345,0xCFD0},{0xB346,0xCFD1},{0xB347,0xCFD2},{0xB348,0xCFD3},{0xB349,0xCFD4},{0xB34A,0xCFD5},{0xB34B,0xCFD6},{0xB34C,0xCFD7},{0xB34D,0xCFD8},{0xB34E,0xCFD9},{0xB34F,0xCFDA},{0xB350,0xCFDB},{0xB351,0xCFDC},{0xB352,0xCFDD},{0xB353,0xCFDE},{0xB354,0xCFDF},{0xC4ED,0xCFE0},{0xC4EE,0xCFE1},{0xB355,0xCFE2},{0xB356,0xCFE3},{0xC4EF,0xCFE4},{0xB357,0xCFE5},{0xB358,0xCFE6},{0xB359,0xCFE7},{0xC4F0,0xCFE8},{0xB35A,0xCFE9},{0xB361,0xCFEA},{0xB362,0xCFEB},{0xB363,0xCFEC},{0xB364,0xCFED},{0xB365,0xCFEE},{0xB366,0xCFEF},{0xC4F1,0xCFF0},{0xC4F2,0xCFF1},{0xB367,0xCFF2},{0xC4F3,0xCFF3},{0xB368,0xCFF4},{0xC4F4,0xCFF5},{0xB369,0xCFF6},{0xB36A,0xCFF7},{0xB36B,0xCFF8},{0xB36C,0xCFF9},{0xB36D,0xCFFA},{0xB36E,0xCFFB},{0xC4F5,0xCFFC},{0xB36F,0xCFFD},{0xB370,0xCFFE},{0xB371,0xCFFF},{0xC4F6,0xD000},{0xB372,0xD001},{0xB373,0xD002},{0xB374,0xD003},{0xC4F7,0xD004},{0xB375,0xD005},{0xB376,0xD006},{0xB377,0xD007},{0xB378,0xD008},{0xB379,0xD009},{0xB37A,0xD00A},{0xB381,0xD00B},{0xB382,0xD00C},{0xB383,0xD00D},{0xB384,0xD00E},{0xB385,0xD00F},{0xB386,0xD010},{0xC4F8,0xD011},{0xB387,0xD012},{0xB388,0xD013},{0xB389,0xD014},{0xB38A,0xD015},{0xB38B,0xD016},{0xB38C,0xD017},{0xC4F9,0xD018},{0xB38D,0xD019},{0xB38E,0xD01A},{0xB38F,0xD01B},{0xB390,0xD01C},{0xB391,0xD01D},{0xB392,0xD01E},{0xB393,0xD01F},{0xB394,0xD020},{0xB395,0xD021},{0xB396,0xD022},{0xB397,0xD023},{0xB398,0xD024},{0xB399,0xD025},{0xB39A,0xD026},{0xB39B,0xD027},{0xB39C,0xD028},{0xB39D,0xD029},{0xB39E,0xD02A},{0xB39F,0xD02B},{0xB3A0,0xD02C},{0xC4FA,0xD02D},{0xB441,0xD02E},{0xB442,0xD02F},{0xB443,0xD030},{0xB444,0xD031},{0xB445,0xD032},{0xB446,0xD033},{0xC4FB,0xD034},{0xC4FC,0xD035},{0xB447,0xD036},{0xB448,0xD037},{0xC4FD,0xD038},{0xB449,0xD039},{0xB44A,0xD03A},{0xB44B,0xD03B},{0xC4FE,0xD03C},{0xB44C,0xD03D},{0xB44D,0xD03E},{0xB44E,0xD03F},{0xB44F,0xD040},{0xB450,0xD041},{0xB451,0xD042},{0xB452,0xD043},{0xC5A1,0xD044},{0xC5A2,0xD045},{0xB453,0xD046},{0xC5A3,0xD047},{0xB454,0xD048},{0xC5A4,0xD049},{0xB455,0xD04A},{0xB456,0xD04B},{0xB457,0xD04C},{0xB458,0xD04D},{0xB459,0xD04E},{0xB45A,0xD04F},{0xC5A5,0xD050},{0xB461,0xD051},{0xB462,0xD052},{0xB463,0xD053},{0xC5A6,0xD054},{0xB464,0xD055},{0xB465,0xD056},{0xB466,0xD057},{0xC5A7,0xD058},{0xB467,0xD059},{0xB468,0xD05A},{0xB469,0xD05B},{0xB46A,0xD05C},{0xB46B,0xD05D},{0xB46C,0xD05E},{0xB46D,0xD05F},{0xC5A8,0xD060},{0xB46E,0xD061},{0xB46F,0xD062},{0xB470,0xD063},{0xB471,0xD064},{0xB472,0xD065},{0xB473,0xD066},{0xB474,0xD067},{0xB475,0xD068},{0xB476,0xD069},{0xB477,0xD06A},{0xB478,0xD06B},{0xC5A9,0xD06C},{0xC5AA,0xD06D},{0xB479,0xD06E},{0xB47A,0xD06F},{0xC5AB,0xD070},{0xB481,0xD071},{0xB482,0xD072},{0xB483,0xD073},{0xC5AC,0xD074},{0xB484,0xD075},{0xB485,0xD076},{0xB486,0xD077},{0xB487,0xD078},{0xB488,0xD079},{0xB489,0xD07A},{0xB48A,0xD07B},{0xC5AD,0xD07C},{0xC5AE,0xD07D},{0xB48B,0xD07E},{0xB48C,0xD07F},{0xB48D,0xD080},{0xC5AF,0xD081},{0xB48E,0xD082},{0xB48F,0xD083},{0xB490,0xD084},{0xB491,0xD085},{0xB492,0xD086},{0xB493,0xD087},{0xB494,0xD088},{0xB495,0xD089},{0xB496,0xD08A},{0xB497,0xD08B},{0xB498,0xD08C},{0xB499,0xD08D},{0xB49A,0xD08E},{0xB49B,0xD08F},{0xB49C,0xD090},{0xB49D,0xD091},{0xB49E,0xD092},{0xB49F,0xD093},{0xB4A0,0xD094},{0xB541,0xD095},{0xB542,0xD096},{0xB543,0xD097},{0xB544,0xD098},{0xB545,0xD099},{0xB546,0xD09A},{0xB547,0xD09B},{0xB548,0xD09C},{0xB549,0xD09D},{0xB54A,0xD09E},{0xB54B,0xD09F},{0xB54C,0xD0A0},{0xB54D,0xD0A1},{0xB54E,0xD0A2},{0xB54F,0xD0A3},{0xC5B0,0xD0A4},{0xC5B1,0xD0A5},{0xB550,0xD0A6},{0xB551,0xD0A7},{0xC5B2,0xD0A8},{0xB552,0xD0A9},
{0xB553,0xD0AA},{0xB554,0xD0AB},{0xC5B3,0xD0AC},{0xB555,0xD0AD},{0xB556,0xD0AE},{0xB557,0xD0AF},{0xB558,0xD0B0},{0xB559,0xD0B1},{0xB55A,0xD0B2},{0xB561,0xD0B3},{0xC5B4,0xD0B4},{0xC5B5,0xD0B5},{0xB562,0xD0B6},{0xC5B6,0xD0B7},{0xB563,0xD0B8},{0xC5B7,0xD0B9},{0xB564,0xD0BA},{0xB565,0xD0BB},{0xB566,0xD0BC},{0xB567,0xD0BD},{0xB568,0xD0BE},{0xB569,0xD0BF},{0xC5B8,0xD0C0},{0xC5B9,0xD0C1},{0xB56A,0xD0C2},{0xB56B,0xD0C3},{0xC5BA,0xD0C4},{0xB56C,0xD0C5},{0xB56D,0xD0C6},{0xB56E,0xD0C7},{0xC5BB,0xD0C8},{0xC5BC,0xD0C9},{0xB56F,0xD0CA},{0xB570,0xD0CB},{0xB571,0xD0CC},{0xB572,0xD0CD},{0xB573,0xD0CE},{0xB574,0xD0CF},{0xC5BD,0xD0D0},{0xC5BE,0xD0D1},{0xB575,0xD0D2},{0xC5BF,0xD0D3},{0xC5C0,0xD0D4},{0xC5C1,0xD0D5},{0xB576,0xD0D6},{0xB577,0xD0D7},{0xB578,0xD0D8},{0xB579,0xD0D9},{0xB57A,0xD0DA},{0xB581,0xD0DB},{0xC5C2,0xD0DC},{0xC5C3,0xD0DD},{0xB582,0xD0DE},{0xB583,0xD0DF},{0xC5C4,0xD0E0},{0xB584,0xD0E1},{0xB585,0xD0E2},{0xB586,0xD0E3},{0xC5C5,0xD0E4},{0xB587,0xD0E5},{0xB588,0xD0E6},{0xB589,0xD0E7},{0xB58A,0xD0E8},{0xB58B,0xD0E9},{0xB58C,0xD0EA},{0xB58D,0xD0EB},{0xC5C6,0xD0EC},{0xC5C7,0xD0ED},{0xB58E,0xD0EE},{0xC5C8,0xD0EF},{0xC5C9,0xD0F0},{0xC5CA,0xD0F1},{0xB58F,0xD0F2},{0xB590,0xD0F3},{0xB591,0xD0F4},{0xB592,0xD0F5},{0xB593,0xD0F6},{0xB594,0xD0F7},{0xC5CB,0xD0F8},{0xB595,0xD0F9},{0xB596,0xD0FA},{0xB597,0xD0FB},{0xB598,0xD0FC},{0xB599,0xD0FD},{0xB59A,0xD0FE},{0xB59B,0xD0FF},{0xB59C,0xD100},{0xB59D,0xD101},{0xB59E,0xD102},{0xB59F,0xD103},{0xB5A0,0xD104},{0xB641,0xD105},{0xB642,0xD106},{0xB643,0xD107},{0xB644,0xD108},{0xB645,0xD109},{0xB646,0xD10A},{0xB647,0xD10B},{0xB648,0xD10C},{0xC5CC,0xD10D},{0xB649,0xD10E},{0xB64A,0xD10F},{0xB64B,0xD110},{0xB64C,0xD111},{0xB64D,0xD112},{0xB64E,0xD113},{0xB64F,0xD114},{0xB650,0xD115},{0xB651,0xD116},{0xB652,0xD117},{0xB653,0xD118},{0xB654,0xD119},{0xB655,0xD11A},{0xB656,0xD11B},{0xB657,0xD11C},{0xB658,0xD11D},{0xB659,0xD11E},{0xB65A,0xD11F},{0xB661,0xD120},{0xB662,0xD121},{0xB663,0xD122},{0xB664,0xD123},{0xB665,0xD124},{0xB666,0xD125},{0xB667,0xD126},{0xB668,0xD127},{0xB669,0xD128},{0xB66A,0xD129},{0xB66B,0xD12A},{0xB66C,0xD12B},{0xB66D,0xD12C},{0xB66E,0xD12D},{0xB66F,0xD12E},{0xB670,0xD12F},{0xC5CD,0xD130},{0xC5CE,0xD131},{0xB671,0xD132},{0xB672,0xD133},{0xC5CF,0xD134},{0xB673,0xD135},{0xB674,0xD136},{0xB675,0xD137},{0xC5D0,0xD138},{0xB676,0xD139},{0xC5D1,0xD13A},{0xB677,0xD13B},{0xB678,0xD13C},{0xB679,0xD13D},{0xB67A,0xD13E},{0xB681,0xD13F},{0xC5D2,0xD140},{0xC5D3,0xD141},{0xB682,0xD142},{0xC5D4,0xD143},{0xC5D5,0xD144},{0xC5D6,0xD145},{0xB683,0xD146},{0xB684,0xD147},{0xB685,0xD148},{0xB686,0xD149},{0xB687,0xD14A},{0xB688,0xD14B},{0xC5D7,0xD14C},{0xC5D8,0xD14D},{0xB689,0xD14E},{0xB68A,0xD14F},{0xC5D9,0xD150},{0xB68B,0xD151},{0xB68C,0xD152},{0xB68D,0xD153},{0xC5DA,0xD154},{0xB68E,0xD155},{0xB68F,0xD156},{0xB690,0xD157},{0xB691,0xD158},{0xB692,0xD159},{0xB693,0xD15A},{0xB694,0xD15B},{0xC5DB,0xD15C},{0xC5DC,0xD15D},{0xB695,0xD15E},{0xC5DD,0xD15F},{0xB696,0xD160},{0xC5DE,0xD161},{0xB697,0xD162},{0xB698,0xD163},{0xB699,0xD164},{0xB69A,0xD165},{0xB69B,0xD166},{0xB69C,0xD167},{0xC5DF,0xD168},{0xB69D,0xD169},{0xB69E,0xD16A},{0xB69F,0xD16B},{0xC5E0,0xD16C},{0xB6A0,0xD16D},{0xB741,0xD16E},{0xB742,0xD16F},{0xB743,0xD170},{0xB744,0xD171},{0xB745,0xD172},{0xB746,0xD173},{0xB747,0xD174},{0xB748,0xD175},{0xB749,0xD176},{0xB74A,0xD177},{0xB74B,0xD178},{0xB74C,0xD179},{0xB74D,0xD17A},{0xB74E,0xD17B},{0xC5E1,0xD17C},{0xB74F,0xD17D},{0xB750,0xD17E},{0xB751,0xD17F},{0xB752,0xD180},{0xB753,0xD181},{0xB754,0xD182},{0xB755,0xD183},{0xC5E2,0xD184},{0xB756,0xD185},{0xB757,0xD186},{0xB758,0xD187},{0xC5E3,0xD188},{0xB759,0xD189},{0xB75A,0xD18A},{0xB761,0xD18B},{0xB762,0xD18C},{0xB763,0xD18D},{0xB764,0xD18E},{0xB765,0xD18F},{0xB766,0xD190},{0xB767,0xD191},{0xB768,0xD192},{0xB769,0xD193},{0xB76A,0xD194},{0xB76B,0xD195},{0xB76C,0xD196},{0xB76D,0xD197},{0xB76E,0xD198},{0xB76F,0xD199},{0xB770,0xD19A},{0xB771,0xD19B},{0xB772,0xD19C},{0xB773,0xD19D},{0xB774,0xD19E},{0xB775,0xD19F},{0xC5E4,0xD1A0},
{0xC5E5,0xD1A1},{0xB776,0xD1A2},{0xB777,0xD1A3},{0xC5E6,0xD1A4},{0xB778,0xD1A5},{0xB779,0xD1A6},{0xB77A,0xD1A7},{0xC5E7,0xD1A8},{0xB781,0xD1A9},{0xB782,0xD1AA},{0xB783,0xD1AB},{0xB784,0xD1AC},{0xB785,0xD1AD},{0xB786,0xD1AE},{0xB787,0xD1AF},{0xC5E8,0xD1B0},{0xC5E9,0xD1B1},{0xB788,0xD1B2},{0xC5EA,0xD1B3},{0xB789,0xD1B4},{0xC5EB,0xD1B5},{0xB78A,0xD1B6},{0xB78B,0xD1B7},{0xB78C,0xD1B8},{0xB78D,0xD1B9},{0xC5EC,0xD1BA},{0xB78E,0xD1BB},{0xC5ED,0xD1BC},{0xB78F,0xD1BD},{0xB790,0xD1BE},{0xB791,0xD1BF},{0xC5EE,0xD1C0},{0xB792,0xD1C1},{0xB793,0xD1C2},{0xB794,0xD1C3},{0xB795,0xD1C4},{0xB796,0xD1C5},{0xB797,0xD1C6},{0xB798,0xD1C7},{0xB799,0xD1C8},{0xB79A,0xD1C9},{0xB79B,0xD1CA},{0xB79C,0xD1CB},{0xB79D,0xD1CC},{0xB79E,0xD1CD},{0xB79F,0xD1CE},{0xB7A0,0xD1CF},{0xB841,0xD1D0},{0xB842,0xD1D1},{0xB843,0xD1D2},{0xB844,0xD1D3},{0xB845,0xD1D4},{0xB846,0xD1D5},{0xB847,0xD1D6},{0xB848,0xD1D7},{0xC5EF,0xD1D8},{0xB849,0xD1D9},{0xB84A,0xD1DA},{0xB84B,0xD1DB},{0xB84C,0xD1DC},{0xB84D,0xD1DD},{0xB84E,0xD1DE},{0xB84F,0xD1DF},{0xB850,0xD1E0},{0xB851,0xD1E1},{0xB852,0xD1E2},{0xB853,0xD1E3},{0xB854,0xD1E4},{0xB855,0xD1E5},{0xB856,0xD1E6},{0xB857,0xD1E7},{0xB858,0xD1E8},{0xB859,0xD1E9},{0xB85A,0xD1EA},{0xB861,0xD1EB},{0xB862,0xD1EC},{0xB863,0xD1ED},{0xB864,0xD1EE},{0xB865,0xD1EF},{0xB866,0xD1F0},{0xB867,0xD1F1},{0xB868,0xD1F2},{0xB869,0xD1F3},{0xC5F0,0xD1F4},{0xB86A,0xD1F5},{0xB86B,0xD1F6},{0xB86C,0xD1F7},{0xC5F1,0xD1F8},{0xB86D,0xD1F9},{0xB86E,0xD1FA},{0xB86F,0xD1FB},{0xB870,0xD1FC},{0xB871,0xD1FD},{0xB872,0xD1FE},{0xB873,0xD1FF},{0xB874,0xD200},{0xB875,0xD201},{0xB876,0xD202},{0xB877,0xD203},{0xB878,0xD204},{0xB879,0xD205},{0xB87A,0xD206},{0xC5F2,0xD207},{0xB881,0xD208},{0xC5F3,0xD209},{0xB882,0xD20A},{0xB883,0xD20B},{0xB884,0xD20C},{0xB885,0xD20D},{0xB886,0xD20E},{0xB887,0xD20F},{0xC5F4,0xD210},{0xB888,0xD211},{0xB889,0xD212},{0xB88A,0xD213},{0xB88B,0xD214},{0xB88C,0xD215},{0xB88D,0xD216},{0xB88E,0xD217},{0xB88F,0xD218},{0xB890,0xD219},{0xB891,0xD21A},{0xB892,0xD21B},{0xB893,0xD21C},{0xB894,0xD21D},{0xB895,0xD21E},{0xB896,0xD21F},{0xB897,0xD220},{0xB898,0xD221},{0xB899,0xD222},{0xB89A,0xD223},{0xB89B,0xD224},{0xB89C,0xD225},{0xB89D,0xD226},{0xB89E,0xD227},{0xB89F,0xD228},{0xB8A0,0xD229},{0xB941,0xD22A},{0xB942,0xD22B},{0xC5F5,0xD22C},{0xC5F6,0xD22D},{0xB943,0xD22E},{0xB944,0xD22F},{0xC5F7,0xD230},{0xB945,0xD231},{0xB946,0xD232},{0xB947,0xD233},{0xC5F8,0xD234},{0xB948,0xD235},{0xB949,0xD236},{0xB94A,0xD237},{0xB94B,0xD238},{0xB94C,0xD239},{0xB94D,0xD23A},{0xB94E,0xD23B},{0xC5F9,0xD23C},{0xC5FA,0xD23D},{0xB94F,0xD23E},{0xC5FB,0xD23F},{0xB950,0xD240},{0xC5FC,0xD241},{0xB951,0xD242},{0xB952,0xD243},{0xB953,0xD244},{0xB954,0xD245},{0xB955,0xD246},{0xB956,0xD247},{0xC5FD,0xD248},{0xB957,0xD249},{0xB958,0xD24A},{0xB959,0xD24B},{0xB95A,0xD24C},{0xB961,0xD24D},{0xB962,0xD24E},{0xB963,0xD24F},{0xB964,0xD250},{0xB965,0xD251},{0xB966,0xD252},{0xB967,0xD253},{0xB968,0xD254},{0xB969,0xD255},{0xB96A,0xD256},{0xB96B,0xD257},{0xB96C,0xD258},{0xB96D,0xD259},{0xB96E,0xD25A},{0xB96F,0xD25B},{0xC5FE,0xD25C},{0xB970,0xD25D},{0xB971,0xD25E},{0xB972,0xD25F},{0xB973,0xD260},{0xB974,0xD261},{0xB975,0xD262},{0xB976,0xD263},{0xC6A1,0xD264},{0xB977,0xD265},{0xB978,0xD266},{0xB979,0xD267},{0xB97A,0xD268},{0xB981,0xD269},{0xB982,0xD26A},{0xB983,0xD26B},{0xB984,0xD26C},{0xB985,0xD26D},{0xB986,0xD26E},{0xB987,0xD26F},{0xB988,0xD270},{0xB989,0xD271},{0xB98A,0xD272},{0xB98B,0xD273},{0xB98C,0xD274},{0xB98D,0xD275},{0xB98E,0xD276},{0xB98F,0xD277},{0xB990,0xD278},{0xB991,0xD279},{0xB992,0xD27A},{0xB993,0xD27B},{0xB994,0xD27C},{0xB995,0xD27D},{0xB996,0xD27E},{0xB997,0xD27F},{0xC6A2,0xD280},{0xC6A3,0xD281},{0xB998,0xD282},{0xB999,0xD283},{0xC6A4,0xD284},{0xB99A,0xD285},{0xB99B,0xD286},{0xB99C,0xD287},{0xC6A5,0xD288},{0xB99D,0xD289},{0xB99E,0xD28A},{0xB99F,0xD28B},{0xB9A0,0xD28C},{0xBA41,0xD28D},{0xBA42,0xD28E},{0xBA43,0xD28F},{0xC6A6,0xD290},{0xC6A7,0xD291},{0xBA44,0xD292},{0xBA45,0xD293},{0xBA46,0xD294},{0xC6A8,0xD295},{0xBA47,0xD296},{0xBA48,0xD297},
{0xBA49,0xD298},{0xBA4A,0xD299},{0xBA4B,0xD29A},{0xBA4C,0xD29B},{0xC6A9,0xD29C},{0xBA4D,0xD29D},{0xBA4E,0xD29E},{0xBA4F,0xD29F},{0xC6AA,0xD2A0},{0xBA50,0xD2A1},{0xBA51,0xD2A2},{0xBA52,0xD2A3},{0xC6AB,0xD2A4},{0xBA53,0xD2A5},{0xBA54,0xD2A6},{0xBA55,0xD2A7},{0xBA56,0xD2A8},{0xBA57,0xD2A9},{0xBA58,0xD2AA},{0xBA59,0xD2AB},{0xC6AC,0xD2AC},{0xBA5A,0xD2AD},{0xBA61,0xD2AE},{0xBA62,0xD2AF},{0xBA63,0xD2B0},{0xC6AD,0xD2B1},{0xBA64,0xD2B2},{0xBA65,0xD2B3},{0xBA66,0xD2B4},{0xBA67,0xD2B5},{0xBA68,0xD2B6},{0xBA69,0xD2B7},{0xC6AE,0xD2B8},{0xC6AF,0xD2B9},{0xBA6A,0xD2BA},{0xBA6B,0xD2BB},{0xC6B0,0xD2BC},{0xBA6C,0xD2BD},{0xBA6D,0xD2BE},{0xC6B1,0xD2BF},{0xC6B2,0xD2C0},{0xBA6E,0xD2C1},{0xC6B3,0xD2C2},{0xBA6F,0xD2C3},{0xBA70,0xD2C4},{0xBA71,0xD2C5},{0xBA72,0xD2C6},{0xBA73,0xD2C7},{0xC6B4,0xD2C8},{0xC6B5,0xD2C9},{0xBA74,0xD2CA},{0xC6B6,0xD2CB},{0xBA75,0xD2CC},{0xBA76,0xD2CD},{0xBA77,0xD2CE},{0xBA78,0xD2CF},{0xBA79,0xD2D0},{0xBA7A,0xD2D1},{0xBA81,0xD2D2},{0xBA82,0xD2D3},{0xC6B7,0xD2D4},{0xBA83,0xD2D5},{0xBA84,0xD2D6},{0xBA85,0xD2D7},{0xC6B8,0xD2D8},{0xBA86,0xD2D9},{0xBA87,0xD2DA},{0xBA88,0xD2DB},{0xC6B9,0xD2DC},{0xBA89,0xD2DD},{0xBA8A,0xD2DE},{0xBA8B,0xD2DF},{0xBA8C,0xD2E0},{0xBA8D,0xD2E1},{0xBA8E,0xD2E2},{0xBA8F,0xD2E3},{0xC6BA,0xD2E4},{0xC6BB,0xD2E5},{0xBA90,0xD2E6},{0xBA91,0xD2E7},{0xBA92,0xD2E8},{0xBA93,0xD2E9},{0xBA94,0xD2EA},{0xBA95,0xD2EB},{0xBA96,0xD2EC},{0xBA97,0xD2ED},{0xBA98,0xD2EE},{0xBA99,0xD2EF},{0xC6BC,0xD2F0},{0xC6BD,0xD2F1},{0xBA9A,0xD2F2},{0xBA9B,0xD2F3},{0xC6BE,0xD2F4},{0xBA9C,0xD2F5},{0xBA9D,0xD2F6},{0xBA9E,0xD2F7},{0xC6BF,0xD2F8},{0xBA9F,0xD2F9},{0xBAA0,0xD2FA},{0xBB41,0xD2FB},{0xBB42,0xD2FC},{0xBB43,0xD2FD},{0xBB44,0xD2FE},{0xBB45,0xD2FF},{0xC6C0,0xD300},{0xC6C1,0xD301},{0xBB46,0xD302},{0xC6C2,0xD303},{0xBB47,0xD304},{0xC6C3,0xD305},{0xBB48,0xD306},{0xBB49,0xD307},{0xBB4A,0xD308},{0xBB4B,0xD309},{0xBB4C,0xD30A},{0xBB4D,0xD30B},{0xC6C4,0xD30C},{0xC6C5,0xD30D},{0xC6C6,0xD30E},{0xBB4E,0xD30F},{0xC6C7,0xD310},{0xBB4F,0xD311},{0xBB50,0xD312},{0xBB51,0xD313},{0xC6C8,0xD314},{0xBB52,0xD315},{0xC6C9,0xD316},{0xBB53,0xD317},{0xBB54,0xD318},{0xBB55,0xD319},{0xBB56,0xD31A},{0xBB57,0xD31B},{0xC6CA,0xD31C},{0xC6CB,0xD31D},{0xBB58,0xD31E},{0xC6CC,0xD31F},{0xC6CD,0xD320},{0xC6CE,0xD321},{0xBB59,0xD322},{0xBB5A,0xD323},{0xBB61,0xD324},{0xC6CF,0xD325},{0xBB62,0xD326},{0xBB63,0xD327},{0xC6D0,0xD328},{0xC6D1,0xD329},{0xBB64,0xD32A},{0xBB65,0xD32B},{0xC6D2,0xD32C},{0xBB66,0xD32D},{0xBB67,0xD32E},{0xBB68,0xD32F},{0xC6D3,0xD330},{0xBB69,0xD331},{0xBB6A,0xD332},{0xBB6B,0xD333},{0xBB6C,0xD334},{0xBB6D,0xD335},{0xBB6E,0xD336},{0xBB6F,0xD337},{0xC6D4,0xD338},{0xC6D5,0xD339},{0xBB70,0xD33A},{0xC6D6,0xD33B},{0xC6D7,0xD33C},{0xC6D8,0xD33D},{0xBB71,0xD33E},{0xBB72,0xD33F},{0xBB73,0xD340},{0xBB74,0xD341},{0xBB75,0xD342},{0xBB76,0xD343},{0xC6D9,0xD344},{0xC6DA,0xD345},{0xBB77,0xD346},{0xBB78,0xD347},{0xBB79,0xD348},{0xBB7A,0xD349},{0xBB81,0xD34A},{0xBB82,0xD34B},{0xBB83,0xD34C},{0xBB84,0xD34D},{0xBB85,0xD34E},{0xBB86,0xD34F},{0xBB87,0xD350},{0xBB88,0xD351},{0xBB89,0xD352},{0xBB8A,0xD353},{0xBB8B,0xD354},{0xBB8C,0xD355},{0xBB8D,0xD356},{0xBB8E,0xD357},{0xBB8F,0xD358},{0xBB90,0xD359},{0xBB91,0xD35A},{0xBB92,0xD35B},{0xBB93,0xD35C},{0xBB94,0xD35D},{0xBB95,0xD35E},{0xBB96,0xD35F},{0xBB97,0xD360},{0xBB98,0xD361},{0xBB99,0xD362},{0xBB9A,0xD363},{0xBB9B,0xD364},{0xBB9C,0xD365},{0xBB9D,0xD366},{0xBB9E,0xD367},{0xBB9F,0xD368},{0xBBA0,0xD369},{0xBC41,0xD36A},{0xBC42,0xD36B},{0xBC43,0xD36C},{0xBC44,0xD36D},{0xBC45,0xD36E},{0xBC46,0xD36F},{0xBC47,0xD370},{0xBC48,0xD371},{0xBC49,0xD372},{0xBC4A,0xD373},{0xBC4B,0xD374},{0xBC4C,0xD375},{0xBC4D,0xD376},{0xBC4E,0xD377},{0xBC4F,0xD378},{0xBC50,0xD379},{0xBC51,0xD37A},{0xBC52,0xD37B},{0xC6DB,0xD37C},{0xC6DC,0xD37D},{0xBC53,0xD37E},{0xBC54,0xD37F},{0xC6DD,0xD380},{0xBC55,0xD381},{0xBC56,0xD382},{0xBC57,0xD383},{0xC6DE,0xD384},{0xBC58,0xD385},{0xBC59,0xD386},{0xBC5A,0xD387},{0xBC61,0xD388},{0xBC62,0xD389},{0xBC63,0xD38A},{0xBC64,0xD38B},{0xC6DF,0xD38C},{0xC6E0,0xD38D},{0xBC65,0xD38E},
{0xC6E1,0xD38F},{0xC6E2,0xD390},{0xC6E3,0xD391},{0xBC66,0xD392},{0xBC67,0xD393},{0xBC68,0xD394},{0xBC69,0xD395},{0xBC6A,0xD396},{0xBC6B,0xD397},{0xC6E4,0xD398},{0xC6E5,0xD399},{0xBC6C,0xD39A},{0xBC6D,0xD39B},{0xC6E6,0xD39C},{0xBC6E,0xD39D},{0xBC6F,0xD39E},{0xBC70,0xD39F},{0xC6E7,0xD3A0},{0xBC71,0xD3A1},{0xBC72,0xD3A2},{0xBC73,0xD3A3},{0xBC74,0xD3A4},{0xBC75,0xD3A5},{0xBC76,0xD3A6},{0xBC77,0xD3A7},{0xC6E8,0xD3A8},{0xC6E9,0xD3A9},{0xBC78,0xD3AA},{0xC6EA,0xD3AB},{0xBC79,0xD3AC},{0xC6EB,0xD3AD},{0xBC7A,0xD3AE},{0xBC81,0xD3AF},{0xBC82,0xD3B0},{0xBC83,0xD3B1},{0xBC84,0xD3B2},{0xBC85,0xD3B3},{0xC6EC,0xD3B4},{0xBC86,0xD3B5},{0xBC87,0xD3B6},{0xBC88,0xD3B7},{0xC6ED,0xD3B8},{0xBC89,0xD3B9},{0xBC8A,0xD3BA},{0xBC8B,0xD3BB},{0xC6EE,0xD3BC},{0xBC8C,0xD3BD},{0xBC8D,0xD3BE},{0xBC8E,0xD3BF},{0xBC8F,0xD3C0},{0xBC90,0xD3C1},{0xBC91,0xD3C2},{0xBC92,0xD3C3},{0xC6EF,0xD3C4},{0xC6F0,0xD3C5},{0xBC93,0xD3C6},{0xBC94,0xD3C7},{0xC6F1,0xD3C8},{0xC6F2,0xD3C9},{0xBC95,0xD3CA},{0xBC96,0xD3CB},{0xBC97,0xD3CC},{0xBC98,0xD3CD},{0xBC99,0xD3CE},{0xBC9A,0xD3CF},{0xC6F3,0xD3D0},{0xBC9B,0xD3D1},{0xBC9C,0xD3D2},{0xBC9D,0xD3D3},{0xBC9E,0xD3D4},{0xBC9F,0xD3D5},{0xBCA0,0xD3D6},{0xBD41,0xD3D7},{0xC6F4,0xD3D8},{0xBD42,0xD3D9},{0xBD43,0xD3DA},{0xBD44,0xD3DB},{0xBD45,0xD3DC},{0xBD46,0xD3DD},{0xBD47,0xD3DE},{0xBD48,0xD3DF},{0xBD49,0xD3E0},{0xC6F5,0xD3E1},{0xBD4A,0xD3E2},{0xC6F6,0xD3E3},{0xBD4B,0xD3E4},{0xBD4C,0xD3E5},{0xBD4D,0xD3E6},{0xBD4E,0xD3E7},{0xBD4F,0xD3E8},{0xBD50,0xD3E9},{0xBD51,0xD3EA},{0xBD52,0xD3EB},{0xC6F7,0xD3EC},{0xC6F8,0xD3ED},{0xBD53,0xD3EE},{0xBD54,0xD3EF},{0xC6F9,0xD3F0},{0xBD55,0xD3F1},{0xBD56,0xD3F2},{0xBD57,0xD3F3},{0xC6FA,0xD3F4},{0xBD58,0xD3F5},{0xBD59,0xD3F6},{0xBD5A,0xD3F7},{0xBD61,0xD3F8},{0xBD62,0xD3F9},{0xBD63,0xD3FA},{0xBD64,0xD3FB},{0xC6FB,0xD3FC},{0xC6FC,0xD3FD},{0xBD65,0xD3FE},{0xC6FD,0xD3FF},{0xBD66,0xD400},{0xC6FE,0xD401},{0xBD67,0xD402},{0xBD68,0xD403},{0xBD69,0xD404},{0xBD6A,0xD405},{0xBD6B,0xD406},{0xBD6C,0xD407},{0xC7A1,0xD408},{0xBD6D,0xD409},{0xBD6E,0xD40A},{0xBD6F,0xD40B},{0xBD70,0xD40C},{0xBD71,0xD40D},{0xBD72,0xD40E},{0xBD73,0xD40F},{0xBD74,0xD410},{0xBD75,0xD411},{0xBD76,0xD412},{0xBD77,0xD413},{0xBD78,0xD414},{0xBD79,0xD415},{0xBD7A,0xD416},{0xBD81,0xD417},{0xBD82,0xD418},{0xBD83,0xD419},{0xBD84,0xD41A},{0xBD85,0xD41B},{0xBD86,0xD41C},{0xC7A2,0xD41D},{0xBD87,0xD41E},{0xBD88,0xD41F},{0xBD89,0xD420},{0xBD8A,0xD421},{0xBD8B,0xD422},{0xBD8C,0xD423},{0xBD8D,0xD424},{0xBD8E,0xD425},{0xBD8F,0xD426},{0xBD90,0xD427},{0xBD91,0xD428},{0xBD92,0xD429},{0xBD93,0xD42A},{0xBD94,0xD42B},{0xBD95,0xD42C},{0xBD96,0xD42D},{0xBD97,0xD42E},{0xBD98,0xD42F},{0xBD99,0xD430},{0xBD9A,0xD431},{0xBD9B,0xD432},{0xBD9C,0xD433},{0xBD9D,0xD434},{0xBD9E,0xD435},{0xBD9F,0xD436},{0xBDA0,0xD437},{0xBE41,0xD438},{0xBE42,0xD439},{0xBE43,0xD43A},{0xBE44,0xD43B},{0xBE45,0xD43C},{0xBE46,0xD43D},{0xBE47,0xD43E},{0xBE48,0xD43F},{0xC7A3,0xD440},{0xBE49,0xD441},{0xBE4A,0xD442},{0xBE4B,0xD443},{0xC7A4,0xD444},{0xBE4C,0xD445},{0xBE4D,0xD446},{0xBE4E,0xD447},{0xBE4F,0xD448},{0xBE50,0xD449},{0xBE51,0xD44A},{0xBE52,0xD44B},{0xBE53,0xD44C},{0xBE54,0xD44D},{0xBE55,0xD44E},{0xBE56,0xD44F},{0xBE57,0xD450},{0xBE58,0xD451},{0xBE59,0xD452},{0xBE5A,0xD453},{0xBE61,0xD454},{0xBE62,0xD455},{0xBE63,0xD456},{0xBE64,0xD457},{0xBE65,0xD458},{0xBE66,0xD459},{0xBE67,0xD45A},{0xBE68,0xD45B},{0xC7A5,0xD45C},{0xBE69,0xD45D},{0xBE6A,0xD45E},{0xBE6B,0xD45F},{0xC7A6,0xD460},{0xBE6C,0xD461},{0xBE6D,0xD462},{0xBE6E,0xD463},{0xC7A7,0xD464},{0xBE6F,0xD465},{0xBE70,0xD466},{0xBE71,0xD467},{0xBE72,0xD468},{0xBE73,0xD469},{0xBE74,0xD46A},{0xBE75,0xD46B},{0xBE76,0xD46C},{0xC7A8,0xD46D},{0xBE77,0xD46E},{0xC7A9,0xD46F},{0xBE78,0xD470},{0xBE79,0xD471},{0xBE7A,0xD472},{0xBE81,0xD473},{0xBE82,0xD474},{0xBE83,0xD475},{0xBE84,0xD476},{0xBE85,0xD477},{0xC7AA,0xD478},{0xC7AB,0xD479},{0xBE86,0xD47A},{0xBE87,0xD47B},{0xC7AC,0xD47C},{0xBE88,0xD47D},{0xBE89,0xD47E},{0xC7AD,0xD47F},{0xC7AE,0xD480},{0xBE8A,0xD481},{0xC7AF,0xD482},{0xBE8B,0xD483},{0xBE8C,0xD484},{0xBE8D,0xD485},
{0xBE8E,0xD486},{0xBE8F,0xD487},{0xC7B0,0xD488},{0xC7B1,0xD489},{0xBE90,0xD48A},{0xC7B2,0xD48B},{0xBE91,0xD48C},{0xC7B3,0xD48D},{0xBE92,0xD48E},{0xBE93,0xD48F},{0xBE94,0xD490},{0xBE95,0xD491},{0xBE96,0xD492},{0xBE97,0xD493},{0xC7B4,0xD494},{0xBE98,0xD495},{0xBE99,0xD496},{0xBE9A,0xD497},{0xBE9B,0xD498},{0xBE9C,0xD499},{0xBE9D,0xD49A},{0xBE9E,0xD49B},{0xBE9F,0xD49C},{0xBEA0,0xD49D},{0xBF41,0xD49E},{0xBF42,0xD49F},{0xBF43,0xD4A0},{0xBF44,0xD4A1},{0xBF45,0xD4A2},{0xBF46,0xD4A3},{0xBF47,0xD4A4},{0xBF48,0xD4A5},{0xBF49,0xD4A6},{0xBF4A,0xD4A7},{0xBF4B,0xD4A8},{0xC7B5,0xD4A9},{0xBF4C,0xD4AA},{0xBF4D,0xD4AB},{0xBF4E,0xD4AC},{0xBF4F,0xD4AD},{0xBF50,0xD4AE},{0xBF51,0xD4AF},{0xBF52,0xD4B0},{0xBF53,0xD4B1},{0xBF54,0xD4B2},{0xBF55,0xD4B3},{0xBF56,0xD4B4},{0xBF57,0xD4B5},{0xBF58,0xD4B6},{0xBF59,0xD4B7},{0xBF5A,0xD4B8},{0xBF61,0xD4B9},{0xBF62,0xD4BA},{0xBF63,0xD4BB},{0xBF64,0xD4BC},{0xBF65,0xD4BD},{0xBF66,0xD4BE},{0xBF67,0xD4BF},{0xBF68,0xD4C0},{0xBF69,0xD4C1},{0xBF6A,0xD4C2},{0xBF6B,0xD4C3},{0xBF6C,0xD4C4},{0xBF6D,0xD4C5},{0xBF6E,0xD4C6},{0xBF6F,0xD4C7},{0xBF70,0xD4C8},{0xBF71,0xD4C9},{0xBF72,0xD4CA},{0xBF73,0xD4CB},{0xC7B6,0xD4CC},{0xBF74,0xD4CD},{0xBF75,0xD4CE},{0xBF76,0xD4CF},{0xC7B7,0xD4D0},{0xBF77,0xD4D1},{0xBF78,0xD4D2},{0xBF79,0xD4D3},{0xC7B8,0xD4D4},{0xBF7A,0xD4D5},{0xBF81,0xD4D6},{0xBF82,0xD4D7},{0xBF83,0xD4D8},{0xBF84,0xD4D9},{0xBF85,0xD4DA},{0xBF86,0xD4DB},{0xC7B9,0xD4DC},{0xBF87,0xD4DD},{0xBF88,0xD4DE},{0xC7BA,0xD4DF},{0xBF89,0xD4E0},{0xBF8A,0xD4E1},{0xBF8B,0xD4E2},{0xBF8C,0xD4E3},{0xBF8D,0xD4E4},{0xBF8E,0xD4E5},{0xBF8F,0xD4E6},{0xBF90,0xD4E7},{0xC7BB,0xD4E8},{0xBF91,0xD4E9},{0xBF92,0xD4EA},{0xBF93,0xD4EB},{0xC7BC,0xD4EC},{0xBF94,0xD4ED},{0xBF95,0xD4EE},{0xBF96,0xD4EF},{0xC7BD,0xD4F0},{0xBF97,0xD4F1},{0xBF98,0xD4F2},{0xBF99,0xD4F3},{0xBF9A,0xD4F4},{0xBF9B,0xD4F5},{0xBF9C,0xD4F6},{0xBF9D,0xD4F7},{0xC7BE,0xD4F8},{0xBF9E,0xD4F9},{0xBF9F,0xD4FA},{0xC7BF,0xD4FB},{0xBFA0,0xD4FC},{0xC7C0,0xD4FD},{0xC041,0xD4FE},{0xC042,0xD4FF},{0xC043,0xD500},{0xC044,0xD501},{0xC045,0xD502},{0xC046,0xD503},{0xC7C1,0xD504},{0xC047,0xD505},{0xC048,0xD506},{0xC049,0xD507},{0xC7C2,0xD508},{0xC04A,0xD509},{0xC04B,0xD50A},{0xC04C,0xD50B},{0xC7C3,0xD50C},{0xC04D,0xD50D},{0xC04E,0xD50E},{0xC04F,0xD50F},{0xC050,0xD510},{0xC051,0xD511},{0xC052,0xD512},{0xC053,0xD513},{0xC7C4,0xD514},{0xC7C5,0xD515},{0xC054,0xD516},{0xC7C6,0xD517},{0xC055,0xD518},{0xC056,0xD519},{0xC057,0xD51A},{0xC058,0xD51B},{0xC059,0xD51C},{0xC05A,0xD51D},{0xC061,0xD51E},{0xC062,0xD51F},{0xC063,0xD520},{0xC064,0xD521},{0xC065,0xD522},{0xC066,0xD523},{0xC067,0xD524},{0xC068,0xD525},{0xC069,0xD526},{0xC06A,0xD527},{0xC06B,0xD528},{0xC06C,0xD529},{0xC06D,0xD52A},{0xC06E,0xD52B},{0xC06F,0xD52C},{0xC070,0xD52D},{0xC071,0xD52E},{0xC072,0xD52F},{0xC073,0xD530},{0xC074,0xD531},{0xC075,0xD532},{0xC076,0xD533},{0xC077,0xD534},{0xC078,0xD535},{0xC079,0xD536},{0xC07A,0xD537},{0xC081,0xD538},{0xC082,0xD539},{0xC083,0xD53A},{0xC084,0xD53B},{0xC7C7,0xD53C},{0xC7C8,0xD53D},{0xC085,0xD53E},{0xC086,0xD53F},{0xC7C9,0xD540},{0xC087,0xD541},{0xC088,0xD542},{0xC089,0xD543},{0xC7CA,0xD544},{0xC08A,0xD545},{0xC08B,0xD546},{0xC08C,0xD547},{0xC08D,0xD548},{0xC08E,0xD549},{0xC08F,0xD54A},{0xC090,0xD54B},{0xC7CB,0xD54C},{0xC7CC,0xD54D},{0xC091,0xD54E},{0xC7CD,0xD54F},{0xC092,0xD550},{0xC7CE,0xD551},{0xC093,0xD552},{0xC094,0xD553},{0xC095,0xD554},{0xC096,0xD555},{0xC097,0xD556},{0xC098,0xD557},{0xC7CF,0xD558},{0xC7D0,0xD559},{0xC099,0xD55A},{0xC09A,0xD55B},{0xC7D1,0xD55C},{0xC09B,0xD55D},{0xC09C,0xD55E},{0xC09D,0xD55F},{0xC7D2,0xD560},{0xC09E,0xD561},{0xC09F,0xD562},{0xC0A0,0xD563},{0xC141,0xD564},{0xC7D3,0xD565},{0xC142,0xD566},{0xC143,0xD567},{0xC7D4,0xD568},{0xC7D5,0xD569},{0xC144,0xD56A},{0xC7D6,0xD56B},{0xC145,0xD56C},{0xC7D7,0xD56D},{0xC146,0xD56E},{0xC147,0xD56F},{0xC148,0xD570},{0xC149,0xD571},{0xC14A,0xD572},{0xC14B,0xD573},{0xC7D8,0xD574},{0xC7D9,0xD575},{0xC14C,0xD576},{0xC14D,0xD577},{0xC7DA,0xD578},{0xC14E,0xD579},{0xC14F,0xD57A},{0xC150,0xD57B},{0xC7DB,0xD57C},
{0xC151,0xD57D},{0xC152,0xD57E},{0xC153,0xD57F},{0xC154,0xD580},{0xC155,0xD581},{0xC156,0xD582},{0xC157,0xD583},{0xC7DC,0xD584},{0xC7DD,0xD585},{0xC158,0xD586},{0xC7DE,0xD587},{0xC7DF,0xD588},{0xC7E0,0xD589},{0xC159,0xD58A},{0xC15A,0xD58B},{0xC161,0xD58C},{0xC162,0xD58D},{0xC163,0xD58E},{0xC164,0xD58F},{0xC7E1,0xD590},{0xC165,0xD591},{0xC166,0xD592},{0xC167,0xD593},{0xC168,0xD594},{0xC169,0xD595},{0xC16A,0xD596},{0xC16B,0xD597},{0xC16C,0xD598},{0xC16D,0xD599},{0xC16E,0xD59A},{0xC16F,0xD59B},{0xC170,0xD59C},{0xC171,0xD59D},{0xC172,0xD59E},{0xC173,0xD59F},{0xC174,0xD5A0},{0xC175,0xD5A1},{0xC176,0xD5A2},{0xC177,0xD5A3},{0xC178,0xD5A4},{0xC7E2,0xD5A5},{0xC179,0xD5A6},{0xC17A,0xD5A7},{0xC181,0xD5A8},{0xC182,0xD5A9},{0xC183,0xD5AA},{0xC184,0xD5AB},{0xC185,0xD5AC},{0xC186,0xD5AD},{0xC187,0xD5AE},{0xC188,0xD5AF},{0xC189,0xD5B0},{0xC18A,0xD5B1},{0xC18B,0xD5B2},{0xC18C,0xD5B3},{0xC18D,0xD5B4},{0xC18E,0xD5B5},{0xC18F,0xD5B6},{0xC190,0xD5B7},{0xC191,0xD5B8},{0xC192,0xD5B9},{0xC193,0xD5BA},{0xC194,0xD5BB},{0xC195,0xD5BC},{0xC196,0xD5BD},{0xC197,0xD5BE},{0xC198,0xD5BF},{0xC199,0xD5C0},{0xC19A,0xD5C1},{0xC19B,0xD5C2},{0xC19C,0xD5C3},{0xC19D,0xD5C4},{0xC19E,0xD5C5},{0xC19F,0xD5C6},{0xC1A0,0xD5C7},{0xC7E3,0xD5C8},{0xC7E4,0xD5C9},{0xC241,0xD5CA},{0xC242,0xD5CB},{0xC7E5,0xD5CC},{0xC243,0xD5CD},{0xC244,0xD5CE},{0xC245,0xD5CF},{0xC7E6,0xD5D0},{0xC246,0xD5D1},{0xC7E7,0xD5D2},{0xC247,0xD5D3},{0xC248,0xD5D4},{0xC249,0xD5D5},{0xC24A,0xD5D6},{0xC24B,0xD5D7},{0xC7E8,0xD5D8},{0xC7E9,0xD5D9},{0xC24C,0xD5DA},{0xC7EA,0xD5DB},{0xC24D,0xD5DC},{0xC7EB,0xD5DD},{0xC24E,0xD5DE},{0xC24F,0xD5DF},{0xC250,0xD5E0},{0xC251,0xD5E1},{0xC252,0xD5E2},{0xC253,0xD5E3},{0xC7EC,0xD5E4},{0xC7ED,0xD5E5},{0xC254,0xD5E6},{0xC255,0xD5E7},{0xC7EE,0xD5E8},{0xC256,0xD5E9},{0xC257,0xD5EA},{0xC258,0xD5EB},{0xC7EF,0xD5EC},{0xC259,0xD5ED},{0xC25A,0xD5EE},{0xC261,0xD5EF},{0xC262,0xD5F0},{0xC263,0xD5F1},{0xC264,0xD5F2},{0xC265,0xD5F3},{0xC7F0,0xD5F4},{0xC7F1,0xD5F5},{0xC266,0xD5F6},{0xC7F2,0xD5F7},{0xC267,0xD5F8},{0xC7F3,0xD5F9},{0xC268,0xD5FA},{0xC269,0xD5FB},{0xC26A,0xD5FC},{0xC26B,0xD5FD},{0xC26C,0xD5FE},{0xC26D,0xD5FF},{0xC7F4,0xD600},{0xC7F5,0xD601},{0xC26E,0xD602},{0xC26F,0xD603},{0xC7F6,0xD604},{0xC270,0xD605},{0xC271,0xD606},{0xC272,0xD607},{0xC7F7,0xD608},{0xC273,0xD609},{0xC274,0xD60A},{0xC275,0xD60B},{0xC276,0xD60C},{0xC277,0xD60D},{0xC278,0xD60E},{0xC279,0xD60F},{0xC7F8,0xD610},{0xC7F9,0xD611},{0xC27A,0xD612},{0xC7FA,0xD613},{0xC7FB,0xD614},{0xC7FC,0xD615},{0xC281,0xD616},{0xC282,0xD617},{0xC283,0xD618},{0xC284,0xD619},{0xC285,0xD61A},{0xC286,0xD61B},{0xC7FD,0xD61C},{0xC287,0xD61D},{0xC288,0xD61E},{0xC289,0xD61F},{0xC7FE,0xD620},{0xC28A,0xD621},{0xC28B,0xD622},{0xC28C,0xD623},{0xC8A1,0xD624},{0xC28D,0xD625},{0xC28E,0xD626},{0xC28F,0xD627},{0xC290,0xD628},{0xC291,0xD629},{0xC292,0xD62A},{0xC293,0xD62B},{0xC294,0xD62C},{0xC8A2,0xD62D},{0xC295,0xD62E},{0xC296,0xD62F},{0xC297,0xD630},{0xC298,0xD631},{0xC299,0xD632},{0xC29A,0xD633},{0xC29B,0xD634},{0xC29C,0xD635},{0xC29D,0xD636},{0xC29E,0xD637},{0xC8A3,0xD638},{0xC8A4,0xD639},{0xC29F,0xD63A},{0xC2A0,0xD63B},{0xC8A5,0xD63C},{0xC341,0xD63D},{0xC342,0xD63E},{0xC343,0xD63F},{0xC8A6,0xD640},{0xC344,0xD641},{0xC345,0xD642},{0xC346,0xD643},{0xC347,0xD644},{0xC8A7,0xD645},{0xC348,0xD646},{0xC349,0xD647},{0xC8A8,0xD648},{0xC8A9,0xD649},{0xC34A,0xD64A},{0xC8AA,0xD64B},{0xC34B,0xD64C},{0xC8AB,0xD64D},{0xC34C,0xD64E},{0xC34D,0xD64F},{0xC34E,0xD650},{0xC8AC,0xD651},{0xC34F,0xD652},{0xC350,0xD653},{0xC8AD,0xD654},{0xC8AE,0xD655},{0xC351,0xD656},{0xC352,0xD657},{0xC8AF,0xD658},{0xC353,0xD659},{0xC354,0xD65A},{0xC355,0xD65B},{0xC8B0,0xD65C},{0xC356,0xD65D},{0xC357,0xD65E},{0xC358,0xD65F},{0xC359,0xD660},{0xC35A,0xD661},{0xC361,0xD662},{0xC362,0xD663},{0xC363,0xD664},{0xC364,0xD665},{0xC365,0xD666},{0xC8B1,0xD667},{0xC366,0xD668},{0xC8B2,0xD669},{0xC367,0xD66A},{0xC368,0xD66B},{0xC369,0xD66C},{0xC36A,0xD66D},{0xC36B,0xD66E},{0xC36C,0xD66F},{0xC8B3,0xD670},{0xC8B4,0xD671},{0xC36D,0xD672},{0xC36E,0xD673},
{0xC8B5,0xD674},{0xC36F,0xD675},{0xC370,0xD676},{0xC371,0xD677},{0xC372,0xD678},{0xC373,0xD679},{0xC374,0xD67A},{0xC375,0xD67B},{0xC376,0xD67C},{0xC377,0xD67D},{0xC378,0xD67E},{0xC379,0xD67F},{0xC37A,0xD680},{0xC381,0xD681},{0xC382,0xD682},{0xC8B6,0xD683},{0xC383,0xD684},{0xC8B7,0xD685},{0xC384,0xD686},{0xC385,0xD687},{0xC386,0xD688},{0xC387,0xD689},{0xC388,0xD68A},{0xC389,0xD68B},{0xC8B8,0xD68C},{0xC8B9,0xD68D},{0xC38A,0xD68E},{0xC38B,0xD68F},{0xC8BA,0xD690},{0xC38C,0xD691},{0xC38D,0xD692},{0xC38E,0xD693},{0xC8BB,0xD694},{0xC38F,0xD695},{0xC390,0xD696},{0xC391,0xD697},{0xC392,0xD698},{0xC393,0xD699},{0xC394,0xD69A},{0xC395,0xD69B},{0xC396,0xD69C},{0xC8BC,0xD69D},{0xC397,0xD69E},{0xC8BD,0xD69F},{0xC398,0xD6A0},{0xC8BE,0xD6A1},{0xC399,0xD6A2},{0xC39A,0xD6A3},{0xC39B,0xD6A4},{0xC39C,0xD6A5},{0xC39D,0xD6A6},{0xC39E,0xD6A7},{0xC8BF,0xD6A8},{0xC39F,0xD6A9},{0xC3A0,0xD6AA},{0xC441,0xD6AB},{0xC8C0,0xD6AC},{0xC442,0xD6AD},{0xC443,0xD6AE},{0xC444,0xD6AF},{0xC8C1,0xD6B0},{0xC445,0xD6B1},{0xC446,0xD6B2},{0xC447,0xD6B3},{0xC448,0xD6B4},{0xC449,0xD6B5},{0xC44A,0xD6B6},{0xC44B,0xD6B7},{0xC44C,0xD6B8},{0xC8C2,0xD6B9},{0xC44D,0xD6BA},{0xC8C3,0xD6BB},{0xC44E,0xD6BC},{0xC44F,0xD6BD},{0xC450,0xD6BE},{0xC451,0xD6BF},{0xC452,0xD6C0},{0xC453,0xD6C1},{0xC454,0xD6C2},{0xC455,0xD6C3},{0xC8C4,0xD6C4},{0xC8C5,0xD6C5},{0xC456,0xD6C6},{0xC457,0xD6C7},{0xC8C6,0xD6C8},{0xC458,0xD6C9},{0xC459,0xD6CA},{0xC45A,0xD6CB},{0xC8C7,0xD6CC},{0xC461,0xD6CD},{0xC462,0xD6CE},{0xC463,0xD6CF},{0xC464,0xD6D0},{0xC8C8,0xD6D1},{0xC465,0xD6D2},{0xC466,0xD6D3},{0xC8C9,0xD6D4},{0xC467,0xD6D5},{0xC468,0xD6D6},{0xC8CA,0xD6D7},{0xC469,0xD6D8},{0xC8CB,0xD6D9},{0xC46A,0xD6DA},{0xC46B,0xD6DB},{0xC46C,0xD6DC},{0xC46D,0xD6DD},{0xC46E,0xD6DE},{0xC46F,0xD6DF},{0xC8CC,0xD6E0},{0xC470,0xD6E1},{0xC471,0xD6E2},{0xC472,0xD6E3},{0xC8CD,0xD6E4},{0xC473,0xD6E5},{0xC474,0xD6E6},{0xC475,0xD6E7},{0xC8CE,0xD6E8},{0xC476,0xD6E9},{0xC477,0xD6EA},{0xC478,0xD6EB},{0xC479,0xD6EC},{0xC47A,0xD6ED},{0xC481,0xD6EE},{0xC482,0xD6EF},{0xC8CF,0xD6F0},{0xC483,0xD6F1},{0xC484,0xD6F2},{0xC485,0xD6F3},{0xC486,0xD6F4},{0xC8D0,0xD6F5},{0xC487,0xD6F6},{0xC488,0xD6F7},{0xC489,0xD6F8},{0xC48A,0xD6F9},{0xC48B,0xD6FA},{0xC48C,0xD6FB},{0xC8D1,0xD6FC},{0xC8D2,0xD6FD},{0xC48D,0xD6FE},{0xC48E,0xD6FF},{0xC8D3,0xD700},{0xC48F,0xD701},{0xC490,0xD702},{0xC491,0xD703},{0xC8D4,0xD704},{0xC492,0xD705},{0xC493,0xD706},{0xC494,0xD707},{0xC495,0xD708},{0xC496,0xD709},{0xC497,0xD70A},{0xC498,0xD70B},{0xC499,0xD70C},{0xC49A,0xD70D},{0xC49B,0xD70E},{0xC49C,0xD70F},{0xC49D,0xD710},{0xC8D5,0xD711},{0xC49E,0xD712},{0xC49F,0xD713},{0xC4A0,0xD714},{0xC541,0xD715},{0xC542,0xD716},{0xC543,0xD717},{0xC8D6,0xD718},{0xC8D7,0xD719},{0xC544,0xD71A},{0xC545,0xD71B},{0xC8D8,0xD71C},{0xC546,0xD71D},{0xC547,0xD71E},{0xC548,0xD71F},{0xC8D9,0xD720},{0xC549,0xD721},{0xC54A,0xD722},{0xC54B,0xD723},{0xC54C,0xD724},{0xC54D,0xD725},{0xC54E,0xD726},{0xC54F,0xD727},{0xC8DA,0xD728},{0xC8DB,0xD729},{0xC550,0xD72A},{0xC8DC,0xD72B},{0xC551,0xD72C},{0xC8DD,0xD72D},{0xC552,0xD72E},{0xC553,0xD72F},{0xC554,0xD730},{0xC555,0xD731},{0xC556,0xD732},{0xC557,0xD733},{0xC8DE,0xD734},{0xC8DF,0xD735},{0xC558,0xD736},{0xC559,0xD737},{0xC8E0,0xD738},{0xC55A,0xD739},{0xC561,0xD73A},{0xC562,0xD73B},{0xC8E1,0xD73C},{0xC563,0xD73D},{0xC564,0xD73E},{0xC565,0xD73F},{0xC566,0xD740},{0xC567,0xD741},{0xC568,0xD742},{0xC569,0xD743},{0xC8E2,0xD744},{0xC56A,0xD745},{0xC56B,0xD746},{0xC8E3,0xD747},{0xC56C,0xD748},{0xC8E4,0xD749},{0xC56D,0xD74A},{0xC56E,0xD74B},{0xC56F,0xD74C},{0xC570,0xD74D},{0xC571,0xD74E},{0xC572,0xD74F},{0xC8E5,0xD750},{0xC8E6,0xD751},{0xC573,0xD752},{0xC574,0xD753},{0xC8E7,0xD754},{0xC575,0xD755},{0xC8E8,0xD756},{0xC8E9,0xD757},{0xC8EA,0xD758},{0xC8EB,0xD759},{0xC576,0xD75A},{0xC577,0xD75B},{0xC578,0xD75C},{0xC579,0xD75D},{0xC57A,0xD75E},{0xC581,0xD75F},{0xC8EC,0xD760},{0xC8ED,0xD761},{0xC582,0xD762},{0xC8EE,0xD763},{0xC583,0xD764},{0xC8EF,0xD765},{0xC584,0xD766},{0xC585,0xD767},{0xC586,0xD768},{0xC8F0,0xD769},{0xC587,0xD76A},
{0xC588,0xD76B},{0xC8F1,0xD76C},{0xC589,0xD76D},{0xC58A,0xD76E},{0xC58B,0xD76F},{0xC8F2,0xD770},{0xC58C,0xD771},{0xC58D,0xD772},{0xC58E,0xD773},{0xC8F3,0xD774},{0xC58F,0xD775},{0xC590,0xD776},{0xC591,0xD777},{0xC592,0xD778},{0xC593,0xD779},{0xC594,0xD77A},{0xC595,0xD77B},{0xC8F4,0xD77C},{0xC8F5,0xD77D},{0xC596,0xD77E},{0xC597,0xD77F},{0xC598,0xD780},{0xC8F6,0xD781},{0xC599,0xD782},{0xC59A,0xD783},{0xC59B,0xD784},{0xC59C,0xD785},{0xC59D,0xD786},{0xC59E,0xD787},{0xC8F7,0xD788},{0xC8F8,0xD789},{0xC59F,0xD78A},{0xC5A0,0xD78B},{0xC8F9,0xD78C},{0xC641,0xD78D},{0xC642,0xD78E},{0xC643,0xD78F},{0xC8FA,0xD790},{0xC644,0xD791},{0xC645,0xD792},{0xC646,0xD793},{0xC647,0xD794},{0xC648,0xD795},{0xC649,0xD796},{0xC64A,0xD797},{0xC8FB,0xD798},{0xC8FC,0xD799},{0xC64B,0xD79A},{0xC8FD,0xD79B},{0xC64C,0xD79C},{0xC8FE,0xD79D},{0xC64D,0xD79E},{0xC64E,0xD79F},{0xC64F,0xD7A0},{0xC650,0xD7A1},{0xC651,0xD7A2},{0xC652,0xD7A3}
};

DO_COMMAND(do_test)
{
	int i;

	arg = sub_arg_in_braces(ses, arg, arg1, GET_ONE, SUB_VAR|SUB_FUN);

	if (!strcmp(arg1, "bla"))
	{
		int size = sizeof(cp949_to_unicode_table) / sizeof(struct interval_type);

		printf("size: %d\n", size);

		for (i = 0 ; i < size ; i++)
		{
			execute(ses, "#variable keys[%d] %d", cp949_to_unicode_table[i].head, cp949_to_unicode_table[i].tail);
//			command(ses, do_line, "log cp949_to_unicode_keys %d,", cp949_to_unicode_table[i].head);
//			command(ses, do_line, "log cp949_to_unicode_vals %d,", cp949_to_unicode_table[i].tail);
		}
	}

	if (!strcmp(arg1, "rain"))
	{
		strcpy(arg2, "9");
		strcpy(arg3, "<f3c3>");
		strcpy(arg1, "1 9");

		if (is_digit(arg[0]))
		{
			sprintf(arg2, "%d", (arg[0] - '0') * (arg[0] - '0'));

			if ((is_hex(arg[1]) && is_hex(arg[2]) && is_hex(arg[3])) || (arg[1] == '?' && arg[2] == '?' && arg[3] == '?'))
			{
				sprintf(arg3, "<f%c%c%c>", arg[1], arg[2], arg[3]);

				if (is_digit(arg[4]) && is_digit(arg[5]))
				{
					sprintf(arg1, "%f %d %s", (arg[4] - '0') * (arg[4] - '0') / 10.0, (arg[5] - '0') * (arg[5] - '0'), &arg[6]);
				}
			}
		}
		command(gtd->ses, do_line, "quiet {#event {RECEIVED KEYPRESS} {#end \\};#screen cursor hide;#screen clear all;#event {SECOND} #loop 0 %s cnt #delay {$cnt / (1.0+%s)} #draw %s rain 1 1 -1 -1 rain %s}", arg2, arg2, arg3, arg1);

		return ses;
	}

	return ses;
}

